/* Avnet MicroMonitor configuration file.
 */

#define PLATFORM_NAME       "AVNET Spartan-3 Eval"
#define CPU_NAME			"MicroBlaze"

#define CPU_BE

/* LOOPS_PER_SECOND:
 * Approximately the size of a loop that will cause a 1-second delay.
 * This value can be adjusted by using the "sleep -c" command.
 */
#define LOOPS_PER_SECOND	14000

/* RAM_VECTOR_TABLE:
 * Used as the location into which the ram-based vector table
 * (installed by uMON) is placed...
 */
#define RAM_VECTOR_TABLE    0x00000000

/* Flash bank configuration:
 * Basic information needed to configure the flash driver.
 * Fill in port specific values here.
 */
#define SINGLE_FLASH_DEVICE 	1
#define FLASH_COPY_TO_RAM 		1
#define FLASH_BANK0_BASE_ADDR  	0x22000000
#define FLASH_PROTECT_RANGE  	"0-2"
#define FLASH_BANK0_WIDTH       4
#define FLASH_LARGEST_SECTOR    0x20000
#define FLASHBANKS				1

/* If there is a need to have the range of protected sectors locked (and
 * the flash device driver supports it), then enable this macro...
#define LOCK_FLASH_PROTECT_RANGE
 */

/* TFS definitions:
 * Values that configure the flash space that is allocated to TFS.
 * Fill in port specific values here.
 */
#define TFSSPARESIZE    		FLASH_LARGEST_SECTOR
#define TFSSTART        		(FLASH_BANK0_BASE_ADDR+0x80000)
#define TFSEND          		0x227dFFFF
#define TFSSPARE        		(TFSEND+1)
#define TFSSECTORCOUNT			((TFSSPARE-TFSSTART)/0x20000)
#define TFS_EBIN_ELF    		1
#define TFS_VERBOSE_STARTUP		1
//#define TFS_ALTDEVTBL_BASE		&alt_tfsdevtbl_base

/* ALLOCSIZE:
 * Specify the size of the memory block (in monitor space) that
 * is to be allocated to malloc in the monitor.  Note that this
 * size can be dynamically increased using the heap command at
 * runtime.
 */
#define ALLOCSIZE 		(64*1024)

/* MONSTACKSIZE:
 * The amount of space allocated to the monitor's stack.
 */
#define MONSTACKSIZE	(8*1024)

/* INCLUDE_XXX Macros:
 * Set/clear the appropriate macros depending on what you want
 * to configure in your system.  The sanity of this list is tested
 * through the inclusion of "inc_check.h" at the bottom of this list...
 * When starting a port, set all but INCLUDE_MALLOC, INCLUDE_SHELLVARS,
 * INCLUDE_MEMCMDS and INCLUDE_XMODEM to zero.  Then in small steps
 * enable the following major features in the following order:
 *
 *	INCLUDE_FLASH to test the flash device drivers.
 *	INCLUDE_TFS* to overlay TFS onto the flash. 
 *  INCLUDE_ETHERNET, INCLUDE_TFTP to turn the ethernet interface.
 *
 * All other INCLUDE_XXX macros can be enabled as needed and for the
 * most part, they're hardware independent.
 * Note that for building a very small footprint, INCLUDE_MALLOC and
 * INCLUDE_SHELLVARS can be disabled.
 */
								
#define INCLUDE_MALLOC			1
#define INCLUDE_MEMCMDS         1
#define INCLUDE_SHELLVARS		1
#define INCLUDE_XMODEM          1
#define INCLUDE_EDIT            1
#define INCLUDE_DISASSEMBLER    0
#define INCLUDE_UNZIP           0
#define INCLUDE_ETHERNET        1
#define INCLUDE_ICMP			INCLUDE_ETHERNET
#define INCLUDE_TFTP            INCLUDE_ETHERNET
#define INCLUDE_TFS             1
#define INCLUDE_FLASH           1
#define INCLUDE_LINEEDIT        1
#define INCLUDE_DHCPBOOT        INCLUDE_ETHERNET
#define INCLUDE_TFSAPI          1
#define INCLUDE_TFSSYMTBL       1
#define INCLUDE_TFSSCRIPT       1
#define INCLUDE_TFSCLI          1
#define INCLUDE_EE              0
#define INCLUDE_GDB             0
#define INCLUDE_STRACE          1
#define INCLUDE_CAST            0
#define INCLUDE_STRUCT          0
#define INCLUDE_REDIRECT        0
#define INCLUDE_QUICKMEMCPY     0
#define INCLUDE_PROFILER        0
#define INCLUDE_BBC             0
#define INCLUDE_MEMTRACE        0
#define INCLUDE_STOREMAC        0
#define INCLUDE_VERBOSEHELP     1
#define INCLUDE_HWTMR	 	    0
#define INCLUDE_PORTCMD	 	    0
#define INCLUDE_USRLVL	 	    0

#define INCLUDE_TFTPSRVR		INCLUDE_ETHERNET
#define INCLUDE_ETHERVERBOSE	INCLUDE_ETHERNET
#define INCLUDE_MONCMD			INCLUDE_ETHERNET

#include "inc_check.h"
