/* etherdev.c:
 *
 * General notice:
 * This code is part of a boot-monitor package developed as a generic base
 * platform for embedded system designs.  As such, it is likely to be
 * distributed to various projects beyond the control of the original
 * author.  Please notify the author of any enhancements made or bugs found
 * so that all may benefit from the changes.  In addition, notification back
 * to the author will allow the new user to pick up changes that may have
 * been made by other users after this version of the code was distributed.
 *
 * Author:	Ed Sutter
 * email:	esutter@lucent.com
 * phone:	908-582-2351
 */

#include "config.h"
#if INCLUDE_ETHERNET
#include "genlib.h"
#include "stddefs.h"
#include "ether.h"
#include "xemac.h"
#include "xemac_l.h"
#include "xparameters.h"
#include "xpacket_fifo_l_v2_00_a.h"

XEmac	emac;

char *enetadd, *ipadd;

#define EBASE XPAR_OPB_ETHERNET_0_BASEADDR

ulong tx_buff[400];

void
enreset(void)
{
}

int
eninit(void)
{
	int devid = 0;
	XStatus xresult;

	if ((xresult = XEmac_Initialize(&emac,devid)) != XST_SUCCESS)
		printf("XEmac_Initialize() failed %d\n",xresult);

	XEmac_SetOptions(&emac,XEmac_GetOptions(&emac) | XEM_POLLED_OPTION);
	XEmac_SetMacAddress(&emac,BinEnetAddr);
	XEmac_Start(&emac);
	XEmac_PhyReset(&emac);
	return (0);
}

int
EtherdevStartup(int verbose)
{
	enreset();
	return(eninit());
}

/* disablePromiscuousReception():
 * Provide the code that disables promiscuous reception.
 */
void
disablePromiscuousReception(void)
{
	/* OPT_ADD_CODE_HERE */
}

/* enablePromiscuousReception():
 * Provide the code that enables promiscuous reception.
 */
void
enablePromiscuousReception(void)
{
	/* OPT_ADD_CODE_HERE */
}

/* disableBroadcastReception():
 * Provide the code that disables broadcast reception.
 */
void
disableBroadcastReception(void)
{
	/* ADD_CODE_HERE */
}

/* enableBroadcastReception():
 * Provide the code that enables broadcast reception.
 */
void
enableBroadcastReception(void)
{
	/* ADD_CODE_HERE */
}

/* 
 * enselftest():
 *	Run a self test of the ethernet device(s).  This can be stubbed
 *	with a return(1).
 *	Return 1 if success; else -1 if failure.
 */
int
enselftest(int verbose)
{
	return(1);
}

/* ShowEtherdevStats():
 * This function is used to display device-specific stats (error counts
 * usually).
 */
void
ShowEtherdevStats(void)
{
	/* OPT_ADD_CODE_HERE */
}

/* getXmitBuffer():
 * Return a pointer to the buffer that is to be used for transmission of
 * the next packet.  Since the monitor's driver is EXTREMELY basic,
 * there will only be one packet ever being transmitted.  No need to queue
 * up transmit packets.
 */
uchar *
getXmitBuffer(void)
{
	return((uchar *)tx_buff);
}

/* sendBuffer():
 * Send out the packet assumed to be built in the buffer returned by the
 * previous call to getXmitBuffer() above.
 */
int
sendBuffer(int length)
{
#if INCLUDE_ETHERVERBOSE
	if (EtherVerbose &  SHOW_OUTGOING)
		printPkt((struct ether_header *)tx_buff,length,ETHER_OUTGOING);
#endif

	/* Bump up the packet length to a minimum of 64 bytes.
	 */
	if (length < 64)
		length = 64;

	XEmac_PollSend(&emac,(uchar *)tx_buff,length);

	EtherXFRAMECnt++;
	return(0);
}

int
polletherdev(void)
{
	static uchar pktbuf[1600];
	long pktlen;

	pktlen = sizeof(pktbuf);
	if (XEmac_PollRecv(&emac,pktbuf,&pktlen) == XST_SUCCESS) {
		processPACKET((struct ether_header *)pktbuf, pktlen);
		return(1);
	}

	return(0);
}

void
DisableEtherdev(void)
{
	XEmac_Stop(&emac);
}

char *
extGetIpAdd(void)
{
	return((char *)0);
}

char *
extGetEtherAdd(void)
{
	return((char *)0);
}

#endif
