#include "config.h"
#include "cpu.h"
#include "cpuio.h"
#include "cdefBF537.h"

/* cpuInit():
 * This function is called at CPU reset time to initialize the basic
 * stuff on the BF537.  It is called VERY early in the startup, so
 * don't assume printf is available.
 */
void
cpuinit(void)
{
	volatile int c;
	volatile unsigned short stmp;

	/* PLL setup:
	 */
	asm("ssync;");
	*pPLL_CTL = (MSEL_VAL << 9) | PLL_DF_VAL;
	*pSIC_IWR = 1;
	asm("ssync;");
	asm("cli r0;");
	asm("idle;");
	asm("sti r0;");
	asm("ssync;");

	*pPLL_LOCKCNT =	0x0300;
	*pPLL_DIV = (SSEL_VAL) | (CSEL_VAL << 4);
	asm("ssync;");

	*pDTEST_COMMAND = 0;

	/* Memory bank init:
	 * All banks are tied to the 1 4Mg flash, so they're all configured
	 * the same...
	 *   - BWAT: 8 cycles
	 *   - BRAT: 4 cycles
	 *   - BHT:  1 cycle 
	 *   - BST:  2 cycles 
	 *   - BTT:  1 cycle 
	 */
	*pEBIU_AMBCTL0 = 0x84668466;
	*pEBIU_AMBCTL1 = 0x84668466;
	asm("ssync;");

//	*pVR_CTL |= CLKBUFOE;		/* enable CLKBUF output to drive PHY */

	/* SDRAM ctrlr init:
	 * (should be done 100us after reset)
	 * Refer to pg 6-60 of HW reference.
	 */
	for(c=0;c<100000;c++);
	*pEBIU_SDRRC = (((SYSCLKFREQ/1000) * 64) / 8192) - (TRAS + TRP);
	asm("ssync;");
	*pEBIU_SDBCTL = (EBCAW_10 | EBSZ_64 | EBE);
	asm("ssync;");
	if (*pEBIU_SDSTAT & SDRS)
		*pEBIU_SDGCTL = (PSS | TWR_2 | TRCD_2 | TRP_2 | TRAS_5 | CL_3 | SCTLE);
	else
		*pEBIU_SDGCTL = (TWR_2 | TRCD_2 | TRP_2 | TRAS_5 | CL_3 | SCTLE);
	asm("ssync;");

	*pEBIU_AMGCTL = 0x00ff;
	asm("ssync;");
	
	for(c=0;c<10000;c++);
		*(char *)c = (char)c;

	*pPORT_MUX = 0x0000;

#if HARDWARE_IS_REVA

	/* Port F configuration:
	 * PF0:  UART0_TX
	 * PF1:  UART0_RX
	 * PF2:  UART1_TX
	 * PF3:  UART1_RX
	 * PF4:  LED DS2 Green Bit
	 * PF5:  UART1 TX_ENABLE (RS485)
	 * PF6:  LED DS2 Red Bit
	 * PF8:  PPI_FS2
	 * PF9:  PPI_FS1
	 * PF10: LED DS3 Red Bit
	 * PF11: Isolated input
	 * PF12: Isolated output
	 * PF13: Isolated output
	 * PF14: LED DS3 Green Bit
	 * PF15: PPI_CLK
	 */
	stmp = *pPORTF_FER;
	*pPORTF_FER = 0x870f;
	*pPORTF_FER = 0x870f;
	*pPORTFIO_DIR = LED_BITMASK | ISO_OUT1BIT | ISO_OUT2BIT | TX485_EN;
	*pPORTFIO_CLEAR = TX485_EN | ISO_OUT1BIT | ISO_OUT2BIT;
	*pPORTFIO_INEN = ISO_INBIT;

	/* Port G configuration:
	 * PG0-7:  PPI_DATA
	 * PG10:   Camera reset (0=reset)
	 * PG12:   Decoder reset (0=reset)
	 * PG14:   Exposure (snapshot control)
	 * PG15:   Camera/decoder select (1=decoder)
	 */
	stmp = *pPORTG_FER;
	*pPORTG_FER = 0x00ff;
	*pPORTG_FER = 0x00ff;
	*pPORTGIO_DIR =
		CAMERA_RESET_BIT | DECODER_RESET_BIT | EXPOSURE_BIT | AB_SELECT_BIT;
	DECODER_RESET_0();
	DECODER_RESET_1();
	CAMERA_SELECT();

#elif HARDWARE_IS_REVB

	/* Port F configuration:
	 * PF0:  UART0_TX
	 * PF1:  UART0_RX
	 * PF2:  UART1_TX
	 * PF3:  UART1_RX
	 * PF4:  LED DS2 Green Bit
	 * PF5:  UART1 TX_ENABLE (RS485)
	 * PF6:  LED DS2 Red Bit
	 * PF7:  Isolated output (relay A)
	 * PF8:  PPI_FS2
	 * PF9:  PPI_FS1
	 * PF10: SPI Flash Chip Select
	 * PF11: SPI Output
	 * PF12: SPI Input
	 * PF13: SPI Clock
	 * PF14: LED DS3 Yellow
	 * PF15: PPI_CLK
	 */
	stmp = *pPORTF_FER;
	*pPORTF_FER = 0xbf0f;	/* Set the bits that are NOT used as GPIO */
	*pPORTF_FER = 0xbf0f;
	*pPORTFIO_DIR = LED_BITMASK | ISO_OUT2BIT | TX485_EN;
	*pPORTFIO_CLEAR = TX485_EN | ISO_OUT2BIT;

	/* Port G configuration:
	 * PG0-7:  PPI_DATA
	 * PG10:   Camera reset (0=reset)
	 * PG11:   Isolated output (relay B)
	 * PG15:   Snapshot control for camera
	 */
	stmp = *pPORTG_FER;
	*pPORTG_FER = 0x00ff; 	/* Set the bits that are NOT used as GPIO */
	*pPORTG_FER = 0x00ff;
	*pPORTGIO_DIR = CAMERA_RESET_BIT | ISO_OUT1BIT | EXPOSURE_BIT;
	*pPORTGIO_INEN = ISO_INBIT;

	/* Initialize SPI interface:
 	 * The AT25DF321 runs at 70MHz max, so referring to the equation
	 * of figure 10-11 (BF537 HW Reference Manual),
	 * 	70000000 = SYSCLKFREQ/(2*SPI_BAUD)
	 *  and...
	 *    SPI_BAUD = SYSCLKFREQ/(70000000*2)
	*pSPI_BAUD = SYSCLKFREQ/(70000000*2);
	 */

#endif

	CAMERA_RESET_0();
	CAMERA_RESET_1();
	EXPOSURE_1();

	/* Port H configuration:
	 */
	stmp = *pPORTH_FER;
	*pPORTH_FER = 0xffff;
	*pPORTH_FER = 0xffff;

	/* Enable the RTC pre-Scaler:
	 * (the BFIN RTC is not used on this target)
	*pRTC_PREN = 1;
	 */
}

void
icache_off(void)
{
	int i;
	volatile unsigned long *icplb;

	/* Disable I-cache...
	 */
	*pIMEM_CONTROL = 0x00000000;
	asm("ssync;");

	icplb = pICPLB_DATA0;
	for(i=0;i<16;i++) {
		*icplb++ = 0;
		asm("csync;");
	}

	asm("ssync;");
}

void
dcache_off(void)
{
	int i;
	volatile unsigned long *dcplb;

	/* Disable I-cache...
	 */
	*pDMEM_CONTROL = 0x00000000;
	asm("ssync;");

	dcplb = pDCPLB_DATA0;
	for(i=0;i<16;i++) {
		*dcplb++ = 0;
		asm("csync;");
	}

	asm("ssync;");
}

/* bootinit(), ramtstinit() & braminit():
 * One of these functions is called for each of the three different
 * builds created for the BF537.  Refer to reset.S.
 */
void
bootinit(void)
{
}

void
ramtstinit(void)
{
}

void
braminit(void)
{
#if 0
	extern void icache_off(void);

	icache_off();

	/* Enable I-cache for the top 1Mg of SDRAM used by uMon
	 */
	*pICPLB_DATA0 = 0x00021105;
	*pICPLB_ADDR0 = (void *)0x03f00000;
	*pIMEM_CONTROL = 0x00000007;
	asm("ssync;");
#endif
}

