#include <stdint.h>
#include "config.h"
#include "stddefs.h"
#include "genlib.h"
#include "cache.h"
#include "warmstart.h"
#include "cpu.h"
#include "cpuio.h"
#include "timer.h"
#include "cdefBF537.h"
#include "date.h"
#include "i2c.h"
#include "portcmd.h"
#include "cli.h"
#include "spif.h"
#include "spifmap.h"

#ifdef DMA_UART_RCV
#define UBUFSIZ CACHE_LNSZ
uint8_t ubuf[CACHE_LNSZ*3];
uint8_t *ubuf0, *ubuf1;
uint8_t *uptr0, *uptr1;
uint8_t *uend0, *uend1;
#endif

int	poll485(void);
int delay485;


/* devInit():
 * Initialize console...
 */
void static
uartInit(ulong base, int baud)
{
	ushort tmp;

	*(vushort *)(base + GCTL) = 1;		/* Enable UART clocks */
	*(vushort *)(base + MCR) = 0;
	*(vushort *)(base + LCR) = 0x03;	/* no parity, 8-bit char, 1 stopbit */
	tmp = *(vushort *)(base + LSR);		/* clear LSR */
	*(vushort *)(base + IER) = 0;		/* no ints */
	*(vushort *)(base + SCR) = 0;		/* no ints */
	ConsoleBaudSet(baud);

#ifdef DMA_UART_RCV
	if (base == UART0_BASE) {
		/* Init DMA8 (UART0 RCV):
		 */
		*pUART0_IER = 0;
		*pDMA8_CONFIG = 0;
		*pDMA8_START_ADDR = ubuf0;
		*pDMA8_CURR_ADDR = ubuf0;
		*pDMA8_X_COUNT = UBUFSIZ;
		*pDMA8_X_MODIFY = 1;
		*pDMA8_CURR_X_COUNT = 0;
		*pDMA8_CONFIG = DMAEN | WNR | WDSIZE_8 | FLOW_AUTO;
		*pUART0_IER = ERBFI;
		uptr0 = ubuf0;
		uend0 = uptr0+UBUFSIZ;
	}
	if (base == UART1_BASE) {
		/* Init DMA10 (UART1 RCV):
		 */
		*pUART1_IER = 0;
		*pDMA10_CONFIG = 0;
		*pDMA10_START_ADDR = ubuf1;
		*pDMA10_CURR_ADDR = ubuf1;
		*pDMA10_X_COUNT = UBUFSIZ;
		*pDMA10_X_MODIFY = 1;
		*pDMA10_CURR_X_COUNT = 0;
		*pDMA10_CONFIG = DMAEN | WNR | WDSIZE_8 | FLOW_AUTO;
		*pUART1_IER = ERBFI;
		uptr1 = ubuf1;
		uend1 = uptr1+UBUFSIZ;
	}
#endif
}

int static
uartBaudSet(ulong base, int baud)
{
	unsigned short	lctl, hi, lo;

	lo = SYSCLKFREQ/(baud*16);
	hi = (lo & 0xff00) >> 8;
	lo &= 0x00ff;

	lctl = *(vushort *)(base + LCR);	/* Save linectl reg */
	*(vushort *)(base + LCR) = DLAB;
	*(vushort *)(base + DLL) = lo;		/* Set baud divisor */
	*(vushort *)(base + DLH) = hi;
	*(vushort *)(base + LCR) = lctl;	/* Restore linectl reg */
	return(0);
}

void
devInit(int baud)
{
#ifdef DMA_UART_RCV
	/* Align the start of each UART's DMA buffer to be on a
	 * cache-line boundary...
	 */
	ubuf0 = ubuf;
	while(((long)ubuf0 & (CACHE_LNSZ-1)) != 0)
		ubuf0++;
	ubuf1 = ubuf0+CACHE_LNSZ;
	//printf("0x%lx 0x%lx 0x%lx\n",(long)ubuf,(long)ubuf0,(long)ubuf1);
#endif
	uartInit(UART0_BASE,baud);
	uartInit(UART1_BASE,baud);
}

/* ConsoleBaudSet():
 * Change baud rate to that of 'baud'.
 */
int
ConsoleBaudSet(int baud)
{
	uartBaudSet(UART0_BASE,baud);
	uartBaudSet(UART1_BASE,baud);
	switch(baud) {
		case 115200:
			delay485 = 1;
			break;
		case 57600:
			delay485 = 2;
			break;
		case 38400:
			delay485 = 3;
			break;
		case 19200:
			delay485 = 5;
			break;
		default:
		case 9600:
			delay485 = 10;
			break;
	}
	return(0);
}

/* target_console_empty():
 * Returns 1 if there are no characters waiting to
 * be put out on the UART; else return 0 indicating that the UART
 * is still busy outputting characters from its FIFO.
 */
int
target_console_empty(void)
{
	if (*(ushort *)CONSOLE(LSR) & TEMT)
		return(1);
	return(0);
}

/* target_putchar():
 * When buffer has space available, load the incoming character
 * into the UART.
 */
int
target_putchar(char c)
{
    /* Wait for transmit ready bit */
	while(!(*(vushort *)CONSOLE(LSR) & THRE));

	*(vushort *)CONSOLE(THR) = (ushort)c;

    return((int)c);
}

/* target_gotachar():
 * Return 0 if no char is avaialable at UART rcv fifo; else 1.
 * Do NOT pull character out of fifo, just return status. 
 */
int
target_gotachar(void)
{
#if INCLUDE_BLINKLED
	static uint8_t ledstate;
	static struct elapsed_tmr tmr;

	if (getenv("NOBLINK")) {
		STATLED_OFF();
	}
	else {
		switch(ledstate) {
			case 0:
				startElapsedTimer(&tmr,500);
				ledstate = 1;
				STATLED_ON();
				break;
			case 1:
				if(msecElapsed(&tmr)) {
					STATLED_OFF();
					ledstate = 2;
					startElapsedTimer(&tmr,500);
				}
				break;
			case 2:
				if(msecElapsed(&tmr)) {
					STATLED_ON();
					ledstate = 1;
					startElapsedTimer(&tmr,500);
				}
				break;
		}
	}
#endif

	if (getenv("485ADD"))
		poll485();

#ifdef DMA_UART_RCV
	if (*pDMA8_CURR_ADDR != uptr0)
		return(1);
#else
	if (*(vushort *)CONSOLE(LSR) & DR)
		return(1);
#endif
	return(0);
} 

/* target_getchar():
 * Assume there is a character in the UART's input buffer and just
 * pull it out and return it.
 */
int 
target_getchar(void)
{
#ifdef DMA_UART_RCV
	if (uptr0 == uend0)
		uptr0 = (uint8_t *)ubuf0;

	if (getenv("FLUSHINV"))
		FlushInv((char *)ubuf0);

	return(*uptr0++);
#else
    return((int)*(vushort *)CONSOLE(RBR));
#endif
}

int
rs485_putchar(int c)
{
	extern int rawmode;

	if ((c == '\n') && (rawmode == 0))
		rs485_putchar('\r');

	*pPORTFIO_SET = TX485_EN;
	while(!(*(vushort *)RS485(LSR) & THRE));
	*(vushort *)RS485(THR) = (ushort)c;
	monDelay(delay485);
	*pPORTFIO_CLEAR = TX485_EN;

    return((int)c);
}

int
rs485_gotachar(void)
{
#ifdef DMA_UART_RCV
	if (*pDMA10_CURR_ADDR != uptr1)
		return(1);
#else
	if (*(vushort *)RS485(LSR) & DR)
		return(1);
#endif
    return(0);
}

int 
rs485_getchar(void)
{
	while(!rs485_gotachar());

#ifdef DMA_UART_RCV
	if (uptr1 == uend1)
		uptr1 = (uint8_t *)ubuf1;

	if (getenv("FLUSHINV"))
		FlushInv((char *)ubuf1);

	return((int)*uptr1++);
#else
    return((int)*(vushort *)RS485(RBR));
#endif
}

int
rs485_putstr(char *string)
{
	int tot = 0;

	while(*string) {
		rs485_putchar(*string++);
		tot++;
	}
	return(tot);
}

void
rs485_prompt(void)
{
	rs485_putstr("uMON");
	rs485_putstr(getenv("485ADD"));
	rs485_putchar('>');
}

int
poll485(void)
{
	char *env;
	static int idx;

	if (rs485_gotachar()) {
		int c;
		static char state, addr[4], cmd[64];
		
		c = rs485_getchar();
		switch(state) {
			case 0:
				if (c == '@')
					state = 1;
				break;
			case 1:
				if (c == '@')
					state = 2;
				else
					state = 0;
				break;
			case 2:
				addr[0] = c;
				state = 3;
				break;
			case 3:
				addr[1] = c;
				addr[2] = 0;
				env = getenv("485ADD");
				if ((env)  && !strcmp(addr,env))  {
					rs485_prompt();
					state = 4;
					idx = 0;
				}
				else
					state = 0;
				break;
			case 4:
				if ((idx == 0) && (c == '@'))
					state = 1;
				else if ((c == '\r') || (c == '\n')) {
					rs485_putchar('\n');
					cmd[idx] = 0;
					remoteputchar = rs485_putchar;
					remotegetchar = rs485_getchar;
					remotegotachar = rs485_gotachar;
					docommand(cmd,0);
					remoteputchar = 0;
					remotegetchar = 0;
					remotegotachar = 0;
					rs485_prompt();
					cmd[0] = 0;
					idx = 0;
				}
				else if (c == '\b') {
					if (idx > 0) {
						rs485_putstr("\b \b");
						idx--;
					}
				}
				else {
					if (idx < (sizeof(cmd) - 1)) {
						rs485_putchar(c);
						cmd[idx++] = c;
					}
				}
				break;
			default:
				state = 0;
				break;
		}
		return(1);
	}
	return(0);
}


int
iInvalidateRange(char *start, int size)
{
	long addr, end, imemctrl;


	/* If start and size are zero, then we are to invalidate the entire
	 * i-Cache.  That's done by clearing the IMC bit then re-setting it.
	 */
	if ((start == 0) && (size == 0)) {
		imemctrl = *pIMEM_CONTROL;

		asm("ssync;");
		*pIMEM_CONTROL &= ~IMC;
		asm("csync;");
		*pIMEM_CONTROL = imemctrl;
		asm("csync;");
	}
	else {
		addr = (long)start;
		addr &= ~0x1f;
		end = (long)(start + size);

		for(;addr < end; addr += 32)
			IFlush((char *)addr);
	}
	return(0);
}

int
dFlushRange(char *start, int size)
{
	long addr, end;

	/* TODO:
	 * This needs to support the "start=0,size=0" input to flush
	 * the entire d-cache.
 	 */
	addr = (long)start;
	addr &= ~0x1f;
	end = (long)(start + size);

	for(;addr < end; addr += 32)
		Flush((char *)addr);

	return(0);
}

/* cacheInitForTarget():
 * Establish target specific function pointers and
 * enable i-cache...
 * Refer to $core/cache.c for a description of the function pointers.
 * NOTE:
 * If cache (either I or D or both) is enabled, then it is important
 * that the appropriate cacheflush/invalidate function be established.
 * This is very important because programs (i.e. cpu instructions) are
 * transferred to memory using data memory accesses and could
 * potentially result in cache coherency problems.
 */
void
cacheInitForTarget(void)
{
	extern int icache_off(void);
	extern int dcache_off(void);

	icacheDisable = icache_off;
	dcacheDisable = dcache_off;
	dcacheFlush = dFlushRange;
	icacheInvalidate = iInvalidateRange;
}

/* target_reset():
 * From BF537 programmer's manual...
 * The reset vector is determined by the processor system. It points to the
 * start of the on-chip boot ROM (0xef000000), or to the start of
 * external asynchronous memory (0x20000000), depending on the state of
 * the BMODE pins.  uMon is built to run in Mode 0, which means the CPU
 * starts fetching from location 0x20000000 immediately out of reset.
 */
void
target_reset(void)
{
	flushDcache(0,0);
	disableDcache();
	invalidateIcache(0,0);
	disableIcache();

	/* Use Watchdog to generate reset...
	 */
	*pWDOG_CTL = 0x0ad0;	/* Disable watchdog */
	*pWDOG_CNT = 0x0004;	/* Set a low count value */
	*pWDOG_CTL = 0x0000;	/* Enable watchdog */
	while(1);				/* Wait for the hit */
}

/* If any CPU IO wasn't initialized in reset.S, do it here...
 * This just provides a "C-level" IO init opportunity. 
 */
void
initCPUio(void)
{
#if HARDWARE_IS_REVB
	uchar wbuf[4];

	/* Turn on trickle charger:
	 * Write 0xa5 to register 9 of DS1374.
	 * These lines are equivalent to the command
	 *   "i2c -b write 0xd0 9 0xa5"
	 */
	wbuf[0] = 9;
	wbuf[1] = 0xa5;
	i2cWrite(0,MAXIM_RTC,wbuf,2);
#endif

	/* Shut off all LEDs:
	 */
	DS2_OFF();
	DS3_OFF();
}

char *i2cinfo[] = {
	"Addr      Description",
	"0x42      ADV7173B Multiformat SDTV Video Decoder",
	RM_ADDR "      RAMTRON  Memory",
	"0xB8      MT9V022  Digital Image Sensor",
#if HARDWARE_IS_REVB
	"0xD0      DS1374 Real Time Clock",
#elif HARDWARE_IS_REVA
	RC_ADDR "      RAMTRON  CPU Companion",
#endif
	"",
	"",
	"* Video decoder notes:",
	"  To read a register (or block of registers), use the -w option to",
	"  specify starting address of register to read...",
	"     uMON>i2c -w17 read 0x42 8",
	"  In the above case, register '17' (decimal) is the starting address",
	"  of the register bank that you want to read from, so the output",
	"  would be 8 register values... that of reg17, reg18, etc..."
	"",
	"  The 'write' case uses the -b (burst) option so that the register",
	"  address is included in the write as follows...",
	"     uMON>i2c -b write 0x42 8 0x88",
	"",
	"* Image sensor notes:",
	"  Read 32 registers starting from zero:",
	"     uMON>i2c write 0xb8 0; i2c -b read 0xb8 32",
	"",
	"* Ramtron memory:",
	"  To write, use burst mode (-b) with the first two bytes being the",
	"  start address...",
	"     uMON>i2c -b write " RM_ADDR " 0 0 1 2 3 4 5",
	"  To read, use -w to specify the starting address, and read 'N' bytes",
	"  from that location...",
	"     uMON>i2c -w0,0 read " RM_ADDR " N",
#if HARDWARE_IS_REVA
	"",
	"* Ramtron CPU companion:",
	"  To write, use burst mode (-b) with the first byte being the",
	"  offset of the register to write...",
	"     uMON>i2c -b write " RC_ADDR " 1 0x01",
	"  To read, use -w to specify the starting offset, and read 'N'",
	"  registers starting a the speicifed offset...",
	"     uMON>i2c -w1 read " RC_ADDR " N",
	"  Read all registers with:",
	"     uMON>i2c -w0 read " RC_ADDR " 25",
#elif HARDWARE_IS_REVB
	"",
	"* Maxim DS1374 RTC:",
	"  To write, use burst mode (-b) with the first byte being the",
	"  offset of the register to write...",
	"     uMON>i2c -b write 0xD0 1 0x01",
	"  To read, use -w to specify the starting offset, and read 'N'",
	"  registers starting a the speicifed offset...",
	"     uMON>i2c -w1 read 0xD0 N",
	"  Read all registers with:",
	"     uMON>i2c -w0 read 0xD0 10",
#endif
	"",
	0,
};

int
bfin_i2cshow(int interface)
{
	int i;

	for(i=0; i2cinfo[i]; i++)
		printf("%s\n",i2cinfo[i]);
	return(0);
}

char *spiinfo[] = {
	"Addr      Description",
	"  1       AT25DF321 Serial flash",
	0,
};

int
bfin_spishow(int interface)
{
	int i;

	for(i=0; spiinfo[i]; i++)
		printf("%s\n",spiinfo[i]);
	return(0);
}

void
showBlackfinInfo(int center)
{
	uchar *sno;
	int	(*pfunc)(char *, ...);
	uchar *getSerialNumber(void);

	if (center)
		pfunc = cprintf;
	else
		pfunc = printf;
	pfunc("CPU Version %d\n",*pDSPID & 0x0000ffff);
	pfunc("Bootmode: %d\n",*pSYSCR & 7);
	sno = getSerialNumber();
	if ((sno) && (sno[0] != 0xff))
		pfunc("SNO: %s\n",sno);
}

/* portCmd():
 * Used to allow the application to retrieve the revision of
 * the board (cmd==1).  More commands can be added as needed.
 */
long
portCmd(int cmd, void *arg)
{
	switch(cmd) {
		case GET_HW_REV:
#if HARDWARE_IS_REVA
			return(1);
#elif HARDWARE_IS_REVB
			return(2);
#endif
		default:
			return(-1);
	}
}

uchar *
getSerialNumber(void)
{
	static unsigned char snostr[64];

	if (spifReadBlock(SPIF_SNO_ADDRS_BASE,(char *)snostr,sizeof(snostr)) < 0) {
		printf("getSerialNumber: spifReadBlock error\n");
		return(0);
	}

	if (snostr[0] != 0xff)
		setenv("SERIALNO",(char *)snostr);

	return(snostr);
}

void
putSerialNumber(char *sno)
{
	int rc;
	char buf[64];

	if (spifReadBlock(SPIF_SNO_ADDRS_BASE,buf,sizeof(buf)) < 0) {
		printf("putSerialNumber: spifReadBlock error\n");
		return;
	}
	if (buf[0] != (char)0xff) {
		printf("SNO store abort: SPI block (0x%lx bytes at 0x%lx) not empty\n",
			SPIF_SNO_ADDRS_SIZE, SPIF_SNO_ADDRS_BASE);
		return;
	}

	spifWriteEnable();	
	spifGlobalUnprotect();	
	spifWriteEnable();	
	rc = spifWriteBlock(SPIF_SNO_ADDRS_BASE,sno,strlen(sno)+1);
	spifWriteEnable();	
	spifGlobalProtect();
	spifWriteDisable();	
	if (rc < 0) {
		printf("putSerialNumber: spifWriteBlock error\n");
		return;
	}

	printf("SNO burned into SPI flash\n");
}

char *SnoHelp[] = {
	"Display or modify serial number.",
	"[new serial number]",
	0,
};

int
SnoCmd(int argc,char *argv[])
{
	int 	i, rc;
	uchar	*sno;

	if (argc == 1) {
		sno = getSerialNumber();
		if (sno) {
			printf("Current serial number: ");
			for(i=0;i<64;i++) {
				if ((sno[i] == 0) || (sno[i] == 0xff))
					break;
				putchar(sno[i]);
			}
			printf("\n");
		}
	}
	else if (argc == 2) {
		if (strcmp(argv[1],"erase") == 0) {
			spifWriteEnable();	
			spifGlobalUnprotect();	
			spifWriteEnable();	
			rc = spifBlockErase(SPIF_SNO_ADDRS_SIZE,SPIF_SNO_ADDRS_BASE);
			spifWriteEnable();	
			spifGlobalProtect();
			spifWriteDisable();	
			if (rc < 0)
				return(CMD_FAILURE);
		}
		else {
			putSerialNumber(argv[1]);
		}
	}
	else
		return(CMD_PARAM_ERROR);
	return(CMD_SUCCESS);
}

unsigned long
spifGetTFSSize()
{
	return((unsigned long)SPIF_TFS_SIZE);
}

unsigned long
spifGetTFSBase()
{
	return((unsigned long)SPIF_TFS_BASE);
}
