/* iotest.c:
 * This file consists of a command that can be used to test some of the
 * target IO.
 */
#include <stdint.h>
#include "config.h"
#include "stddefs.h"
#include "cli.h"
#include "genlib.h"
#include "cache.h"
#include "warmstart.h"
#include "cpuio.h"
#include "cdefBF537.h"
#include "date.h"
#include "i2c.h"

void static
iotest_485(void)
{
	int  c, led = 0;

	*pPORTFIO_CLEAR = TX485_EN;

	DS3_OFF();

	printf("Flushing RS485 input...\n");
	while(rs485_gotachar()) {
		if (target_gotachar())
			goto abort;
		rs485_getchar();
	}

	printf("Printing 'x' while waiting for a 'q'...\n");
	printf("(all other input is echoed and followed by '!')\n");
	while(1) {
		if (rs485_gotachar()) {
			c = rs485_getchar();
			rs485_putchar(c);
			rs485_putchar('!');
			if (c == 'q')
				break;
		}
		rs485_putchar('x');
		monDelay(500);
		if (led) {
			led = 0;
#if HARDWARE_IS_REVA
			DS3_NOTGREEN();
#elif HARDWARE_IS_REVB
			DS3_NOTYELLOW();
#endif
		}
		else {
			led = 1;
#if HARDWARE_IS_REVA
			DS3_GREEN();
#elif HARDWARE_IS_REVB
			DS3_YELLOW();
#endif
		}
	}

abort:
	printf("RS485 test terminated\n");
}

void static
iotest_IN(void)
{
	printf("Monitoring state of pin 1 J4...\n");
	printf("(pin1 is toward center of board)\n");
	printf("(default state should be 1)\n");


	while(!target_gotachar()) {
#if HARDWARE_IS_REVA
		if (*pPORTFIO & ISO_INBIT)
#elif HARDWARE_IS_REVB
		if (*pPORTGIO & ISO_INBIT)
#endif
			target_putchar('1');
		else
			target_putchar('0');
		monDelay(300);
	}
	target_getchar();
}

void static
iotest_OUT1(void)
{
	printf("Toggling state of pin 1 J5 every 2 seconds...\n");
	printf("(pin1 is toward center of board)\n");

	while(!target_gotachar()) {
#if HARDWARE_IS_REVA
		*pPORTFIO_SET = ISO_OUT1BIT;
#elif HARDWARE_IS_REVB
		*pPORTGIO_SET = ISO_OUT1BIT;
#endif
		printf("1\n");
		monDelay(1000);
#if HARDWARE_IS_REVA
		*pPORTFIO_CLEAR = ISO_OUT1BIT;
#elif HARDWARE_IS_REVB
		*pPORTGIO_CLEAR = ISO_OUT1BIT;
#endif
		printf("0\n");
		monDelay(1000);
	}
	target_getchar();
}

void static
iotest_OUT2(void)
{
	printf("Toggling state of pin 6 J5 every 2 seconds...\n");
	printf("(pin6 is near edge of board)\n");

	while(!target_gotachar()) {
		*pPORTFIO_SET = ISO_OUT2BIT;
		printf("1\n");
		monDelay(1000);
		*pPORTFIO_CLEAR = ISO_OUT2BIT;
		printf("0\n");
		monDelay(1000);
	}
	target_getchar();
}

char *ioTestHelp[] = {
	"Test system IO",
	"{485 | in | out1 | out2}",
#if INCLUDE_VERBOSEHELP
	"Notes:",
	" 485:   outputs 'x' till a character is received, then loops back",
	" in:    monitors state of pin 1 on J4",
	" out1:  toggles state of pin 1 on J5",
	" out2:  toggles state of pin 6 on J5",
	"",
	"All tests are endless loop terminated by input on console",
#endif
	0,
};

int
ioTestCmd(int argc,char *argv[])
{
	int opt, verbose;

	verbose = 0;
	while((opt=getopt(argc,argv,"v")) != -1) {
		switch(opt) {
		case 'v':
			verbose = 1;
			break;
		default:
			return(CMD_PARAM_ERROR);
		}
	}
	if (argc != optind+1)
		return(CMD_PARAM_ERROR);

	if (!strcmp(argv[1],"485"))
		iotest_485();
	else if (!strcmp(argv[1],"in"))
		iotest_IN();
	else if (!strcmp(argv[1],"out1"))
		iotest_OUT1();
	else if (!strcmp(argv[1],"out2"))
		iotest_OUT2();
	else
		return(CMD_PARAM_ERROR);

	printf("\n");
	return(CMD_SUCCESS);
}
