/* reset.S:
 * Basic startup code used for Blackfin.
 * This file is used for three different builds:
 * 1. The flash-based image that pumps the bram image to memory and 
 *    jumps into it (-D BOOT_BUILD).
 * 2. The ram-based image that is pumped by the flash-based image
 *    (-D BRAM_BUILD).
 * 3. The ram-based image that is used for test and is loaded into
 *	  ram by TFTP (-D RAMTST_BUILD).
 */
#include "config.h"
#include "warmstart.h"
#include "def_LPBlackfin.h"

#ifdef BOOT_BUILD
#undef MONSTACKSIZE
#define MONSTACKSIZE 512
	.comm	_MonStack,MONSTACKSIZE
#else
	.extern _MonStack
#endif
	.extern _start, _cstart, _moncom
	.extern _cpuinit, _bootinit, _braminit, _ramtstinit
	.global	_coldstart, _warmstart
	.global	_intsoff, _intsrestore, _target_timer
	.global	_Flush, _IFlush, _FlushInv, _PreFetch
	.global	_getRETE, _getRETN, _getRETI, _getRETX
	.global _moncomptr, _etheraddr, _alt_tfsdevtbl_base
	.global _bfin_cycles_lo, _bfin_cycles_hi

/* If BOOT_BUILD is set, then this code should be placed
 * at 0x20000000 in the memory map.
 */
_coldstart:
	R0 = INITIALIZE;
	jump	_morestart

#ifndef BOOT_BUILD

	.balign 0x4
_moncomptr:
    .long   _moncom

#else
	.balign 0x10
_etheraddr:
	.byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
	.byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
	.byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff

	.balign	0x10
_alt_tfsdevtbl_base:
    .byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    .byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    .byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    .byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    .byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    .byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    .byte 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff

#endif

_morestart:
	/* Clear all DAG registers:
	 */
	R1 = 0
	I0 = R1
	I1 = R1
	I2 = R1
	I3 = R1
	L0 = R1
	L1 = R1
	L2 = R1
	L3 = R1
	B0 = R1
	B1 = R1
	B2 = R1
	B3 = R1
	M0 = R1
	M1 = R1
	M2 = R1
	M3 = R1 

	LC0 = R1
	LC1 = R1

	/* Enable cycle counter:
	 */
	R1 = SYSCFG		
	R2 = 2
	R3 = R1 | R2
	SYSCFG = R3

	/* This next block of code is shamelessly taken from the Blackfin
	 * programming reference as the means of staying in supervisor mode
	 * when coming out of reset.
	 */
	P0.L = (EVT15 & 0xffff);
	P0.H = ((EVT15 >> 16) & 0xffff);
	P1.L = _warmstart;
	P1.H = _warmstart;
	[P0] = P1;
	P0.L = (IMASK & 0xffff);
	P0.H = ((IMASK >> 16) & 0xffff);
	R2 = [P0];
	R1.L = EVT_IVG15 & 0xffff;
	R2 = R2 | R1;
	[P0] = R2;
	RAISE 15;
	P0.L = wait_here;
	P0.H = wait_here;
	RETI = P0;
	RTI;
wait_here:
	jump wait_here;

_warmstart:
	R5 = R0;
	sp.l = (0xff803ff0 & 0xffff)
	sp.h = (0xff803ff0 >> 16)
	call _cpuinit

#ifdef BOOT_BUILD
	call _bootinit
#endif
#ifdef BRAM_BUILD
	call _braminit
#endif
#ifdef RAMTST_BUILD
	call _ramtstinit
#endif

_GoToC:
	R0 = R5;	/* R5 contains the param passed to warmstart */
	sp.l = _MonStack+MONSTACKSIZE - 4
	sp.h = _MonStack+MONSTACKSIZE - 4
#ifdef BOOT_BUILD
	jump.l _cstart
#else
	jump.l _start
#endif


_getRETN:
	R0 = RETN;
	RTS;

_getRETE:
	R0 = RETE;
	RTS;

_getRETI:
	R0 = RETI;
	RTS;

_getRETX:
	R0 = RETX;
	RTS;

_intsoff:
	CLI R0
	RTS

_intsrestore:
	STI R0
	RTS

_target_timer:
	R0 = CYCLES;
	RTS

_IFlush:
	[--sp] = p0
	p0 = r0
	iflush [p0]
	p0 = [sp++]
	rts

_Flush:
	[--sp] = p0
	p0 = r0
	flush [p0]
	p0 = [sp++]
	rts

_FlushInv:
	[--sp] = p0
	p0 = r0
	flushinv [p0]
	p0 = [sp++]
	rts
	
_PreFetch:
	[--sp] = p0
	p0 = r0
	prefetch [p0]
	p0 = [sp++]
	rts
	

#if 0
/* Example functions that can be called from 'C':
 * R0 is the return value.
 * R0 is incoming Arg0
 * R1 is incoming Arg1
 * R2 is incoming Arg2
 */
	.global _return12345678
	.global _returnARG0
	.global _returnARG1
	.global _returnARG2

_return12345678:
	R0.H = 0x1234;
	R0.L = 0x5678;
	RTS

_returnARG0:
	RTS

_returnARG1:
	R0 = R1;
	RTS

_returnARG2:
	R0 = R2;
	RTS
#endif

