//==========================================================================
//
// mc9328mx21.h
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Contributors: Luis Torrico, Cogent Computer Systems, Inc.
// Date:         09/18/2005
// Description:  This file contains register base addresses and offsets
//				 and access macros for the MC9328MX21 on-chip peripherals
//				 This was copied from the mc9328mxl.h and peripherals not
//				 used by UMON have not been tested (and may not be defined).
//			     Use these defines with caution!!
//

#include "bits.h"

//---------------------------------------
// AIPI1 - Arm Peripheral Interface 1
#define AIPI1_BASE_ADD		0x10000000
#define AIPI2_BASE_ADD		0x10020000
#define AIPI1_BASE(_x_)		*(vulong *)(AIPI1_BASE_ADD + 0x000 + _x_)
#define AIPI2_BASE(_x_)		*(vulong *)(AIPI2_BASE_ADD + 0x000 + _x_)
#define AIPI_PSR0 			0x00 	// Peripheral Size Register 0
#define AIPI_PSR1 			0x04 	// Peripheral Size Register 1
#define AIPI_PAR 			0x08 	// Peripheral Access Register

//---------------------------------------
// DMAC - Direct Memory Access Controller
#define DMAC_BASE_ADD		0x10001000
#define DMAC0_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x080 + _x_)
#define DMAC1_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x0C0 + _x_)
#define DMAC2_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x100 + _x_)
#define DMAC3_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x140 + _x_)
#define DMAC4_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x180 + _x_)
#define DMAC5_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x1C0 + _x_)
#define DMAC6_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x200 + _x_)
#define DMAC7_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x240 + _x_)
#define DMAC8_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x280 + _x_)
#define DMAC9_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x2C0 + _x_)
#define DMAC10_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x300 + _x_)
#define DMAC11_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x340 + _x_)
#define DMAC12_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x380 + _x_)
#define DMAC13_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x3C0 + _x_)
#define DMAC14_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x400 + _x_)
#define DMAC15_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x440 + _x_)
#define DMAC_SAR 			0x00 	// Source Address Register
#define DMAC_DAR 			0x04 	// Destination Address Register
#define DMAC_CNTR 			0x08 	// Count Register
#define DMAC_CR 			0x0C 	// Control Register
#define DMAC_RSSR 			0x10 	// Request Source Select Register
#define DMAC_BLR 			0x14 	// Burst Length Register
#define DMAC_RTOR 			0x18 	// Request Time-Out Register
#define DMAC_BUCR 			0x18 	// Bus Utilization Control Register
#define DMAC_COUNTR 		0x1C 	// Counter Register

//---------------------------------------
// WDOG - Watchdog Timer
#define WDOG_BASE_ADD		0x10002000
#define WDOG_REG(_x_)		*(vulong *)(WDOG_BASE_ADD + _x_)
#define WDOG_CR 			0x00 	// Control Register
#define WDOG_SR 			0x02 	// Service Register
#define WDOG_STR 			0x04 	// Reset Status Register

//---------------------------------------
// GPT - General Purpose Timers
#define GPT1_BASE_ADD		0x10003000
#define GPT2_BASE_ADD		0x10004000
#define GPT3_BASE_ADD		0x10005000
#define GPT1_REG(_x_)		*(vulong *)(GPT1_BASE_ADD + _x_)
#define GPT2_REG(_x_)		*(vulong *)(GPT2_BASE_ADD + _x_)
#define GPT3_REG(_x_)		*(vulong *)(GPT3_BASE_ADD + _x_)
#define GPT_CTL 			0x00 	// Control Register
#define GPT_PRE 			0x04 	// Prescaler Register
#define GPT_CMP 			0x08 	// Compare Register
#define GPT_CR 				0x0C 	// Capture Register
#define GPT_CN 				0x10 	// Counter Register
#define GPT_STAT 			0x14 	// Status Register

// ------------------------------------------
// PWM - Pulse Width Modulator
#define PWM_BASE_ADD		0x10006000
#define PWM_REG(_x_)		*(vulong *)(PWM_BASE_ADD + _x_)
#define PWM_CTLR 			0x00 	// Control Register
#define PWM_STAT 			0x04 	// Sample Register
#define PWM_PERIOD 			0x08 	// Period Register
#define PWM_CNT 			0x0C 	// Counter Register

//---------------------------------------
// RTC - Real Time Clock
#define RTC_BASE_ADD		0x10007000
#define RTC_REG(_x_)		*(vulong *)(RTC_BASE_ADD + _x_)
#define RTC_HOURMIN 		0x00 	// Hours and Minutes Counter Register
#define RTC_SECONDS 		0x04 	// Seconds Counter Register
#define RTC_ALRM_HM 		0x08 	// Hours and Minutes Alarm Register
#define RTC_ALRM_SEC 		0x0C 	// Seconds Alarm Register
#define RTC_RCCTL 			0x10 	// Control Register
#define RTC_RTCISR 			0x14 	// Interrupt Status Register
#define RTC_RTCIENR 		0x18 	// Interrupt Enable Register
#define RTC_STPWCH 			0x1C 	// Stopwatch Minutes Register
#define RTC_DAYR 			0x20 	// Days Counter Register
#define RTC_DAYALARM 		0x24 	// Day Alarm Register

//---------------------------------------
// LCDC - LCD Controller
// additional LCDC defines are in mc9328mx21_lcd.h
#define LCDC_BASE_ADD		0x10021000
#define LCDC_REG(_x_)		*(vulong *)(LCDC_BASE_ADD + _x_)
#define LCDC_MAP(_x_)		*(vulong *)(LCDC_BASE_ADD + 0x800 + _x_)

//---------------------------------------
// UARTS
// additional UART defines are in mc9328mx21_uart.h
#define UART1_BASE_ADD		0x1000A000
#define UART2_BASE_ADD		0x1000B000
#define UART3_BASE_ADD		0x1000C000
#define UART4_BASE_ADD		0x1000D000
#define UART1_REG(_x_)		*(vulong *)(UART1_BASE_ADD + _x_)
#define UART2_REG(_x_)		*(vulong *)(UART2_BASE_ADD + _x_)
#define UART3_REG(_x_)		*(vulong *)(UART3_BASE_ADD + _x_)
#define UART4_REG(_x_)		*(vulong *)(UART4_BASE_ADD + _x_)

//---------------------------------------
// SPI -  Serial Peripheral Interface
#define SPI1_BASE_ADD		0x1000E000
#define SPI2_BASE_ADD		0x1000F000
#define SPI3_BASE_ADD		0x10017000
#define SPI1_REG(_x_)		*(vulong *)(SPI1_BASE_ADD + _x_)
#define SPI2_REG(_x_)		*(vulong *)(SPI2_BASE_ADD + _x_)
#define SPI3_REG(_x_)		*(vulong *)(SPI3_BASE_ADD + _x_)
#define SPI_RXD 			0x00 	// Receive Data Register
#define SPI_TXD 			0x04 	// Transmit Data Register
#define SPI_CTRL 			0x08 	// Control Register
#define SPI_INT 			0x0C 	// Interrupt Control/Status Register
#define SPI_TEST 			0x10 	// Test Register
#define SPI_PERIOD 			0x14 	// Sample Period Control Register
#define SPI_DMA 			0x18 	// DMA Register
#define SPI_RESET 			0x1C 	// Soft Reset Register

// ------------------------------------------
// SSI - Synchronous Serial Interface
#define SSI1_BASE_ADD		0x10010000
#define SSI2_BASE_ADD		0x10011000
#define SSI1_REG(_x_)		*(vulong *)(SSI1_BASE_ADD + _x_)
#define SSI2_REG(_x_)		*(vulong *)(SSI2_BASE_ADD + _x_)
#define SSI_TXD0 			0x00 	// Transmit Data Register
#define SSI_TXD1 			0x04 	// Transmit Data Register
#define SSI_RXD0 			0x08 	// Receive Data Register
#define SSI_RXD1 			0x0C 	// Receive Data Register
#define SSI_CR	 			0x10 	// Control Register
#define SSI_ISR 			0x14 	// Interrupt Status Register
#define SSI_IER 			0x18 	// Interrupt Enable Register
#define SSI_TCR 			0x1C 	// Transmit Configuration Register
#define SSI_RCR 			0x20 	// Receive Configuration Register
#define SSI_TCCR 			0x24 	// Transmit Clock Control Register
#define SSI_RCCR 			0x28 	// Receive Clock Control Register
#define SSI_FCSR 			0x2C 	// FIFO Control/Status Register
#define SSI_TR	 			0x30 	// Test Register
#define SSI_OR 				0x24 	// Option Register
#define SSI_AC97CR			0x38 	// AC97 Control Register
#define SSI_AC97CMDAR		0x3C 	// AC97 Command Address Register
#define SSI_AC97CMDDR		0x40 	// AC97 Command Data Register
#define SSI_AC97TR			0x44 	// AC97 Tag Register
#define SSI_TTSR 			0x48 	// Transmit Time Slot Mask Register
#define SSI_RTSR 			0x4C 	// Receive Time Slot Mask Register

// ------------------------------------------
// I2C - Two-Wire Serial I/O
#define I2C_BASE_ADD		0x10012000
#define I2C_REG(_x_)		*(vulong *)(I2C_BASE_ADD + _x_)
#define I2C_ADR 			0x00 	// Address Register
#define I2C_FDR 			0x04 	// Frequency Divider Register
#define I2C_CR 				0x08 	// Control Register
#define I2C_SR 				0x0C 	// Status Register
#define I2C_DR 				0x10 	// Data I/O Register

// ------------------------------------------
// SDHC - Secure-Digital I/O Host Controller (also supports MMC mode)
#define SDHC1_BASE_ADD		0x10013000
#define SDHC2_BASE_ADD		0x10014000
#define SDHC1_REG(_x_)		*(vulong *)(SDIO_BASE_ADD + _x_)
#define SDHC2_REG(_x_)		*(vulong *)(SDIO2_BASE_ADD + _x_)
#define SDHC_CLK_CTRL		0x00 	// Clock Control Register
#define SDHC_STAT 			0x04 	// Status Register
#define SDHC_CLK_RATE 		0x08 	// Clock Rate Register
#define SDHC_CD_CTRL		0x0C 	// Command and Data Control Register
#define SDHC_RES_TO 		0x10 	// Response Time Out Register
#define SDHC_READ_TO 		0x14 	// Read Time Out Register
#define SDHC_BLK_LEN 		0x18 	// Block Length Register
#define SDHC_NOB 			0x1C 	// Number of Blocks Register
#define SDHC_REV_NO 		0x20 	// Revision Number Register
#define SDHC_INT_MASK 		0x24 	// Interrupt Mask Register
#define SDHC_CMD 			0x28 	// Command Number Register
#define SDHC_ARGH	 		0x2C 	// Higher Argument Register
#define SDHC_ARGL	 		0x30 	// Lower Argument Register
#define SDHC_RES_FIFO		0x34 	// Response FIFO Register
#define SDHC_BUF			0x38 	// Buffer Access Register

// ------------------------------------------
// GPIO - General Purpose I/O
#define GPIO_BASE_ADD		0x10015000
#define GPIO_PMASK 			0x10056000 	// GPIO Port Interrupt Mask for all ports
#define GPIOA_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x000 + _x_)
#define GPIOB_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x100 + _x_)
#define GPIOC_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x200 + _x_)
#define GPIOD_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x300 + _x_)
#define GPIOE_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x400 + _x_)
#define GPIOF_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x500 + _x_)
#define GPIO_DDIR 			0x00 	// Data Direction Register
#define GPIO_OCR1 			0x04 	// Output Configuration Register 1
#define GPIO_OCR2 			0x08 	// Output Configuration Register 2
#define GPIO_ICONFA1 		0x0C 	// Input Configuration Register A1
#define GPIO_ICONFA2 		0x10 	// Input Configuration Register A2
#define GPIO_ICONFB1 		0x14 	// Input Configuration Register B1
#define GPIO_ICONFB2 		0x18 	// Input Configuration Register B2
#define GPIO_DR 			0x1C 	// Data Register
#define GPIO_GIUS 			0x20 	// GPIO In Use Register
#define GPIO_SSR 			0x24 	// Sample Status Register
#define GPIO_ICR1 			0x28 	// Interrupt Configuration Register 1
#define GPIO_ICR2 			0x2C 	// Interrupt Configuration Register 2
#define GPIO_IMR 			0x30 	// Interrupt Mask Register
#define GPIO_ISR 			0x34 	// Interrupt Status Register
#define GPIO_GPR 			0x38 	// General Purpose Register
#define GPIO_SWR 			0x3C 	// Software Reset Register
#define GPIO_PUEN 			0x40 	// Pull_Up Enable Register


// ------------------------------------------
// AUDMUX - Audio Multiplexer
#define AUDMUX_BASE_ADD		0x10016000
#define AUDMUX_REG(_x_)		*(vulong *)(AUDMUX_BASE_ADD + _x_)
#define AUDMUX_HPCR1 		0x00  	// Host Port Configuration Register 1
#define AUDMUX_HPCR2 		0x04  	// Host Port Configuration Register 2
#define AUDMUX_HPCR3 		0x08  	// Host Port Configuration Register 3
#define AUDMUX_PPCR1 		0x10  	// Peripheral Port Configuration Register 1
#define AUDMUX_PPCR2 		0x14  	// Peripheral Port Configuration Register 2
#define AUDMUX_PPCR3 		0x1C  	// Peripheral Port Configuration Register 3

// ------------------------------------------
// LCDC - LCD Controller
// Individual bit and register defines are in mc9328mx21_lcd.h
#define LCDC_BASE_ADD		0x10021000
#define LCDC_REG(_x_)		*(vulong *)(LCDC_BASE_ADD + _x_)

// ------------------------------------------
// SLCDC - Smart LCD Controller
#define SLCDC_BASE_ADD		0x10022000
#define SLCDC_REG(_x_)		*(vulong *)(SLCDC_BASE_ADD + _x_)
#define SLCDC_DBA 			0x00	// Data Base Address Register
#define SLCDC_DBS 			0x04	// Data Buffer Size Register
#define SLCDC_CBA 			0x08	// Command Buffer Base Address Register
#define SLCDC_CBS 			0x0C	// Command Buffer Size Register
#define SLCDC_CSTS 			0x10	// Command String Size Register
#define SLCDC_FCFG 			0x14	// FIFO Configuration Register
#define SLCDC_LCFG 			0x18	// Configuration Register
#define SLCDC_LXCFG 		0x1C	// Transfer Configuration Register
#define SLCDC_DCSTAT 		0x20	// DMA Control/Status Register
#define SLCDC_LCC 			0x24	// Clock Configuration Register
#define SLCDC_LWD			0x28	// Write Data Register

// ------------------------------------------
// USBOTG - USB On-The-Go Controller
#define USBOTG_BASE_ADD		0x10024000
#define USBOTG_REG(_x_)		*(vulong *)(USBOTG_BASE_ADD + _x_)

// ------------------------------------------
// USBD - Universal Serial Bus Device Interface
#define USBD_BASE_ADD		0x00212000
#define USBD_REG(_x_)		*(vulong *)(USBD_BASE_ADD + _x_)

// ------------------------------------------
// EMMA - Multimedia Accelerator
#define EMMA_BASE_ADD		0x10026000
#define EMMA_REG(_x_)		*(vulong *)(EMMA_BASE_ADD + _x_)

// ------------------------------------------
// PLL - PLL and Clock Controler
#define PLL_BASE_ADD		0x10027000
#define PLL_REG(_x_)		*(vulong *)(PLL_BASE_ADD + _x_)
#define PLL_CSCR 			0x00 	// Clock Source Control Register
#define PLL_MPCTL0 			0x04 	// MCU PLL Control Register 0
#define PLL_MPCTL1 			0x08 	// MCU PLL and System Clock Control Register 1
#define PLL_SPCTL0 			0x0C 	// System PLL Control Register 0
#define PLL_SPCTL1 			0x10 	// System PLL Control Register 1
#define PLL_OSC26MCTL		0x14 	// Oscillator 26M Register
#define PLL_PCDR0 			0x18 	// Peripheral Clock Divider Register 0
#define PLL_PCDR1 			0x1C 	// Peripheral Clock Divider Register 1
#define PLL_PCCR0 			0x20 	// Peripheral Clock Control Register 0
#define PLL_PCCR1 			0x24 	// Peripheral Clock Control Register 1
#define PLL_CCSR 			0x28 	// Clock Control Status Register
#define PLL_PMCTL			0x2C 	// PMOS Switch Control Register
#define PLL_PMCOUNT			0x30 	// PMOS Switch Counter Register
#define PLL_WKGDCTL			0x34 	// Wakeup Guard Mode Control Register

// ------------------------------------------
// SYS - System Control
#define SYS_BASE_ADD		0x10027800
#define SYS_REG(_x_)		*(vulong *)(SYS_BASE_ADD + _x_)
#define SYS_RSR 			0x00 	// Reset Source Register
#define SYS_SIDR 			0x04 	// Silicon ID Register
#define SYS_GCCR 			0x10 	// Global Clock Control Register
#define SYS_FMCR 			0x14 	// Function Multiplexing Control Register
#define SYS_GPCR 			0x18 	// Global Peripheral Control Register
#define SYS_WBCR 			0x1C 	// Well Bias Control Register
#define SYS_DSCR1 			0x20 	// Driving Strength Control Register 1
#define SYS_DSCR2 			0x24 	// Driving Strength Control Register 2
#define SYS_DSCR3 			0x28 	// Driving Strength Control Register 3
#define SYS_DSCR4 			0x2C 	// Driving Strength Control Register 4
#define SYS_DSCR5 			0x30 	// Driving Strength Control Register 5
#define SYS_DSCR6 			0x34 	// Driving Strength Control Register 6
#define SYS_DSCR7 			0x38 	// Driving Strength Control Register 7
#define SYS_DSCR8 			0x3C 	// Driving Strength Control Register 8
#define SYS_DSCR9 			0x40 	// Driving Strength Control Register 9
#define SYS_DSCR10 			0x44 	// Driving Strength Control Register 10
#define SYS_DSCR11 			0x48 	// Driving Strength Control Register 11
#define SYS_DSCR12 			0x4C 	// Driving Strength Control Register 12
#define SYS_PCSR 			0x50 	// Priority Control and Select Register

// ------------------------------------------
// FIR - Fast Infrared Interface
#define FIR_BASE_ADD		0x10028000
#define FIR_REG(_x_)		*(vulong *)(FIR_BASE_ADD + _x_)
#define FIR_TCTL 	 		0x00 	// Transmit Control Register
#define FIR_TCNT  	 		0x04 	// Transmit Count Register
#define FIR_RCTL	 		0x08 	// Receive Control Register
#define FIR_TSTAT	 		0x0C 	// Transmit Status Register
#define FIR_RSTAT	 		0x10 	// Receive Status Register
#define FIR_TXF	 			0x14 	// Transmitter FIFO
#define FIR_RXF	 			0x18 	// Receiver FIFO
#define FIR_CTL		 		0x1C 	// Control Register

// ------------------------------------------
// CSI - CMOS Sensor Input
#define CSI_BASE_ADD		0x80000000
#define CSI_REG(_x_)		*(vulong *)(CSI_BASE_ADD + _x_)
#define CSI_CR1 	 		0x00 	// Control Register 1
#define CSI_CR2 	 		0x04 	// Control Register 2
#define CSI_CR3 	 		0x1C 	// Control Register 3
#define CSI_SR 	 			0x08 	// Status Register
#define CSI_STATR  			0x0C 	// Statistic FIFO Register
#define CSI_RXR 	 		0x10 	// Rx FIFO Register
#define CSI_RXCR 	 		0x14 	// Rx Count Register

// ------------------------------------------
// AITC - Advanced Interrupt Controller
#define AITC_BASE_ADD		0x10040000
#define AITC_REG(_x_)		*(vulong *)(AITC_BASE_ADD + _x_)
#define AITC_ICTL 			0x00 	// Interrupt Control Register
#define AITC_NIMASK 		0x04 	// Normal Interrupt Mask Register
#define AITC_IENNUM 		0x08 	// Interrupt Enable Number Register
#define AITC_IDISNUM 		0x0C 	// Interrupt Disable Number Register
#define AITC_IENH 			0x10 	// Interrupt Enable Register High
#define AITC_IENL 			0x14 	// Interrupt Enable Register Low
#define AITC_ITH 			0x18 	// Interrupt Type Register High
#define AITC_ITL 			0x1C 	// Interrupt Type Register Low
#define AITC_NIP7 			0x20 	// Normal Interrupt Priority Level Register 7
#define AITC_NIP6 			0x24 	// Normal Interrupt Priority Level Register 6
#define AITC_NIP5 			0x28 	// Normal Interrupt Priority Level Register 5
#define AITC_NIP4 			0x2C 	// Normal Interrupt Priority Level Register 4
#define AITC_NIP3 			0x30 	// Normal Interrupt Priority Level Register 3
#define AITC_NIP2 			0x34 	// Normal Interrupt Priority Level Register 2
#define AITC_NIP1 			0x38 	// Normal Interrupt Priority Level Register 1
#define AITC_NIP0 			0x3C 	// Normal Interrupt Priority Level Register 0
#define AITC_NIVS 			0x40 	// Normal Interrupt Vector and Status Register
#define AITC_FIVS 			0x44 	// Fast Interrupt Vector and Status Register
#define AITC_ISH 			0x48 	// Interrupt Source Register High
#define AITC_ISL 			0x4C 	// Interrupt Source Register Low
#define AITC_IFH 			0x50 	// Interrupt Force Register High
#define AITC_IFL 			0x54 	// Interrupt Force Register Low
#define AITC_NIPH 			0x58 	// Normal Interrupt Pending Register High
#define AITC_NIPL 			0x5C 	// Normal Interrupt Pending Register Low
#define AITC_FIPH 			0x60 	// Fast Interrupt Pending Register High
#define AITC_FIPL 			0x64 	// Fast Interrupt Pending Register Low
// ------------------------------------------
// EIM - External Interface Module
// Individual bit and register defines are in mc9328mx21_mem.h
#define EIM_BASE_ADD		0xDF001000
#define EIM_REG(_x_)		*(vulong *)(EIM_BASE_ADD + _x_)

// ------------------------------------------
// SDRAMC - SDRAM Controller
#define SDRAMC_BASE_ADD		0xDF000000
#define SDRAMC_REG(_x_)		*(vulong *)(SDRAMC_BASE_ADD + _x_)
#define SDRAMC_CTL0 		0x00 	// SDRAM 0 Control Register
#define SDRAMC_CTL1 		0x04 	// SDRAM 1 Control Register
#define SDRAMC_MISC 		0x14 	// Miscellaneous Register
#define SDRAMC_RST 			0x18 	// SDRAM Reset Register

// ------------------------------------------
// AITC - Advanced Interrupt Controller
// may have to change completely for mc9328mx21
#define AITC_BASE_ADD		0x10040000
#define AITC_REG(_x_)		*(vulong *)(AITC_BASE_ADD + _x_)
#define AITC_INTCNTL 		0x00 	// Interrupt Control Register
#define AITC_NIMASK 		0x04 	// Normal Interrupt Mask Register
#define AITC_INTENNUM 		0x08 	// Interrupt Enable Number Register
#define AITC_INTDISNUM 		0x0C 	// Interrupt Disable Number Register
#define AITC_INTENABLEH 	0x10 	// Interrupt Enable Register High
#define AITC_INTENABLEL 	0x14 	// Interrupt Enable Register Low
#define AITC_INTTYPEH 		0x18 	// Interrupt Type Register High
#define AITC_INTTYPEL 		0x1C 	// Interrupt Type Register Low
#define AITC_NIPRIORITY7 	0x20 	// Normal Interrupt Priority Level Register 7
#define AITC_NIPRIORITY6 	0x24 	// Normal Interrupt Priority Level Register 6
#define AITC_NIPRIORITY5 	0x28 	// Normal Interrupt Priority Level Register 5
#define AITC_NIPRIORITY4 	0x2C 	// Normal Interrupt Priority Level Register 4
#define AITC_NIPRIORITY3 	0x30 	// Normal Interrupt Priority Level Register 3
#define AITC_NIPRIORITY2 	0x34 	// Normal Interrupt Priority Level Register 2
#define AITC_NIPRIORITY1 	0x38 	// Normal Interrupt Priority Level Register 1
#define AITC_NIPRIORITY0 	0x3C 	// Normal Interrupt Priority Level Register 0
#define AITC_NIVECSR 		0x40 	// Normal Interrupt Vector and Status Register
#define AITC_FIVECSR 		0x44 	// Fast Interrupt Vector and Status Register
#define AITC_INTSRCH 		0x48 	// Interrupt Source Register High
#define AITC_INTSRCL 		0x4C 	// Interrupt Source Register Low
#define AITC_INTFRCH 		0x50 	// Interrupt Force Register High
#define AITC_INTFRCL 		0x54 	// Interrupt Force Register Low
#define AITC_NIPNDH 		0x58 	// Normal Interrupt Pending Register High
#define AITC_NIPNDL 		0x5C 	// Normal Interrupt Pending Register Low
#define AITC_FIPNDH 		0x60 	// Fast Interrupt Pending Register High
#define AITC_FIPNDL 		0x64 	// Fast Interrupt Pending Register Low

