//==========================================================================
//
// au1500_gpio.h
//
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         07/22/2002
// Description:  Include file for au1500 GPIO 1 and 2
//
//--------------------------------------------------------------------------

#define GPIO1_BASE_ADDRESS	0xb1900000
#define GPIO1(_x_)  		*(vulong *)(GPIO1_BASE_ADDRESS + _x_)
#define GPIO1_TRI 			0x0000 // GPIO1 Tristate (0 = tristates)
#define GPIO1_OUTPUT_SET	0x0108 // GPIO1 Data Output Set, 1 sets the corresponding GPIO1 output
#define GPIO1_OUTPUT_CLR	0x010c // GPIO1 Data Output Clear, 1 clears the corresponding GPIO1 output
#define GPIO1_PINSTATE 		0x0110 // GPIO1 Pin State - Read
#define GPIO1_INPUTEN		0x0110 // GPIO1 Input Enable, write a 0 to enable all GPIO1's as possible inputs
#define GPIO1_PINFUNC		0x002C // GPIO1 Pin Function

#define GPIO2_BASE_ADDRESS	0xb1700000
#define GPIO2(_x_)  		*(vulong *)(GPIO2_BASE_ADDRESS + _x_)
#define GPIO2_DIR 			0x0000 // GPIO2 Direction			
#define GPIO2_OUTPUT 		0x0008 // GPIO2 Data Output
#define GPIO2_PINSTATE 		0x000C // GPIO2 Pin State
#define GPIO2_INTEN			0x0010 // GPIO2 Interrupt Enable
#define GPIO2_ENABLE		0x0014 // GPIO2 Enable

//--------------------------------------------------------------------------
//
// GPIO Port 1 and 2 bit assignments for the CSB250 are as follows.
// Active indicates what level is considered active for that
// signal, if any.  The numbers are used by the various GPIO
// functions
//
// 							GPIO	   Direction	Active	Description
#define GPIO_USER_PB_SW0	0		// Input		Low		User Pushbutton Switch 0
#define GPIO_USER_PB_SW1	1		// Input		Low		User Pushbutton Switch 1
//							2		// Output		N/A		Used for EXTCLK 0
//							3		// Output		N/A		Used for EXTCLK 1
#define GPIO_USER_PB_SW2	4		// Input		Low		User Pushbutton Switch 2
//							5		// Input		High	Used for Mouse Interrupt
//							6		// Input		High	Used for Keyboard Interrupt
//							7		// Input		Low		Used for PHY 1 Interrupt
//							8		// Input		Low		Used for PHY 0 Interrupt
//							9-14	// N/A			N/A		Used for alternate I/O functions
#define GPIO_PCI_RST		200		// Output		Low		PCI Bus Reset	
#define GPIO_USBH_PWR_EN	201		// Output		Low		USB Host Port Power Enable		
#define GPIO_USBH_PWR_ERR	202		// Input		Low		USB Host Port Power Error Flag
#define GPIO_USER_LED0		203		// Output		Low		User LED 0		
#define GPIO_USER_LED1		204		// Output		Low		User LED 1	
#define GPIO_USER_LED2		205		// Output		Low		User LED 2			
#define GPIO_SDA			206		// I/O			N/A		I2C Bus Clock (SCL)				
#define GPIO_SCL			207		// I/O			N/A		I2C Bus Data (SDA)				
#define GPIO_USER_DIP_SW0	208		// Input		Low		User Dip Switch 0, left most (0 = on)
#define GPIO_USER_DIP_SW1	209		// Input		Low		User Dip Switch 0, 
#define GPIO_USER_DIP_SW2	210		// Input		Low		User Dip Switch 0, 
#define GPIO_USER_DIP_SW3	211		// Input		Low		User Dip Switch 0, right most
//							212		// Input		N/A		Unused		
//							213		// Input		N/A		Unused
#define GPIO_PCI_ID0		214		// Output		High	PCI Slot 0 ID Select
#define GPIO_PCI_ID1		215		// Output		High	PCI Slot 1 ID Select

// GPIO1 pin functions
#define GPIO1_PF_CS			BIT16	// GPIO2 output clock select, 0 = EXTCLK0, 1 = 32Khz Clock
#define GPIO1_PF_USB 		BIT15	// USB Port 1 Functionality, 0 = USB Device, 1 = USB Host
#define GPIO1_PF_U3_TXD		BIT14 	// GPIO23 Select, 0 = UART3 TXD, 1 = GPIO
#define GPIO1_PF_SRC		BIT11	// GPI06 Select, 0 = GPIO, 1 = SMROMCKE
#define GPIO1_PF_EX1		BIT10	// GPI03 Select, 0 = GPIO, 1 = EXTCLK1
#define GPIO1_PF_EX0		BIT9	// GPI02 Select, 0 = GPIO, 1 = EXTCLK1/32Khz
#define GPIO1_PF_U3_CTL		BIT7	// GPIO9-14 Select, 0 = GPIO, 1 = UART3 Control (DSR, DTR, CTS, RTS)
#define GPIO1_PF_NI2		BIT4	// GPIO24-28 Select, 0 = Enet Port 2, 1 = GPIO
#define GPIO1_PF_U0_TXD3	BIT3	// GPIO20 Select, 0 = UART0 TXD, 1 = GPIO

#define GPIO2_EN_MR			BIT1	// module reset for GPIO2 block
#define GPIO2_EN_CE			BIT0	// clock enable for GPIO2 block

// macro to convert a GPIO number(200-215) to a bit position (0x0001)
#define GPIO_NUM2BIT(_x_) 	(1 << (_x_ - 200))
