/* csb250_flash.c:
 * The CSB250 has 2 AM29LV642 devices.  Each of these devices contains
 * 2 AM29LV640 devices, each with it's own chipslect; so, think of it
 * as being 2 banks of 2 AM29LV640's.  Each AM29LV640 is an 8Mbyte device;
 * hence, a total of 32Mbyte of flash is onboard.
 * For this case we cannot use the SINGLE_FLASH_DEVICE code in
 * am29lv640d_16x2.c file, so we include a modified version of that
 * code here.  It is basically the same as the SINGLE_FLASH_DEVICE
 * code except that two banks are on board.
 */
#include "config.h"
#include "stddefs.h"
#include "cpu.h"
#include "flash.h"
#include "am29lv640d_16x2.h"

/* FlashNamId[]:
 * Used to correlate between the ID and a string representing the name
 * of the flash device.
 */
struct flashdesc FlashNamId[] = {
	{ AMD29LV640D,	"AMD29LV640D" },
#ifdef FLASHRAM_BASE
	{ FLASHRAM,		"FLASH-RAM" },
#endif
	{ 0, (char *)0 },
};

int SectorSizesLV640D[] = {   /* There are 128 sectors*/ 
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
    0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000, 0x20000,
};

struct sectorinfo sinfo640[2][sizeof(SectorSizesLV640D)/sizeof(int)];

/* FlashInit():
 * Initialize data structures for each bank of flash...
 */
int
FlashInit()
{
	int	i,	snum, bank;
	uchar	*begin;
	struct	flashinfo *fbnk;

	snum = 0;
	FlashCurrentBank = 0;

	/* Copy functions to ram space...
	 * Note that this MUST be done when cache is disabled to assure that
	 * the RAM is occupied by the designated block of code.
	 */
	for(bank=0;bank<2;bank++) {
		fbnk = &FlashBank[bank];
		if (bank == 0)
			fbnk->base = (unsigned char *)FLASH_BANK0_BASE_ADDR;
		else
			fbnk->base = (unsigned char *)FLASH_BANK1_BASE_ADDR;
		fbnk->end = fbnk->base + FLASH_BANK0_SIZE - 1;
		fbnk->sectorcnt = (sizeof(SectorSizesLV640D)/sizeof(int));
		fbnk->width = FLASH_BANK0_WIDTH;
		fbnk->fltype = Am29lv640d_16x2_type;
		fbnk->flerase = Am29lv640d_16x2_erase;
		fbnk->flwrite = Am29lv640d_16x2_write;
		fbnk->flewrite = Am29lv640d_16x2_ewrite;
		fbnk->sectors = sinfo640[bank];
		fbnk->id = flashtype(fbnk);
	
		begin = fbnk->base;
		for(i=0;i<fbnk->sectorcnt;i++,snum++) {
			int	ssize;
	
			ssize = SectorSizesLV640D[i];
			fbnk->sectors[i].snum = snum;
			fbnk->sectors[i].size = ssize;
			fbnk->sectors[i].begin = begin;
			fbnk->sectors[i].end = fbnk->sectors[i].begin + ssize - 1;
			fbnk->sectors[i].protected = 0;
			begin += ssize;
		}
	}

	sectorProtect(FLASH_PROTECT_RANGE,1);

#ifdef FLASHRAM_BASE
	FlashRamInit(snum, FLASHRAM_SECTORCOUNT, &FlashBank[FLASHRAM_BANKNUM],
		sinfoRAM, 0);
#endif

	return(0);
}
