//==========================================================================
//
//      cpu_i2c.h
//
// Author(s):   Michael Kelly - Cogent Computer Systems, Inc.
// Date:        03/30/2002
// Description:	CSB272 - 405GP Single Board IIC Routines 
//
// Modification (els):
//	Extracted from cpu_i2c.c to be a stand-alone header
//	that can be pulled in by csbi2c.c as well as cpu_i2c.c.
//
//==========================================================================

//--------------------------------------------------------------------------
// some 405GP I2C register and bit defines
//
#define I2C_XCTL			*(vulong *)(0xef60050f)	// extended control register
#define I2C_XCTL_SRST		0x01000000	// Soft Reset Bit - must be set 
										// to 1 to use direct control

#define I2C_DCTL			*(vulong *)(0xef600510)	// direct ctrl of IIC bits
#define I2C_DCTL_SDA_OUT	0x08000000	// SDA Out, 0=drive low, 1=tri-state 
#define I2C_DCTL_SCL_OUT	0x04000000	// SCL Out, 0=drive low, 1=tri-state 
#define I2C_DCTL_SDA_IN		0x02000000	// SDA In, Direct Read
#define I2C_DCTL_SCL_IN		0x01000000	// SCL In, Direct Read

//--------------------------------------------------------------------------
// Low level I2C Macros
//
#define I2C_SCL_CLR			I2C_DCTL &= ~(I2C_DCTL_SCL_OUT)
#define I2C_SCL_SET			I2C_DCTL |= (I2C_DCTL_SCL_OUT) 	

#define I2C_SDA_CLR			I2C_DCTL &= ~(I2C_DCTL_SDA_OUT)		
#define I2C_SDA_SET			I2C_DCTL |= (I2C_DCTL_SDA_OUT) 		

#define I2C_SDA_RD			I2C_DCTL & I2C_DCTL_SDA_IN
#define I2C_SCL_RD			I2C_DCTL & I2C_DCTL_SCL_IN

#define I2C_DELAY 			monDelay(1)

//--------------------------------------------------------------------------
// function prototypes
//
ulong i2c_init(void);
ulong i2c_wr_device(uchar dev, uchar reg, uchar data);
ulong i2c_rd_device(uchar dev, uchar reg, uchar *data);
ulong i2c_wr_byte(uchar data);
uchar i2c_rd_byte(void);
void i2c_start(void);
void i2c_stop(void);

extern void udelay(int delay);

extern ulong sed_disp_mode;
