//==========================================================================
//
// lh79520.h
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         02/16/2003
// Description:  This file contains register base addresses and offsets
//				 and access macros for the LH795200 on-chip peripherals
//

#include "bits.h"

//---------------------------------------
// UARTS
// additional UART defines are in lh79520_uart.h
#define UART_BASE			0xfffc0000
#define UART0_REG(_x_)		*(vulong *)(UART_BASE + 0x0000 + _x_)
#define UART1_REG(_x_)		*(vulong *)(UART_BASE + 0x1000 + _x_)
#define UART2_REG(_x_)		*(vulong *)(UART_BASE + 0x2000 + _x_)

//---------------------------------------
// Pulse Width Modulators
#define PWM_BASE			0xfffc3000
#define PWM0_REG(_x_)		*(vulong *)(PWM_BASE + 0x0000 + _x_)
#define PWM1_REG(_x_)		*(vulong *)(PWM_BASE + 0x0020 + _x_)
#define PWM_TC				0x000	// Terminal Count Register
#define PWM_DC				0x004	// Duty Cyle Register
#define PWM_EN				0x008	// Enable Register
#define PWM_INV				0x00C	// Invert Register
#define PWM_SYNC			0x010	// Sync Register

//---------------------------------------
// Timers
#define TIM_BASE			0xfffc4000
#define TIM0_REG(_x_)		*(vulong *)(TIM_BASE + 0x0000 + _x_)
#define TIM1_REG(_x_)		*(vulong *)(TIM_BASE + 0x0020 + _x_)
#define TIM2_REG(_x_)		*(vulong *)(TIM_BASE + 0x1000 + _x_)
#define TIM3_REG(_x_)		*(vulong *)(TIM_BASE + 0x1020 + _x_)
#define TIM_LD				0x000	// Load Register
#define TIM_VAL				0x000	// Value Register
#define TIM_CTL				0x000	// Control Register
#define TIM_CLR				0x000	// Clear Register

//---------------------------------------
// Synchronous Serial Port (SSP)
#define SSP_BASE			0xfffc4000
#define SSP_REG(_x_)		*(vulong *)(SSP_BASE + _x_)
#define SSP_CR0				0x000	// Control Register 0
#define SSP_CR1				0x004	// Control Register 1
#define SSP_DR				0x008	// Data Register
#define SSP_SR				0x00c	// Status Register
#define SSP_CPR				0x010	// Clock Prescale Register
#define SSP_IIR				0x014	// Interrupt ID Register - Read Only
#define SSP_ICR				0x014	// Interrupt Clear Register - Write Only
#define SSP_RXT				0x018	// Receive Timeout Register

//---------------------------------------
// General Purpose I/O
#define GPIO_BASE			0xfffdc000
#define GPIO_G_REG(_x_)		*(vulong *)(GPIO_BASE + 0x0000 + _x_)
#define GPIO_H_REG(_x_)		*(vulong *)(GPIO_BASE + 0x0004 + _x_)
#define GPIO_E_REG(_x_)		*(vulong *)(GPIO_BASE + 0x1000 + _x_)
#define GPIO_F_REG(_x_)		*(vulong *)(GPIO_BASE + 0x1004 + _x_)
#define GPIO_C_REG(_x_)		*(vulong *)(GPIO_BASE + 0x2000 + _x_)
#define GPIO_D_REG(_x_)		*(vulong *)(GPIO_BASE + 0x2004 + _x_)
#define GPIO_A_REG(_x_)		*(vulong *)(GPIO_BASE + 0x3000 + _x_)
#define GPIO_B_REG(_x_)		*(vulong *)(GPIO_BASE + 0x3004 + _x_)
#define GPIO_DATA			0x000	// Data Register
#define GPIO_DDIR			0x008	// Data Direction

//---------------------------------------
// Real Time Clock
#define RTC_BASE			0xfffe0000
#define RTC_REG(_x_)		*(vulong *)(GPIO_BASE + _x_)
#define RTC_DR				0x000	// Data Register
#define RTC_MR				0x004	// Match Register
#define RTC_STAT			0x008	// Interrupt Status Register - Read Only
#define RTC_EOI				0x008	// Interrupt Clear Register - Write Only
#define RTC_CLR				0x00c	// Counter Load Register
#define RTC_CCR				0x010	// Interrupt Control Register

//---------------------------------------
// DMA
#define DMA_BASE			0xfffe1000
#define DMA0_REG(_x_)		*(vulong *)(DMA_BASE + 0x0000 + _x_)
#define DMA1_REG(_x_)		*(vulong *)(DMA_BASE + 0x0040 + _x_)
#define DMA2_REG(_x_)		*(vulong *)(DMA_BASE + 0x0080 + _x_)
#define DMA3_REG(_x_)		*(vulong *)(DMA_BASE + 0x00c0 + _x_)
#define DMA_SRC_HI			0x000	// Source Address Register High
#define DMA_SRC_LO			0x004	// Source Address Register Low
#define DMA_DEST_HI			0x008	// Destination Address Register High
#define DMA_DEST_LO			0x00c	// Destination Address Register Low
#define DMA_MAX				0x010	// Maximum Count Register
#define DMA_CTL				0x014	// Control Register
#define DMA_SRC_HI_C		0x018	// Source Address Register High - Current
#define DMA_SRC_LO_C		0x01c	// Source Address Register Low - Current
#define DMA_DEST_HI_C		0x020	// Destination Address Register High - Current
#define DMA_DEST_LO_C		0x024	// Destination Address Register Low - Current
#define DMA_TCNT			0x028	// Terminal Count Register
// Additional block for overall DMA control functions
#define DMA_CTL_REG(_x_)	*(vulong *)(DMA_BASE + 0x00f0 + _x_)
#define DMA_MASK			0x000	// Interrupt Mask Register
#define DMA_INT				0x004	// Interrupt Clear Register
#define DMA_STAT			0x008	// Status Register

//---------------------------------------
// Reset, Clock and Power Control
#define RCP_BASE			0xfffe2000
#define RCP_REG(_x_)		*(vulong *)(RCP_BASE + _x_)
#define RCP_CTL				0x000	// RCP Control Register
#define RCP_REMAP			0x008	// Address Re-Map Register
#define RCP_SRST			0x00c	// Soft Reset Register
#define RCP_RSTAT			0x010	// Reset Status Register
#define RCP_RSTAT_CRL		0x014	// Reset Status Clear Register
#define RCP_HCLK_PS			0x018	// HCLK Prescale Register
#define RCP_CCLK_PS			0x01c	// CPU Core Clock Prescaler Register
#define RCP_PCLK_CTL		0x024	// Peripheral Clock Control Register
#define RCP_PCLK_CTL2		0x028	// Peripheral Clock Control Register 2
#define RCP_AHB				0x02c	// AHB Clock Control Register
#define RCP_PCLK_SEL		0x030	// Peripheral Clock Select Register
#define RCP_PCLK_SEL2		0x034	// Peripheral Clock Select Register 2
#define RCP_PWM0_PS			0x038	// PWM0 Clock Prescaler Register
#define RCP_PWM1_PS			0x03c	// PWM1 Clock Prescaler Register
#define RCP_LCD_PS			0x040	// LCD Clock Prescaler Register
#define RCP_SSP_PS			0x044	// SSP Clock Prescaler Register
#define RCP_XINT_CFG		0x080	// External Interrupt Configuration Register
#define RCP_XINT_CLR		0x084	// External Interrupt Clear Register
#define RCP_CCLK_CFG		0x088	// Core Clock Configuration Register

//---------------------------------------
// Watchdog Timer
#define WDT_BASE			0xfffe3000
#define WDT_REG(_x_)		*(vulong *)(WDT_BASE + _x_)
#define WTD_CTL				0x000	// Control Register
#define WTD_CNT_RST			0x004	// Counter Reset Register
#define WTD_STAT			0x008	// Status Register
#define WTD_CNT0			0x00c	// Counter Register 0
#define WTD_CNT1			0x010	// Counter Register 1
#define WTD_CNT2			0x014	// Counter Register 2
#define WTD_CNT3			0x018	// Counter Register 3

//---------------------------------------
// HR-TFT TIming Controller
#define HRT_BASE			0xfffe4000
#define HRT_REG(_x_)		*(vulong *)(HRT_BASE + _x_)
#define HRT_SETUP			0x000	// Setup Register
#define HRT_CTL				0x004	// Control Register
#define HRT_TMG1			0x008	// Timing Register 1
#define HRT_TMG2			0x00c	// Timing Register 2

//---------------------------------------
// I/O Pin Multiplexing
#define PIN_BASE			0xfffe5000
#define PIN_REG(_x_)		*(vulong *)(PIN_BASE + _x_)
#define PIN_MEM				0x000	// Memory Pin Multiplex Control Register
#define PIN_LCD				0x004	// LCD Pin Multiplex Control Register
#define PIN_MISC			0x008	// Miscellaneous Pin Multiplex Control Register
#define PIN_DMA				0x00c	// DMA Pin Multiplex Control Register
#define PIN_UART			0x010	// UART Pin Multiplex Control Register
#define PIN_SSP				0x014	// SSP Pin Multiplex Control Register

//---------------------------------------
// Static Memory Controller
#define SMC_BASE			0xffff1000
#define SMC_REG(_x_)		*(vulong *)(SMC_BASE + _x_)

//---------------------------------------
// SDRAM Memory Controller
#define SDRC_BASE			0xffff2000
#define SDRC_REG(_x_)		*(vulong *)(SDRC_BASE + _x_)

//---------------------------------------
// Color LCD Controller
#define LCD_BASE			0xffff4000
#define LCD_REG(_x_)		*(vulong *)(LCD_BASE + _x_)
#define LCD_HOR				0x000	// Horizontal Timing Register
#define LCD_VER				0x004	// Vertical Timing Register
#define LCD_CPC				0x008	// Clock and Polarity Control Register
#define LCD_FB_HI			0x010	// Frame Buffer Base Address Register - High
#define LCD_FB_LO			0x014	// Frame Buffer Base Address Register - Low
#define LCD_IMSC			0x018	// Interrupt Mask Set/Clear Register
#define LCD_PPC				0x01c	// Panel Pixel Control Register
#define LCD_RIS				0x020	// Raw Interrupt Status Register
#define LCD_MIS				0x024	// Masked Interrupt Status Register
#define LCD_FB_HI_C			0x028	// Frame Buffer Current Address Register - High
#define LCD_FB_LO_C			0x02c	// Frame Buffer Current Address Register - Low

//---------------------------------------
// Color LCD Controller - Palette Ram
#define PAL_REG(_x_)		*(vulong *)(LCD_BASE + 0x0200 + _x_)

//---------------------------------------
// Vectored Interrupt Controller
#define VIC_BASE			0xfffff000
#define VIC_REG(_x_)		*(vulong *)(VIC_BASE + _x_)
#define VIC_IRQ_STAT		0x000	// IRQ Interrupt Status Register
#define VIC_FIQ_STAT		0x004	// FIQ Interrupt Status Register
#define VIC_RAW_STAT		0x008	// Raw Interrupt Status Register
#define VIC_SEL				0x00c	// FIQ/IRQ Select Register
#define VIC_IEN				0x010	// Interrupt Enable Status Register - Read Only
#define VIC_IMS				0x010	// Interrupt Mask Set Register - Write Only
#define VIC_IMC				0x014	// Interrupt Mask Clear Register - Write Only
#define VIC_SWI				0x018	// Software Interrupts Status Register - Read Only
#define VIC_SWI_SET			0x018	// Software Interrupts Set Register - Write Only
#define VIC_SWI_CLR			0x01c	// Software Interrupts Clear Register
#define VIC_VEC_CUR			0x000	// Current Interrupt Vector Address Register
#define VIC_VEC_DEF			0x000	// Default Vector Address Register
#define VIC_VEC_ADD0		0x000	// Vector Address Register 0	
#define VIC_VEC_ADD1		0x000	// Vector Address Register 1	
#define VIC_VEC_ADD2		0x000	// Vector Address Register 2	
#define VIC_VEC_ADD3		0x000	// Vector Address Register 3	
#define VIC_VEC_ADD4		0x000	// Vector Address Register 4	
#define VIC_VEC_ADD5		0x000	// Vector Address Register 5	
#define VIC_VEC_ADD6		0x000	// Vector Address Register 6	
#define VIC_VEC_ADD7		0x000	// Vector Address Register 7	
#define VIC_VEC_ADD8		0x000	// Vector Address Register 8	
#define VIC_VEC_ADD9		0x000	// Vector Address Register 9	
#define VIC_VEC_ADD10		0x000	// Vector Address Register 10
#define VIC_VEC_ADD11		0x000	// Vector Address Register 11
#define VIC_VEC_ADD12		0x000	// Vector Address Register 12
#define VIC_VEC_ADD13		0x000	// Vector Address Register 13
#define VIC_VEC_ADD14		0x000	// Vector Address Register 14
#define VIC_VEC_ADD15		0x000	// Vector Address Register 15
#define VIC_VEC_CTL0		0x000	// Vector Control Register 0	
#define VIC_VEC_CTL1		0x000	// Vector Control Register 1	
#define VIC_VEC_CTL2		0x000	// Vector Control Register 2	
#define VIC_VEC_CTL3		0x000	// Vector Control Register 3	
#define VIC_VEC_CTL4		0x000	// Vector Control Register 4	
#define VIC_VEC_CTL5		0x000	// Vector Control Register 5	
#define VIC_VEC_CTL6		0x000	// Vector Control Register 6	
#define VIC_VEC_CTL7		0x000	// Vector Control Register 7	
#define VIC_VEC_CTL8		0x000	// Vector Control Register 8	
#define VIC_VEC_CTL9		0x000	// Vector Control Register 9	
#define VIC_VEC_CTL10		0x000	// Vector Control Register 10
#define VIC_VEC_CTL11		0x000	// Vector Control Register 11
#define VIC_VEC_CTL12		0x000	// Vector Control Register 12
#define VIC_VEC_CTL13		0x000	// Vector Control Register 13
#define VIC_VEC_CTL14		0x000	// Vector Control Register 14
#define VIC_VEC_CTL15		0x000	// Vector Control Register 15
#define VIC_TEST			0x30c	// Interrupt Test Output
