//
// PXA250 LCD Controller Register and Bit Definitions
//
//LCD_HOR - Horizontal Timing Register
#define LCD_HOR_PPL(_x_)		((_x_ & 0x3f) << 2)		// Pixels Per Line = (16 * (PPL - 1))
#define LCD_HOR_HSW(_x_)		((_x_ & 0xff) << 8)		// Horizontal Sync Pulse Width - 1
#define LCD_HOR_HFP(_x_)		((_x_ & 0xff) << 16)	// Horizontal Front Porch - 1
#define LCD_HOR_HBP(_x_)		((_x_ & 0xff) << 24)	// Horizontal Back Porch - 1

//LCD_VER - Vertical Timing Register
#define LCD_VER_PPL(_x_)		((_x_ & 0x1ff) << 0)	// Lines Per Panel - 1
#define LCD_VER_VSW(_x_)		((_x_ & 0x3f) << 10)	// Vertical Sync Pulse Width - 1
#define LCD_VER_VFP(_x_)		((_x_ & 0xff) << 16)	// Vertical Front Porch - 1
#define LCD_VER_VBP(_x_)		((_x_ & 0xff) << 24)	// Vertical Back Porch - 1

//LCD_CPC - Clock and Polarity Control Register
#define LCD_CPC_PCD(_x_)		((_x_ & 0x1ff) << 0)	// Pixel Clock Divisor
#define LCD_CPC_ACB(_x_)		((_x_ & 0x1f) << 6)		// ACBIAS Frequency Divisor
#define LCD_CPC_IVS				BIT11					// 0 = VSYNC High, 1 = VSYNC Low
#define LCD_CPC_IHS				BIT12					// 0 = HSYNC High, 1 = HSYNC Low
#define LCD_CPC_IPS				BIT13					// 0 = LCD Data Out on Rising Edge, 1 = Falling Edge
#define LCD_CPC_IOE				BIT14					// 0 = ENAB High, 1 = ENAB Low (TFT Only)
#define LCD_CPC_CPL(_x_)		((_x_ & 0x1ff) << 16)	// Actual Clocks Per Line
#define LCD_CPC_BCD				BIT26					// 0 = use PCD field, 1 = Bypass Clock Divider

//LCD_IMSC - Interrupt Mask Set/Clear Register
//LCD_RIS - Raw Interrupt Status Register
//LCD_MIS - Masked Interrupt Status Register
#define LCD_INT_FUF				BIT1					// Fifo Underflow
#define LCD_INT_NBU				BIT2					// Next Base Update
#define LCD_INT_VC				BIT3					// Vertical Compare
#define LCD_INT_AME				BIT4					// AHB Master Error

//LCD_PPC - Panel Pixel Control Register
#define LCD_PPC_LCDEN			BIT0					// Enable LCD Logic
#define LCD_PPC_BPP1			(0x0 << 1)				// Bits Per Pixel 
#define LCD_PPC_BPP2			(0x1 << 1)				//  
#define LCD_PPC_BPP4			(0x2 << 1)				//  
#define LCD_PPC_BPP8			(0x3 << 1)				//  
#define LCD_PPC_BPP16			(0x4 << 1)				//  
#define LCD_PPC_BPP24			(0x5 << 1)				//  
#define LCD_PPC_COLOR			0x00					// Display is Color
#define LCD_PPC_BW				BIT4					// Display is Black/White
#define LCD_PPC_PAS				0x00					// Display is Passive
#define LCD_PPC_TFT				BIT5					// Display is TFT
#define LCD_PPC_BW4				0x00					// B/W Display uses 4-bit data bus
#define LCD_PPC_BW8				BIT6					// B/W Display uses 8-bit data bus
#define LCD_PPC_SINGLE			0x00					// Color Display is a Single Panel
#define LCD_PPC_DUAL			BIT7					// Color Display is a Dual Panel 
#define LCD_PPC_RGB				0x00					// RGB - Normal Output
#define LCD_PPC_BGR				BIT8					// BGR - Reversed Output 
#define LCD_PPC_LCD_LITTLE		0x00					// Little Endian Byte Order to the LCD
#define LCD_PPC_LCD_BIGE		BIT9					// Big Endian Byte Order to the LCD
#define LCD_PPC_PIX_LITTLE		0x00					// Little Endian Pixel Packing Order (1, 2 or 4 BPP only)
#define LCD_PPC_PIX_BIGE		BIT10					// Big Endian Byte Pixel Packing Order (1, 2 or 4 BPP only)
#define LCD_PPC_LCD_PWR			BIT11					// LCD Power is On (when LCDEN is true) 
#define LCD_PPC_VCOM_VSYNC		(0x00 << 12)			// Vertical Compare Interrupt at Start of VSYNC
#define LCD_PPC_VCOM_VSBP		(0x01 << 12)			// Vertical Compare Interrupt at Start of Vertical Back Porch
#define LCD_PPC_VCOM_VACT		(0x02 << 12)			// Vertical Compare Interrupt at Start of Vertical Active Area
#define LCD_PPC_VCOM_VSFP		(0x03 << 12)			// Vertical Compare Interrupt at Start of Vertical Front Porch
#define LCD_PPC_			BIT0					//  
#define LCD_PPC_			BIT0					//  
#define LCD_PPC_			BIT0					//  

