/* mstat.c:
    The mstat command is provided as a target-specific command for keeping
    track of various monitor-specific stuff... uart baud rate, malloc stats,
    chip-select configuration, etc...

    General notice:
    This code is part of a boot-monitor package developed as a generic base
    platform for embedded system designs.  As such, it is likely to be
    distributed to various projects beyond the control of the original
    author.  Please notify the author of any enhancements made or bugs found
    so that all may benefit from the changes.  In addition, notification back
    to the author will allow the new user to pick up changes that may have
    been made by other users after this version of the code was distributed.

    Author: Ed Sutter
    email:  esutter@lucent.com
    phone:  908-582-2351
*/
#include "config.h"
#include "cpu.h"
#include "cpuio.h"
#include "genlib.h"
#include "stddefs.h"
#include "arch_ppc.h"

void mstatshow();

char *MstatHelp[] = {
    "Monitor status",
    "-[b:]",
    " -b {baud}  set baud rate",
    0,
};

int
Mstat(int argc,char *argv[])
{
    int opt;

    /* If no args, just dump current status. */
    if (argc == 1) {
        mstatshow();
        return(0);
    }

    while ((opt=getopt(argc,argv,"b:")) != -1) {
	    switch(opt) {
	        case 'b':
	            ConsoleBaudSet((atoi(optarg)));
	            ConsoleBaudEnvSet();            
	            break;
	        default:
	            return(0);
	    }
    }
    if (argc != optind)
        return(-1);
    return(0);
}

void
mstatshow()
{
    extern int monState();

    monHeader(0);
    mstatshowcom();
    printf("Current:\n");
    printf(" SP:   0x%08lx\n",ppcMfgpr1());
    printf(" MSR:  0x%08lx\n",ppcMfmsr());
    printf(" DCCR:   0x%08lx\n",ppcMfdccr());
    printf(" ICCR:   0x%08lx\n",ppcMficcr());
    printf(" EVPR:   0x%08lx\n",ppcMfevpr());
}

