
//=============================================================================
//
//      cpu_gpio.h
//
//      CPU/Board Specific GPIO assignments
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Date:         04/08/2005
// Description:  This file contains the GPIOIO usage for the CSB536FS
//
//
//=============================================================================

// PORT A - Virtual GPIO Bits 0-31
#define PORTA_VBIT      0
// Signal			    Bit		           Dir  Active	Usage
#define	USR_LED1_BIT	BIT1	        // Out	Low		User LED 1 on CPU Module
#define	USR_LED1	    PORTA_VBIT + 1
#define	LCD_BKL_BIT		BIT2	        // Out	High	LCD Backlight Enable
#define	LCD_BKL		    PORTA_VBIT + 2
#define	USR_SW1_BIT		BIT3	        // In	Low		User Switch 1 on CPU Module
#define	USR_SW1		    PORTA_VBIT + 3
#define	USR_SW0_BIT		BIT4	        // In	Low		User Switch 0 on CPU Module
#define	USR_SW0		    PORTA_VBIT + 4
#define	I2C_SDA_BIT		BIT15	        // I/O	NA		I2C Data
#define	I2C_SDA		    PORTA_VBIT + 15
#define	I2C_SCL_BIT		BIT16	        // I/O	NA		I2C Clock
#define	I2C_SCL		    PORTA_VBIT + 16
#define	DTACK_BIT		BIT17	        // In	Low		DTACK - routed via ICONF to AIN
#define	DTACK_SCL	    PORTA_VBIT + 17

// Define initial direction (1 = output) and value
#define PORTA_DDIR      (USR_LED1_BIT | LCD_BKL_BIT)
#define PORTA_DR        (USR_LED1_BIT)
#define PORTA_OCR1      0xffffffff      // all PORTA GPIO's PA17 but are driven by the GPIO Data Register
#define PORTA_OCR2      0xffffffff      // all PORTA GPIO's but PA17 are driven by the GPIO Data Register
#define PORTA_ICR1      0x00000000      // all PORTA GPIO's inputs but PA17 go to the GPIO Sample Status Register
#define PORTA_ICR2      0x00000000      // all PORTA GPIO's inputs but PA17 go to the GPIO Sample Status Register
       
// Define signals that are to be set as GPIO (bit = 1) and define for Primary (0)
// or Secondary (1) use non-GPIO
#define PORTA_GPIUS		(USR_LED1_BIT | LCD_BKL_BIT | USR_SW1_BIT | USR_SW0_BIT | I2C_SDA_BIT | I2C_SCL_BIT | DTACK_BIT)
#define PORTA_GPR       0x0 // no secondary functions

// -----------------------------------------------------------------------------------------------
// PORT B
#define PORTB_VBIT      32
// Signal			    Bit		               Dir	Active	Usage
#define	SD_VEN_BIT	    BIT14	            // In  Low		SD Card Detect
#define	SD_VEN	        PORTB_VBIT + 14
#define	SD_CD_BIT	    BIT15	            // In	Low		SD Card Detect
#define	SD_CD	        PORTB_VBIT + 15
#define	SD_WP_BIT	    BIT16	            // In	High	SD Card Write Protect Switch
#define	SD_WP	        PORTB_VBIT + 16
#define	E_INT_BIT	    BIT17	            // In	High	CS8900a Interrupt
#define	E_INT	        PORTB_VBIT + 17
#define	PIRQ_BIT	    BIT18	            // In	Low     ADS7846 Touch Interrupt
#define	PIRQ	        PORTB_VBIT + 18
#define	I2C_INT_BIT	    BIT19	            // In	Low     I2C Expander Interrupt
#define	I2C_INT	        PORTB_VBIT + 19
#define	USB_SPD_BIT	    BIT28	            // Out	High    USB Device Xcvr Speed, 1 = 12Mbit
#define	USB_SPD	        PORTB_VBIT + 28
#define	USB_MODE_BIT    BIT29	            // Out	High    USB Device Xcvr Mode, 1 = Differential mode
#define	USB_MODE        PORTB_VBIT + 29

// Define initial direction (1 = output) and value
#define PORTB_DDIR      (USB_SPD_BIT | USB_MODE_BIT)
#define PORTB_DR        (USB_SPD_BIT)
#define PORTB_OCR1      0xffffffff      // all PORTB GPIO's are driven by the GPIO Data Register
#define PORTB_OCR2      0xffffffff      // all PORTB GPIO's are driven by the GPIO Data Register
#define PORTB_ICR1      0x0             // all PORTB GPIO's inputs go to the GPIO Sample Status Register
#define PORTB_ICR2      0x0             // all PORTB GPIO's inputs go to the GPIO Sample Status Register
       
// Define signals that are to be set as GPIO (bit = 1) and define for Primary (0)
// or Secondary (1) use non-GPIO
#define PORTB_GPIUS     (SD_VEN_BIT | SD_CD_BIT | SD_WP_BIT | E_INT_BIT | PIRQ_BIT | I2C_INT_BIT | USB_SPD_BIT | USB_MODE_BIT)
#define PORTB_GPR       0x0 // no secondary functions

// -----------------------------------------------------------------------------------------------
// PORT C
#define PORTC_VBIT      64

// Signal			    Bit		               Dir	Active	Usage
#define	LCD_VEN_BIT	    BIT8	            // Out  High    LCD Power Enable
#define	LCD_VEN	        PORTC_VBIT + 8
#define	USB_CD_BIT	    BIT9	            // In  High		USB Cable Detect
#define	USB_CD	        PORTC_VBIT + 9
#define	USB_SCON_BIT    BIT10	            // Out	High    USB Device Soft Connect, 1 = Device Present
#define	USB_SCON        PORTC_VBIT + 10
#define	TSEN_BIT  	  	BIT15	            // Out	High    USB Device Soft Connect, 1 = Device Present
#define	TSEN        	PORTC_VBIT + 15


// Define initial direction (1 = output) and value
#define PORTC_DDIR      (USB_SCON_BIT | LCD_VEN_BIT | TSEN_BIT)
#define PORTC_DR        TSEN
#define PORTC_OCR1      0xffffffff      // all PORTC GPIO's are driven by the GPIO Data Register
#define PORTC_OCR2      0xffffffff      // all PORTC GPIO's are driven by the GPIO Data Register
#define PORTC_ICR1      0x0             // all PORTC GPIO's inputs go to the GPIO Sample Status Register
#define PORTC_ICR2      0x0             // all PORTC GPIO's inputs go to the GPIO Sample Status Register
       
// Define signals that are to be set as GPIO (bit = 1) and define for Primary (0)
// or Secondary (1) use non-GPIO
#define PORTC_GPIUS     (LCD_VEN_BIT | USB_CD_BIT | USB_SCON_BIT | TSEN_BIT)
#define PORTC_GPR       0x0 // no secondary functions

// -----------------------------------------------------------------------------------------------
// PORT D
#define PORTD_VBIT      96

// Signal			    Bit		               Dir	Active	Usage
#define	CF_CD_BIT	    BIT7	            // In   Low     Compact Flash Card Detect
#define	CF_CD	        PORTD_VBIT + 7
#define	CF_RST_BIT	    BIT8	            // Out  High    Compact Flash Reset
#define	CF_RST	        PORTD_VBIT + 8
#define	CF_RDY_BIT	    BIT9	            // In   n/a     Compact Flash Ready/Busy
#define	CF_RDY	        PORTD_VBIT + 9
#define	CF_VEN_BIT	    BIT10	            // Out  Low     Compact Flash Power Enable
#define	CF_VEN	        PORTD_VBIT + 10
#define	LCD_VEE_BIT	    BIT11	            // Out  High    LCD VEE Enable
#define	LCD_VEE	        PORTD_VBIT + 11
#define	USR_LED0_BIT	BIT31	            // Out  Low		User LED 0 on CPU Module
#define	USR_LED0	    PORTD_VBIT + 31

// Define initial direction (1 = output) and value
#define PORTD_DDIR      (CF_RST_BIT | CF_VEN_BIT | USR_LED0_BIT | LCD_VEE_BIT)      
#define PORTD_DR        (CF_RST_BIT | USR_LED0_BIT)
#define PORTD_OCR1      0xffffffff      // all PORTD GPIO's are driven by the GPIO Data Register
#define PORTD_OCR2      0xffffffff      // all PORTD GPIO's are driven by the GPIO Data Register
#define PORTD_ICR1      0x0             // all PORTD GPIO's inputs go to the GPIO Sample Status Register
#define PORTD_ICR2      0x0             // all PORTD GPIO's inputs go to the GPIO Sample Status Register

       
// Define signals that are to be set as GPIO (bit = 1) and define for Primary (0)
// or Secondary (1) use non-GPIO
#define PORTD_GPIUS		(CF_CD_BIT | CF_RST_BIT | CF_RDY_BIT | CF_VEN_BIT | LCD_VEE_BIT	| USR_LED0_BIT)
#define PORTD_GPR       0x0 // no secondary functions

extern void GPIO_init(void);
extern int GPIO_set(int gpio_bit);
extern int GPIO_clr(int gpio_bit);
extern int GPIO_tst(int gpio_bit);
extern int GPIO_in(int gpio_bit);
extern int GPIO_out(int gpio_bit);
