//==========================================================================
//
// mc9328mxl.h
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         10/23/2004
// Description:  This file contains register base addresses and offsets
//				 and access macros for the MC9328MXL on-chip peripherals
//

#include "bits.h"


//---------------------------------------
// WDOG - Watchdog Timer
#define WDOG_BASE_ADD		0x00201000
#define WDOG_REG(_x_)		*(vulong *)(WDOG_BASE_ADD + _x_)
#define WDOG_CR 			0x00 	// Control Register
#define WDOG_SR 			0x04 	// Service Register
#define WDOG_STR 			0x08 	// Status Registert

//---------------------------------------
// TMR - Timers
#define TMR1_BASE_ADD		0x00202000
#define TMR2_BASE_ADD		0x00203000
#define TMR1_REG(_x_)		*(vulong *)(TMR1_BASE_ADD + _x_)
#define TMR2_REG(_x_)		*(vulong *)(TMR2_BASE_ADD + _x_)
#define TMR_CTL 			0x00 	// Control Register
#define TMR_PRE 			0x04 	// Prescaler Register
#define TMR_CMP 			0x08 	// Compare Register
#define TMR_CR 				0x0C 	// Capture Register
#define TMR_CN 				0x10 	// Counter Register
#define TMR_STAT 			0x14 	// Status Register

//---------------------------------------
// RTC - Real Time Clock
#define RTC_BASE_ADD		0x00204000
#define RTC_REG(_x_)		*(vulong *)(RTC_BASE_ADD + _x_)
#define RTC_HOURMIN 		0x00 	// Hours and Minutes Counter Register
#define RTC_SECONDS 		0x04 	// Seconds Counter Register
#define RTC_ALRM_HM 		0x08 	// Hours and Minutes Alarm Register
#define RTC_ALRM_SEC 		0x0C 	// Seconds Alarm Register
#define RTC_RCCTL 			0x10 	// Control Register
#define RTC_RTCISR 			0x14 	// Interrupt Status Register
#define RTC_RTCIENR 		0x18 	// Interrupt Enable Register
#define RTC_STPWCH 			0x1C 	// Stopwatch Minutes Register
#define RTC_DAYR 			0x20 	// Days Counter Register
#define RTC_DAYALARM 		0x24 	// Day Alarm Register

//---------------------------------------
// LCDC - LCD Controller
// additional LCDC defines are in mc9328mxl_lcd.h
#define LCDC_BASE_ADD		0x00205000
#define LCDC_REG(_x_)		*(vulong *)(LCDC_BASE_ADD + _x_)

#define LCDC_MAP(_x_)		*(vulong *)(LCDC_BASE_ADD + 0x800 + _x_)

//---------------------------------------
// UARTS
// additional UART defines are in mc9328mxl_uart.h
#define UART1_BASE_ADD		0x00206000
#define UART2_BASE_ADD		0x00207000
#define UART1_REG(_x_)		*(vulong *)(UART1_BASE_ADD + _x_)
#define UART2_REG(_x_)		*(vulong *)(UART2_BASE_ADD + _x_)

// ------------------------------------------
// PWM - Pulse Width Modulator
#define PWM_BASE_ADD		0x00208000
#define PWM_REG(_x_)		*(vulong *)(PWM_BASE_ADD + _x_)
#define PWM_CTLR 			0x00 	// Control Register
#define PWM_STAT 			0x04 	// Sample Register
#define PWM_PERIOD 			0x08 	// Period Register
#define PWM_CNT 			0x0C 	// Counter Register

// ------------------------------------------
// DMAC - Direct Memory Access Controller
#define DMAC_BASE_ADD		0x00209000
#define DMAC_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + _x_)
// Common control registers
#define DMAC_CCR 			0x00 	// Control Register
#define DMAC_ISR 			0x04 	// Interrupt Status Register
#define DMAC_IMR 			0x08 	// Interrupt Mask Register
#define DMAC_BTOSR 			0x0C 	// Burst Time-Out Status Register
#define DMAC_RTOSR 			0x10 	// Request Time-Out Status Register
#define DMAC_SESR 			0x14 	// Transfer Error Status Register
#define DMAC_BOSR 			0x18 	// Buffer Overflow Status Register
#define DMAC_BTOCR 			0x1C 	// Burst Time-Out Control Register
#define DMAC_WSRA 			0x40 	// W-Size Register A
#define DMAC_XSRA 			0x44 	// X-Size Register A
#define DMAC_YSRA 			0x48 	// Y-Size Register A
#define DMAC_WSRB 			0x4C 	// W-Size Register B
#define DMAC_XSRB 			0x50 	// X-Size Register B
#define DMAC_YSRB 			0x54 	// Y-Size Register B

// Offsets and macros for each individual DMA channel
#define DMAC0_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x080 + _x_)
#define DMAC1_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x0C0 + _x_)
#define DMAC2_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x100 + _x_)
#define DMAC3_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x140 + _x_)
#define DMAC4_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x180 + _x_)
#define DMAC5_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x1C0 + _x_)
#define DMAC6_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x200 + _x_)
#define DMAC7_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x240 + _x_)
#define DMAC8_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x280 + _x_)
#define DMAC9_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x2C0 + _x_)
#define DMAC10_REG(_x_)		*(vulong *)(DMAC_BASE_ADD + 0x300 + _x_)
#define DMAC_SAR 			0x00 	// Source Address Register
#define DMAC_DAR 			0x04 	// Destination Address Register
#define DMAC_CNTR 			0x08 	// Count Register
#define DMAC_CR 			0x0C 	// Control Register
#define DMAC_RSSR 			0x10 	// Request Source Select Register
#define DMAC_BLR 			0x14 	// Burst Length Register
#define DMAC_RTOR 			0x18 	// Request Time-Out Register
#define DMAC_BUCR 			0x18 	// Bus Utilization Control Register

// ------------------------------------------
// USBD - Universal Serial Bus Device Interface
#define USBD_BASE_ADD		0x00212000
#define USBD_REG(_x_)		*(vulong *)(USBD_BASE_ADD + _x_)
// Common control registers
#define USBD_FRAME 			0x000 	// USB Frame Number and Match Register
#define USBD_SPEC 			0x004 	// USB Specification and Release Number Register
#define USBD_STAT 			0x008 	// USB Status Register
#define USBD_CTRL 			0x00C 	// USB Control Register
#define USBD_DADR 			0x010 	// USB Descriptor RAM Address Register
#define USBD_DDAT 			0x014 	// USB Descriptor RAM/Endpoint Buffer Data Register
#define USBD_INTR 			0x018 	// USB Interrupt Status Register
#define USBD_MASK 			0x01C 	// USB Interrupt Mask Register
#define USBD_MCTL 			0x020 	// USB FIFO Memory Control Register
#define USBD_ENAB 			0x024 	// USB Enable Register

// Offsets and macros for each individual USBD endpoint
#define USBD_EP0_REG(_x_)	*(vulong *)(USBD_BASE_ADD + 0x030 + _x_)
#define USBD_EP1_REG(_x_)	*(vulong *)(USBD_BASE_ADD + 0x060 + _x_)
#define USBD_EP2_REG(_x_)	*(vulong *)(USBD_BASE_ADD + 0x090 + _x_)
#define USBD_EP3_REG(_x_)	*(vulong *)(USBD_BASE_ADD + 0x0C0 + _x_)
#define USBD_EP4_REG(_x_)	*(vulong *)(USBD_BASE_ADD + 0x0F0 + _x_)
#define USBD_EP5_REG(_x_)	*(vulong *)(USBD_BASE_ADD + 0x120 + _x_)
#define USBD_EP_STAT 		0x030 	// Endpoint Status/Control Register
#define USBD_EP_INTR 		0x034 	// Endpoint Interrupt Status Register
#define USBD_EP_MASK 		0x038 	// Endpoint Interrupt Mask Register
#define USBD_EP_FDAT 		0x03C 	// Endpoint FIFO Data Register
#define USBD_EP_FSTAT 		0x040 	// Endpoint FIFO Status Register
#define USBD_EP_FCTRL 		0x044 	// Endpoint FIFO Control Register
#define USBD_EP_LRFP 		0x048 	// Endpoint Last Read Frame Pointer Register
#define USBD_EP_LWFP 		0x04C 	// Endpoint Last Write Frame Pointer Register
#define USBD_EP_FALRM 		0x050 	// Endpoint FIFO Alarm Register
#define USBD_EP_FRDP 		0x054 	// Endpoint FIFO Read Pointer Register
#define USBD_EP_FWRP 		0x058 	// Endpoint FIFO Write Pointer Register

// ------------------------------------------
// SDIO - Secure-Digital I/O Controller (also supports MMC mode)
#define SDIO_BASE_ADD		0x00214000
#define SDIO_REG(_x_)		*(vulong *)(SDIO_BASE_ADD + _x_)
#define SDIO_CLK_CTRL		0x00 	// Clock Control Register
#define SDIO_STAT 			0x04 	// Status Register
#define SDIO_CLK_RATE 		0x08 	// Clock Rate Register
#define SDIO_CD_CTRL		0x0C 	// Command and Data Control Register
#define SDIO_RES_TO 		0x10 	// Response Time Out Register
#define SDIO_READ_TO 		0x14 	// Read Time Out Register
#define SDIO_BLK_LEN 		0x18 	// Block Length Register
#define SDIO_NOB 			0x1C 	// Number of Blocks Register
#define SDIO_REV_NO 		0x20 	// Revision Number Register
#define SDIO_INT_MASK 		0x24 	// Interrupt Mask Register
#define SDIO_CMD 			0x28 	// Command Number Register
#define SDIO_ARGH	 		0x2C 	// Higher Argument Register
#define SDIO_ARGL	 		0x30 	// Lower Argument Register
#define SDIO_RES_FIFO		0x34 	// Response FIFO Register
#define SDIO_BUF			0x38 	// Buffer Access Register

// ------------------------------------------
// I2C - Two-Wire Serial I/O
#define I2C_BASE_ADD		0x00217000
#define I2C_REG(_x_)		*(vulong *)(I2C_BASE_ADD + _x_)
#define I2C_ADR 			0x00 	// Address Register
#define I2C_FDR 			0x04 	// Frequency Divider Register
#define I2C_CR 				0x08 	// Control Register
#define I2C_SR 				0x0C 	// Status Register
#define I2C_DR 				0x10 	// Data I/O Register

// ------------------------------------------
// SSI - Synchronous Serial Interface
#define SSI_BASE_ADD		0x00218000
#define SSI_REG(_x_)		*(vulong *)(SSI_BASE_ADD + _x_)
#define SSI_TXD 			0x00 	// Transmit Data Register
#define SSI_RXD 			0x04 	// Receive Data Register
#define SSI_CSR 			0x08 	// Control/Status Register
#define SSI_TCR 			0x0C 	// Transmit Configuration Register
#define SSI_RCR 			0x10 	// Receive Configuration Register
#define SSI_TCCR 			0x14 	// Transmit Clock Control Register
#define SSI_RCCR 			0x18 	// Receive Clock Control Register
#define SSI_TSR 			0x1C 	// Time Slot Register
#define SSI_FCSR 			0x20 	// FIFO Control/Status Register
#define SSI_OR 				0x28 	// Option Register

// ------------------------------------------
// SPI - Serial Peripheral Interface
#define SPI1_BASE_ADD		0x00213000
#define SPI2_BASE_ADD		0x00219000
#define SPI1_REG(_x_)		*(vulong *)(SPI1_BASE_ADD + _x_)
#define SPI2_REG(_x_)		*(vulong *)(SPI2_BASE_ADD + _x_)
#define SPI_RXD 			0x00 	// Rx Data Register
#define SPI_TXD 			0x04 	// Tx Data Register
#define SPI_CTRL 			0x08 	// Control Register
#define SPI_INT 			0x0C 	// Interrupt Control/Status Register
#define SPI_TEST 			0x10 	// Test Register
#define SPI_PERIOD 			0x14 	// Sample Period Control Register
#define SPI_DMA 			0x18 	// DMA Control Register
#define SPI_RESET 			0x1C 	// Soft Reset Register

// ------------------------------------------
// MSHC - Sony Memory Stick Host Controller
#define MSHC_BASE_ADD		0x0021A000
#define MSHC_REG(_x_)		*(vulong *)(MSHC_BASE_ADD + _x_)
#define MSHC_CMD 			0x00 	// Command Register
#define MSHC_CSR 			0x02 	// Control/Status Register
#define MSHC_TXD 			0x04 	// Transmit FIFO Data Register
#define MSHC_RXD 			0x04 	// Receive FIFO Data Register
#define MSHC_ICS 			0x06 	// Interrupt Control/Status Register
#define MSHC_PPCD 			0x08 	// Parallel Port Control/Data Register
#define MSHC_C2 			0x0A 	// Control 2 Register
#define MSHC_ACD 			0x0C 	// Auto Command Register
#define MSHC_FAECS			0x0E 	// FIFO Access Error Control/Status Register
#define MSHC_CLKD 			0x10 	// Serial Clock Divider Register
#define MSHC_DRQC 			0x12 	// DMA Request Control Register

// ------------------------------------------
// PLL - PLL and Clock Controler
#define PLL_BASE_ADD		0x0021B000
#define PLL_REG(_x_)		*(vulong *)(PLL_BASE_ADD + _x_)
#define PLL_CSCR 			0x00 	// Clock Source Control Register
#define PLL_MPCTL0 			0x04 	// MCU PLL Control Register 0
#define PLL_MPCTL1 			0x08 	// MCU PLL and System Clock Control Register 1
#define PLL_SPCTL0 			0x0C 	// System PLL Control Register 0
#define PLL_SPCTL1 			0x10 	// System PLL Control Register 1
#define PLL_PCDR 			0x20 	// Peripheral Clock Divider Register

// ------------------------------------------
// SYS - System Control
#define SYS_BASE_ADD		0x0021B800
#define SYS_REG(_x_)		*(vulong *)(SYS_BASE_ADD + _x_)
#define SYS_RSR 			0x00 	// Reset Source Register
#define SYS_SIDR 			0x04 	// Silicon ID Register
#define SYS_FMCR 			0x08 	// Function Multiplexing Control Register
#define SYS_GPCR 			0x0C 	// Global Peripheral Control Register
#define SYS_GCCR 			0x10 	// Global Clock Control Register

// ------------------------------------------
// GPIO - General Purpose I/O
#define GPIO_BASE_ADD		0x0021C000
#define GPIOA_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x000 + _x_)
#define GPIOB_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x100 + _x_)
#define GPIOC_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x200 + _x_)
#define GPIOD_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x300 + _x_)
#define GPIO_DDIR 			0x00 	// Data Direction Register
#define GPIO_OCR1 			0x04 	// Output Configuration Register 1
#define GPIO_OCR2 			0x08 	// Output Configuration Register 2
#define GPIO_ICONFA1 		0x0C 	// Input Configuration Register A1
#define GPIO_ICONFA2 		0x10 	// Input Configuration Register A2
#define GPIO_ICONFB1 		0x14 	// Input Configuration Register B1
#define GPIO_ICONFB2 		0x18 	// Input Configuration Register B2
#define GPIO_DR 			0x1C 	// Data Register
#define GPIO_GIUS 			0x20 	// GPIO In Use Register
#define GPIO_SSR 			0x24 	// Sample Status Register
#define GPIO_ICR1 			0x28 	// Interrupt Configuration Register 1
#define GPIO_ICR2 			0x2C 	// Interrupt Configuration Register 2
#define GPIO_IMR 			0x30 	// Interrupt Mask Register
#define GPIO_ISR 			0x34 	// Interrupt Status Register
#define GPIO_GPR 			0x38 	// General Purpose Register
#define GPIO_SWR 			0x3C 	// Software Reset Register
#define GPIO_PUEN 			0x40 	// Pull_Up Enable Register

// ------------------------------------------
// EIM - External Interface Module
#define EIM_BASE_ADD		0x00220000
#define EIM_REG(_x_)		*(vulong *)(EIM_BASE_ADD + _x_)
#define EIM_CS0U 			0x00 	// Chip Select 0 Upper Control Register
#define EIM_CS0L 			0x04 	// Chip Select 0 Lower Control Register
#define EIM_CS1U 			0x08 	// Chip Select 1 Upper Control Register
#define EIM_CS1L 			0x0C 	// Chip Select 1 Lower Control Register
#define EIM_CS2U 			0x10 	// Chip Select 2 Upper Control Register
#define EIM_CS2L 			0x14 	// Chip Select 2 Lower Control Register
#define EIM_CS3U 			0x18 	// Chip Select 3 Upper Control Register
#define EIM_CS3L 			0x1C 	// Chip Select 3 Lower Control Register
#define EIM_CS4U 			0x20 	// Chip Select 4 Upper Control Register
#define EIM_CS4L 			0x24 	// Chip Select 4 Lower Control Register
#define EIM_CS5U 			0x28 	// Chip Select 5 Upper Control Register
#define EIM_CS5L 			0x2C 	// Chip Select 5 Lower Control Register
#define EIM_CFG				0x30 	// Configuration Register

// ------------------------------------------
// SDRAMC - SDRAM Controller
#define SDRAMC_BASE_ADD		0x00221000
#define SDRAMC_REG(_x_)		*(vulong *)(SDRAMC_BASE_ADD + _x_)
#define SDRAMC_CTL0 		0x00 	// SDRAM 0 Control Register
#define SDRAMC_CTL1 		0x04 	// SDRAM 1 Control Register
#define SDRAMC_MISC 		0x14 	// Miscellaneous Register
#define SDRAMC_RST 			0x18 	// SDRAM Reset Register

// ------------------------------------------
// MMA - Multimedia Accelerator
#define MMA_BASE_ADD		0x00222000
#define MMA_REG(_x_)		*(vulong *)(MMA_BASE_ADD + _x_)
#define MMA_MAC_MOD 		0x000 	// MAC Module Register
#define MMA_MAC_CTRL 		0x004 	// MAC Control Register
#define MMA_MAC_MULT 		0x008 	// MAC Multiply Counter Register
#define MMA_MAC_ACCU 		0x00C 	// MAC Accumulate Counter Register
#define MMA_MAC_INTR 		0x010 	// MAC Interrupt Register
#define MMA_MAC_INTR_MASK 	0x014 	// MAC Interrupt Mask Register
#define MMA_MAC_FIFO MMA	0x018 	// MAC FIFO Register
#define MMA_MAC_FIFO_STAT 	0x01C 	// MAC FIFO Status Register
#define MMA_MAC_BURST 		0x020 	// MAC Burst Count Register
#define MMA_MAC_BITSEL 		0x024 	// MAC Bit Select Register
#define MMA_MAC_XYACCU 		0x040 	// MAC XY Count Accumulate Register
#define MMA_MAC_XBASE 		0x200 	// MAC X Base Address Register
#define MMA_MAC_XINDEX 		0x204 	// MAC X Index Register
#define MMA_MAC_XLENGTH 	0x208 	// MAC X Length Register
#define MMA_MAC_XMODIFY 	0x20C 	// MAC X Modify Register
#define MMA_MAC_XINCR 		0x210 	// MAC X Increment Register
#define MMA_MAC_XCOUNT 		0x214 	// MAC X Count Register
#define MMA_MAC_YBASE 		0x300 	// MAC Y Base Address Register
#define MMA_MAC_YINDEX 		0x304 	// MAC Y Index Register
#define MMA_MAC_YLENGTH		0x308 	// MAC Y Length Register
#define MMA_MAC_YMODIFY 	0x30C 	// MAC Y Modify Register
#define MMA_MAC_YINCR 		0x310 	// MAC Y Increment Register
#define MMA_MAC_YCOUNT 		0x314 	// MAC Y Count Register
#define MMA_DCT_CTRL 		0x400 	// DCT Control Register
#define MMA_DCT_VERSION 	0x404 	// DCT Version Register
#define MMA_DCT_IRQENA 		0x408 	// DCT IRQ Enable Register
#define MMA_DCT_IRQSTAT 	0x40C 	// DCT IRQ Status Register
#define MMA_DCT_SRCDATA 	0x410 	// DCT Source Data Address
#define MMA_DCT_DESDATA 	0x414 	// DCT Destination Data Address
#define MMA_DCT_XOFF 		0x418 	// DCT X-Offset Address
#define MMA_DCT_YOFF 		0x41C 	// DCT Y-Offset Address
#define MMA_DCT_XYCNT 		0x420 	// DCT XY Count
#define MMA_DCT_SKIP 		0x424 	// DCT Skip Address
#define MMA_DCT_FIFO 		0x500 	// DCT Data FIFO

// ------------------------------------------
// AITC - Advanced Interrupt Controller
#define AITC_BASE_ADD		0x00223000
#define AITC_REG(_x_)		*(vulong *)(AITC_BASE_ADD + _x_)
#define AITC_INTCNTL 		0x00 	// Interrupt Control Register
#define AITC_NIMASK 		0x04 	// Normal Interrupt Mask Register
#define AITC_INTENNUM 		0x08 	// Interrupt Enable Number Register
#define AITC_INTDISNUM 		0x0C 	// Interrupt Disable Number Register
#define AITC_INTENABLEH 	0x10 	// Interrupt Enable Register High
#define AITC_INTENABLEL 	0x14 	// Interrupt Enable Register Low
#define AITC_INTTYPEH 		0x18 	// Interrupt Type Register High
#define AITC_INTTYPEL 		0x1C 	// Interrupt Type Register Low
#define AITC_NIPRIORITY7 	0x20 	// Normal Interrupt Priority Level Register 7
#define AITC_NIPRIORITY6 	0x24 	// Normal Interrupt Priority Level Register 6
#define AITC_NIPRIORITY5 	0x28 	// Normal Interrupt Priority Level Register 5
#define AITC_NIPRIORITY4 	0x2C 	// Normal Interrupt Priority Level Register 4
#define AITC_NIPRIORITY3 	0x30 	// Normal Interrupt Priority Level Register 3
#define AITC_NIPRIORITY2 	0x34 	// Normal Interrupt Priority Level Register 2
#define AITC_NIPRIORITY1 	0x38 	// Normal Interrupt Priority Level Register 1
#define AITC_NIPRIORITY0 	0x3C 	// Normal Interrupt Priority Level Register 0
#define AITC_NIVECSR 		0x40 	// Normal Interrupt Vector and Status Register
#define AITC_FIVECSR 		0x44 	// Fast Interrupt Vector and Status Register
#define AITC_INTSRCH 		0x48 	// Interrupt Source Register High
#define AITC_INTSRCL 		0x4C 	// Interrupt Source Register Low
#define AITC_INTFRCH 		0x50 	// Interrupt Force Register High
#define AITC_INTFRCL 		0x54 	// Interrupt Force Register Low
#define AITC_NIPNDH 		0x58 	// Normal Interrupt Pending Register High
#define AITC_NIPNDL 		0x5C 	// Normal Interrupt Pending Register Low
#define AITC_FIPNDH 		0x60 	// Fast Interrupt Pending Register High
#define AITC_FIPNDL 		0x64 	// Fast Interrupt Pending Register Low

// ------------------------------------------
// CSI - CMOS Sensor Input
#define CSI_BASE_ADD		0x00224000
#define CSI_REG(_x_)		*(vulong *)(CSI_BASE_ADD + _x_)
#define CSI_CR1 	 		0x00 	// Control Register 1
#define CSI_CR2 	 		0x04 	// Control Register 2
#define CSI_SR 	 			0x08 	// Status Register
#define CSI_STATR  			0x0C 	// Statistic FIFO Register
#define CSI_RXR 	 		0x10 	// RxFIFO Register

#ifndef ASSEMBLY_ONLY
extern void lcd_init(void);
extern void lcd_on(void);
extern void lcd_off(void);
extern void fb_set_pixel(unsigned long,unsigned long,unsigned char);
#endif
