/*
 * Monitor configuration file for CSB625 - PXA255 Single Board
 *
 * Adapted by Mike Kelly, Cogent Computer Systems, Inc. email: mike@cogcomp.com
 *
 *
 * General notice:
 * This code is part of a boot-monitor package developed as a generic base
 * platform for embedded system designs.  As such, it is likely to be
 * distributed to various projects beyond the control of the original
 * author.  Please notify the author of any enhancements made or bugs found
 * so that all may benefit from the changes.  In addition, notification back
 * to the author will allow the new user to pick up changes that may have
 * been made by other users after this version of the code was distributed.
 *
 * Author:  Ed Sutter
 * email:   esutter@lucent.com
 * phone:   908-582-2351
 *
 *
 * Modified by Technoloy Rescue.
 *	11.03.2003 : removed/restored TFS and changed RAM TFS.
 *	12.03.2003 : removed PS2_DEBUG, changed APPRAMBASE_OVERRIDE.
 *	14.04.2003 : added INCLUDE_I2C and NO_MONLIB_I2C_STUBS; fixed TFSSECTORCOUNT to 1; resed INCLUDE_EDIT to 0.
 *	06.06.2003 : reset INCLUDE_DISASSEMBLER to 0.
 *	20.08.2003 : moved to version 2 : removed FLASHRAM_BASE and added INCLUDE_STOREMAC.
 *	20.08.2003 : added INCLUDE_FLASHFX.
 *	21.08.2003 : set INCLUDE_UNZIP to 1.
 *	21.11.2003 : extended TFS size to 32 Mo.
 *	06.01.2004 : changed TFS_EBIN_MSBIN to TFS_EBIN_ELFMSBIN.
 *
 *	26.04.2004 : General clean-up and added version number.
 *	28.04.2004 : Disabled MMC_DEBUG.
 *	30.04.2004 : Added INCLUDE_FAT.
 *	02.05.2004 : Added INCLUDE_FS.
 *	06.05.2004 : Removed FAT_DEBUG.
 *
 *	03.03.2005 : ddlc enabled TFS.
 *	21.03.2005 : ddlc enabled option as history, quickmemcpy.
 */

#include "boardver.h"

#define CPU_LE
#define NO_MONLIB_I2C_STUBS	1
#define RTCINIT

/* Define following option to include i2c driver. */
//#define INCLUDE_I2C			1

/* Define following option to include s3531a driver. */
//#define	INCLUDE_DS1307		1

/* Define following option to include s3531a driver. */
//#define	INCLUDE_FLASHFX		0

/* Define following option to include mmc commands. */
//#define	INCLUDE_MMC			1
//#define CFG_MMC_BASE		0xF0000000		// This address is virtual and correspond to reserved physical memory.
// Define following to include debug messages.
//#define MMC_DEBUG			1

/* Define following to include file system R/W support. */
//#define	INCLUDE_FS			1

#if INCLUDE_FS

/* Define following to include FAT file system support. */
#define	INCLUDE_FAT			1

// Define following to include debug messages.
//#define	FAT_DEBUG			1

#endif


/*
 * The target_putchar() function also drops the character at the
 * LCD...
 * Note the pass-2 version of the CSB625 used UART1 for console.
 * Run "make USE_UART1=TRUE" for those cases...
 */
#define MORE_PUTCHAR lcd_putchar
#ifdef USE_UART1
#define CONSOLE_UART_BASE 0x40100000
#else
#define CONSOLE_UART_BASE 0x40700000
#endif
#define SIO_STEP 4
#define IEN_DEFAULT 0x40
#define MCTL_DEFAULT 0x01


/* DEFAULT_ETHERADD & DEFAULT_IPADD:
 * Refer to notes in ethernet.c function EthernetStartup() for details
 * regarding the use of these definitions.
 * DEFAULT_IPADD could be set to "DHCP" or "BOOTP" as well.
 */
#define     DEFAULT_ETHERADD "00:23:31:25:"  	// Cogent Block
#define     DEFAULT_IPADD    "192.168.254.215"		

/* override the app ram base to set it to 3Mbyte.  This reserves space
 * for umon and the LCD controller buffer
 */
#define APPRAMBASE_OVERRIDE 0xa008D000
#define BOOTROMBASE_OVERRIDE 0x0

/* Defining DONT_CENTER_MONHEADER eliminates the automatic centering
 * of the monitor's startup banner...
 */
#define DONT_CENTER_MONHEADER

/* XBUFCNT & RBUFCNT:
 *  Number of transmit and receive buffers allocated to ethernet.
 *  The total of XBUFCNT+RBUFCNT should not exceed MAXEBDS
 */
#define XBUFCNT 	8
#define RBUFCNT 	8
#define XBUFSIZE	2048
#define RBUFSIZE	2048

/* LOOPS_PER_SECOND:
 * Approximately the size of a loop that will cause a 1-second delay.
 * This can be guestimated or modified with the sleep -c command at the
 * monitor command line.
 */
#define LOOPS_PER_SECOND    20000

/* The CSB272 hardware simply has one bank of flash devices.
 * We define SINGLE_FLASH_DEVICE here to pull in the default
 * code from the flash driver file.
 */

//#define SINGLE_FLASH_DEVICE		

/* Flash bank configuration:
   Single AM29LV160D
 */
/* Flash bank configuration:
 */
#define FLASHBANKS				1
#define SINGLE_FLASH_DEVICE 	1
#define FLASH_COPY_TO_RAM 		1
#define FLASH_BANK0_BASE_ADDR  	0x0
#define FLASH_PROTECT_RANGE  	"0-1"
#define FLASH_BANK0_WIDTH       2
#define FLASH_LARGEST_SECTOR    0x20000
#define LOCK_FLASH_PROTECT_RANGE

/* TFS definitions:
 *  TFSSTART:       Base address in FLASH at which TFS starts.
 *  TFSEND:         End address of TFS in FLASH.
 *  TFSSPARE:       Location of sector that is used as the spare sector
 *                  by TFS for defragmentation.
 *  TFSSPARESIZE:   Size of the spare sector used by TFS for defragmentation.
 *  TFSSECTORCOUNT: Number of eraseable sectors that TFS covers, not including
 *                  the TFSSPARE sector.
 */
#define TFSSPARESIZE    FLASH_LARGEST_SECTOR
#define TFS_DEVTOT      1
#define TFSSTART        (FLASH_BANK0_BASE_ADDR+0x40000)
#define TFSEND          (FLASH_BANK0_BASE_ADDR+0x007dffff)
#define TFSSPARE        (TFSEND+1)
#define TFSSECTORCOUNT	((TFSSPARE-TFSSTART)/FLASH_LARGEST_SECTOR)
#define TFS_EBIN_ELFMSBIN	1
#define TFS_VERBOSE_STARTUP	1
#define TFS_AUTOBOOT_ABORTABLE	    
#define TFS_ALTDEVTBL_BASE		&alt_tfsdevtbl_base

//#define FLASH_PROTECT_RANGE  "0-4"
//#define FLASH_PROTECT_RANGE  "0-1"

/* SYMFILE is the name of a file that, if present, the monitor uses to 
 * process symbols on the command line.  A symbol is a whitespace delimited
 * string prefixed by a percent sign (%).
 */
#define SYMFILE "symtbl"

/* Specify CPU/PLATFORM type and name so that common code can be used
 * for a similar cpu, on different platforms.
 * The 'TYPE' definition is used for ifdefs in the code and the 'NAME'
 * is used for printfs in the code.
 */
#define CPU_TYPE        PXA255
#define CPU_NAME        "PXA255 XScale"
#define PLATFORM_TYPE   CSB625
#define PLATFORM_NAME   "Cogent CSB625"

/* Specify the size of the memory block (in monitor space) that is to be
 * allocated to malloc in the monitor.  Note that this size can be dynamically
 * increased using the heap extension option in the heap command.
 */
#define ALLOCSIZE		(64*1024)
#define MONSTACKSIZE	(8*1024)

/* Specify inclusion of subsystems within the monitor here.
 * Refer to comments in common/monitor/inc_check.h for details on
 * each of these macros.
 */
#define INCLUDE_MEMTRACE	1
#define INCLUDE_MEMCMDS         1
#define INCLUDE_MALLOC          1
#define INCLUDE_SHELLVARS       1
#define INCLUDE_EDIT            1
#define INCLUDE_DISASSEMBLER    0
#define INCLUDE_UNZIP           1
#define INCLUDE_ETHERNET        1
#define INCLUDE_ICMP			1
#define INCLUDE_TFTP            1
#define INCLUDE_DHCPBOOT        1
#define INCLUDE_TFS             1
#define INCLUDE_TFSCLI          1
#define INCLUDE_TFSAPI          1
#define INCLUDE_TFSSCRIPT       1
#define INCLUDE_TFSSYMTBL       1
#define INCLUDE_XMODEM          1
#define INCLUDE_LINEEDIT        1
#define INCLUDE_EE              1
#define INCLUDE_FLASH           1
#define INCLUDE_STRACE          1
#define INCLUDE_CAST            0
#define INCLUDE_STRUCT          1
#define INCLUDE_REDIRECT        1
#define INCLUDE_QUICKMEMCPY     1
#define INCLUDE_PROFILER        0
#define INCLUDE_BBC             0
#define INCLUDE_STOREMAC		1
#define INCLUDE_VERBOSEHELP     1
#define INCLUDE_PORTCMD         0
#define INCLUDE_HWTMR           0
#define INCLUDE_PS2KBD          1
#define INCLUDE_GDB             1
#define INCLUDE_USRLVL			1
#define INCLUDE_JFFS2			1
#define INCLUDE_JFFS2ZLIB		1

/* Inclusion of this next file will make sure that all of the above
 * inclusions are legal; and warn/adjust where necessary.
 */
#include "inc_check.h"


