//==========================================================================
//
// csb337_gpio.c
//
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         02/16/2003
// Description:  This file contains code to intialize the CSB337 GPIO
//               section as well as set, clear and test functions
//               for manipulating the GPIO bits
//
//--------------------------------------------------------------------------

#include "config.h"
#include "cpuio.h"
#include "stddefs.h"
#include "genlib.h"
#include "umongpio.h"
#include "at91rm9200.h"
#include "at91rm9200_gpio.h"
#include "csb637_gpio.h"

//--------------------------------------------------------
// GPIO_init()
//
// This function sets the startup state for the AT91RM9200
// GPIO as used on the CSB337.  Refer to csb337_gpio.h for
// a description of the default values.  Here we just put
// them into the chip in the following order:
// 1. Disable all GPIO pins, then set the pins that will be GPIO
// 2. Set the pins that will carry alternate function A
// 3. Set the pins that will carry alternate function B
// 4. Disable all GPIO outputs and disable multi-drive
// 5. Clear the GPIO output pins that need to start low
// 6. Set the GPIO output pins that need to start high
// 7. Disable all pullups
// 8. Set which GPIO pins will have pullups
// 9. Enable the GPIO output pins (I/O pins will be left as inputs)

void GPIO_init()
{
	// Port A
	PIOA_REG(PIO_PDR) = 0xffffffff;			// GPIO Pin Disable
	PIOA_REG(PIO_PER) = ~(DEF_PIOA_ASR | DEF_PIOA_BSR);	// GPIO Pin Enable

	PIOA_REG(PIO_ASR) = DEF_PIOA_ASR;		// Alternate Function A
	PIOA_REG(PIO_BSR) = DEF_PIOA_BSR;		// Alternate Function B

	PIOA_REG(PIO_ODR) = 0xffffffff;			// Disable all GPIO Outputs first
	PIOA_REG(PIO_MDDR) = 0x0;				// no multidrive
	PIOA_REG(PIO_SODR) = 0;
	PIOA_REG(PIO_CODR) = 0;

	PIOA_REG(PIO_PUDR) = 0xffffffff;		// Disable all Pullups first
	PIOA_REG(PIO_PUER) = DEF_PIOA_PUER;		// Enable Desired Pullups 

	PIOA_REG(PIO_OER) = 0;					// GPIO Output Enable

	// Port B
	PIOB_REG(PIO_PDR) = 0xffffffff;				
	PIOB_REG(PIO_PER) = ~(DEF_PIOB_ASR | DEF_PIOB_BSR);

	PIOB_REG(PIO_ASR) = DEF_PIOB_ASR;
	PIOB_REG(PIO_BSR) = DEF_PIOB_BSR;

	PIOB_REG(PIO_ODR) = 0xffffffff;
	PIOB_REG(PIO_MDDR) = 0x0;
	PIOB_REG(PIO_SODR) = 0;
	PIOB_REG(PIO_CODR) = 0;

	PIOB_REG(PIO_PUDR) = 0xffffffff;
	PIOB_REG(PIO_PUER) = DEF_PIOB_PUER;

	PIOB_REG(PIO_OER) = 0;

	// Port C
	PIOC_REG(PIO_PDR) = 0xffffffff;			
	PIOC_REG(PIO_PER) = ~(DEF_PIOC_ASR | DEF_PIOC_BSR);

	PIOC_REG(PIO_ASR) = DEF_PIOC_ASR;
	PIOC_REG(PIO_BSR) = DEF_PIOC_BSR;

	PIOC_REG(PIO_ODR) = 0xffffffff;
	PIOC_REG(PIO_MDDR) = 0x0;
	PIOC_REG(PIO_SODR) = DEF_PIOC_SODR;
	PIOC_REG(PIO_CODR) = DEF_PIOC_CODR;

	PIOC_REG(PIO_PUDR) = 0xffffffff;
	PIOC_REG(PIO_PUER) = DEF_PIOC_PUER;

	PIOC_REG(PIO_OER) = DEF_PIOC_OER;

	// Port D
	PIOD_REG(PIO_PDR) = 0xffffffff;
	PIOD_REG(PIO_PER) = ~(DEF_PIOD_ASR | DEF_PIOD_BSR);

	PIOD_REG(PIO_ASR) = DEF_PIOD_ASR;
	PIOD_REG(PIO_BSR) = DEF_PIOD_BSR;

	PIOD_REG(PIO_ODR) = 0xffffffff;
	PIOD_REG(PIO_MDDR) = 0x0;
	PIOD_REG(PIO_SODR) = 0;
	PIOD_REG(PIO_CODR) = 0;

	PIOD_REG(PIO_PUDR) = 0xffffffff;
	PIOD_REG(PIO_PUER) = DEF_PIOD_PUER;

	PIOD_REG(PIO_OER) = 0;
}
