//==========================================================================
//
//      cpu_i2c.h
//
// Author(s):   Michael Kelly - Cogent Computer Systems, Inc.
//				Luis Torrico - Cogent Computer Systems, Inc.
// Date:        02/03/2009
// Description:	CSB733 - i.MX31 Single Board IIC Routines 
//
//==========================================================================

#include "config.h"
#include "cpuio.h"
#include "genlib.h"
#include "stddefs.h"
#include "mx35.h"


//--------------------------------------------------------------------------
// some i.MX31 I2C register and bit defines
//
// Refer to mx31.h for the I2C base address defines  
// I2C base address is at 0x43F80000
// I2C2 base address is at 0x43F98000
// I2C3 base address is at 0x43F84000
//

#define I2C_REG(_x_)		*(vushort *)(I2C_BASE_ADDR + _x_)
#define I2C2_REG(_x_)		*(vushort *)(I2C2_BASE_ADDR + _x_)
#define I2C3_REG(_x_)		*(vushort *)(I2C3_BASE_ADDR + _x_)

#define IADR	0x00 	// I2C Address Register
#define IFDR	0x04 	// I2C Frequency Divider Register
#define I2CR	0x08 	// I2C Control Register
#define I2SR	0x0C 	// I2C Status Register
#define I2DR	0x10 	// I2C Data I/O Register

// Register bit defines for Control Register
#define I2CR_IEN		(1 << 7)	// 
#define I2CR_IIEN		(1 << 6)	// 
#define I2CR_MSTA		(1 << 5)	// 
#define I2CR_MTX		(1 << 4)	// 
#define I2CR_TX_NO_AK	(1 << 3)	// 
#define I2CR_RSTA		(1 << 2)	// 

// Register bit defines for Status Register
#define I2SR_ICF		(1 << 7)	// 
#define I2SR_IBB		(1 << 5)	// 
#define I2SR_IIF		(1 << 1)	// 
#define I2SR_RX_NO_AK	(1 << 0)	// 

//--------------------------------------------------------------------------
// function prototypes
//
ulong i2c_init(void);
ulong i2c_wr_device(uchar dev, uchar reg, uchar data);
ulong i2c_rd_device(uchar dev, uchar reg, uchar *data);
ulong i2c_wr_byte(uchar data);
uchar i2c_rd_byte(void);
extern void udelay(int delay);
