//==========================================================================
//
// mx31.h
//
// Author(s):    Luis Torrico, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         05/02/2008
// Description:  This file contains register base addresses and offsets
//				 and access macros for the MCIMX31 on-chip peripherals
//				 This was copied from the mc9328mx2l.h and peripherals not
//				 used by UMON have not been tested (and may not be defined).
//			     Use these defines with caution!!
//

#include "bits.h"

#ifndef ASSEMBLY_ONLY

//typedef volatile unsigned char vuint8;
//typedef volatile unsigned short vuint16;
typedef volatile unsigned long vuint32;

#endif

/*
  * Default Memory Layout Definitions
  */
 
 #define L2CC_BASE_ADDR          0x30000000
 
 /*
  * AIPS 1
  */
 #define AIPS1_BASE_ADDR         0x43F00000
 #define AIPS1_CTRL_BASE_ADDR    AIPS1_BASE_ADDR
 #define MAX_BASE_ADDR           0x43F04000
 #define EVTMON_BASE_ADDR        0x43F08000
 #define CLKCTL_BASE_ADDR        0x43F0C000
 #define ETB_SLOT4_BASE_ADDR     0x43F10000
 #define ETB_SLOT5_BASE_ADDR     0x43F14000
 #define ECT_CTIO_BASE_ADDR      0x43F18000
 #define I2C_BASE_ADDR           0x43F80000
 #define I2C3_BASE_ADDR          0x43F84000
 #define OTG_BASE_ADDR           0x43F88000
 #define ATA_BASE_ADDR           0x43F8C000
 #define UART1_BASE_ADDR         0x43F90000
 #define UART2_BASE_ADDR         0x43F94000
 #define I2C2_BASE_ADDR          0x43F98000
 #define OWIRE_BASE_ADDR         0x43F9C000
 #define SSI1_BASE_ADDR          0x43FA0000
 #define CSPI1_BASE_ADDR         0x43FA4000
 #define KPP_BASE_ADDR           0x43FA8000
 #define IOMUXC_BASE_ADDR        0x43FAC000
 #define UART4_BASE_ADDR         0x43FB0000
 #define UART5_BASE_ADDR         0x43FB4000
 #define ECT_IP1_BASE_ADDR       0x43FB8000
 #define ECT_IP2_BASE_ADDR       0x43FBC000
 
 /*
  * SPBA
  */
 #define SPBA_BASE_ADDR          0x50000000
 #define MMC_SDHC1_BASE_ADDR     0x50004000
 #define MMC_SDHC2_BASE_ADDR     0x50008000
 #define UART3_BASE_ADDR         0x5000C000
 #define CSPI2_BASE_ADDR         0x50010000
 #define SSI2_BASE_ADDR          0x50014000
 #define SIM_BASE_ADDR           0x50018000
 #define IIM_BASE_ADDR           0x5001C000
 #define ATA_DMA_BASE_ADDR       0x50020000
 #define SPBA_CTRL_BASE_ADDR     0x5003C000
 
 /*
  * AIPS 2
  */
 #define AIPS2_BASE_ADDR         0x53F00000
 #define AIPS2_CTRL_BASE_ADDR    AIPS2_BASE_ADDR
 #define CCM_BASE_ADDR           0x53F80000
 #define FIRI_BASE_ADDR          0x53F8C000
 #define GPT1_BASE_ADDR          0x53F90000
 #define EPIT1_BASE_ADDR         0x53F94000
 #define EPIT2_BASE_ADDR         0x53F98000
 #define GPIO3_BASE_ADDR         0x53FA4000
 #define SCC_BASE                0x53FAC000
 #define SCM_BASE                0x53FAE000
 #define SMN_BASE                0x53FAF000
 #define RNGA_BASE_ADDR          0x53FB0000
 #define IPU_CTRL_BASE_ADDR      0x53FC0000
 #define AUDMUX_BASE             0x53FC4000
 #define MPEG4_ENC_BASE          0x53FC8000
 #define GPIO1_BASE_ADDR         0x53FCC000
 #define GPIO2_BASE_ADDR         0x53FD0000
 #define SDMA_BASE_ADDR          0x53FD4000
 #define RTC_BASE_ADDR           0x53FD8000
 #define WDOG_BASE_ADDR          0x53FDC000
 #define PWM_BASE_ADDR           0x53FE0000
 #define RTIC_BASE_ADDR          0x53FEC000


// ------------------------------------------
// GPT - General Purpose Timer
// Register Defines for MCIMX35
#define GPT1_REG(_x_)		*(vulong *)(GPT1_BASE_ADDR + _x_)
#define GPTCR	0x0000
#define GPTPR	0x0004
#define GPTSR	0x0008
#define GPTIR	0x000C
#define GPTOCR1	0x0010
#define GPTOCR2	0x0014
#define GPTOCR3	0x0018
#define GPTICR1	0x001c
#define GPTICR2	0x0020
#define GPTCNT	0x0024

// ------------------------------------------
// WDOG - WatchDog
#define WDOG_REG(_x_)		*(vushort *)(WDOG_BASE_ADDR + _x_)
#define WDOGWCR				0x00
#define WDOGWSR				0x02
#define WDOGWRSR			0x04

// ------------------------------------------
// CCM - Clock Control Module
// Register Defines for MCIMX35
#define CCM_BASE_ADD		0x53F80000
#define CCM_REG(_x_)		*(vulong *)(CCM_BASE_ADD + _x_)
#define CCM_CCMR 			0x00 	// Clock Source Control Register
#define CCM_PDR0 			0x04 	// Post Divider Register 0
#define CCM_PDR1 			0x08 	// Post Divider Register 1
#define CCM_PDR2 			0x0C 	// Post Divider Register 2
#define CCM_PDR3 			0x10 	// Post Divider Register 3
#define CCM_PDR4 			0x14 	// Post Divider Register 3
#define CCM_RCSR 			0x18 	// Reset Control and Source Register
#define CCM_MPCTL 			0x1C 	// MCU PLL Control Register
#define CCM_PPCTL 			0x20 	// Peripheral PLL Control Register
#define CCM_ACMR 			0x24 	// Audio Clock Mux Register
#define CCM_COSR 			0x28 	// Clock Out Source Register
#define CCM_CGR0 			0x2C 	// Clock Gating Register 0
#define CCM_CGR1 			0x30 	// Clock Gating Register 1
#define CCM_CGR2 			0x34 	// Clock Gating Register 2
#define CCM_CGR3 			0x38 	// Clock Gating Register 3
#define CCM_DCVR0			0x40 	// DPTC Comparator Value Register 0
#define CCM_DCVR1			0x44 	// DPTC Comparator Value Register 1
#define CCM_DCVR2			0x48 	// DPTC Comparator Value Register 2
#define CCM_DCVR3			0x4C 	// DPTC Comparator Value Register 3
#define CCM_LTR0			0x50 	// Load Tracking Register 0
#define CCM_LTR1			0x54 	// Load Tracking Register 1
#define CCM_LTR2			0x58 	// Load Tracking Register 2
#define CCM_LTR3			0x5C 	// Load Tracking Register 3
#define CCM_LTBR0			0x60 	// Load Tracking Buffer Register 0
#define CCM_LTBR1			0x64 	// Load Tracking Buffer Register 1
#define CCM_PMCR0			0x68 	// Power Management Control Register 0
#define CCM_PMCR1			0x6C 	// Power Management Control Register 1
#define CCM_PMCR2 			0x70 	// Power Management Control Register 2

//---------------------------------------
// UARTS
// Register Defines for MCIMX31
// additional UART defines are in mx31_uart.h
#define UART1_BASE_ADD		0x43F90000
#define UART2_BASE_ADD		0x43F94000
#define UART3_BASE_ADD		0x5000C000
#define UART1_REG(_x_)		*(vulong *)(UART1_BASE_ADD + _x_)
#define UART2_REG(_x_)		*(vulong *)(UART2_BASE_ADD + _x_)
#define UART3_REG(_x_)		*(vulong *)(UART3_BASE_ADD + _x_)

// ------------------------------------------
// WEIM - Wireless External Interface Module
// Individual bit and register defines are in mc9328mx21_mem.h
#define WEIM_BASE_ADD		0xB8002000
#define WEIM_REG(_x_)		*(vulong *)(WEIM_BASE_ADD + _x_)

// ------------------------------------------
// GPIO - General Purpose I/O
#define GPIO1_BASE_ADD      0x53FCC000
#define GPIO2_BASE_ADD      0x53FD0000
#define GPIO3_BASE_ADD      0x53FA4000
#define GPIO1_REG(_x_)		*(vulong *)(GPIO1_BASE_ADD + _x_)
#define GPIO2_REG(_x_)		*(vulong *)(GPIO2_BASE_ADD + _x_)
#define GPIO3_REG(_x_)		*(vulong *)(GPIO3_BASE_ADD + _x_)
#define GPIO_DR 			0x00 	// Data Register
#define GPIO_DIR 			0x04 	// Direction Register
#define GPIO_PSTAT 			0x08 	// Pad Status Register (read only)
#define GPIO_ICR1	 		0x0C 	// Input Configuration Register 1
#define GPIO_ICR2	 		0x10 	// Input Configuration Register 2
#define GPIO_IMASK	 		0x14 	// Interrupt Mask Register
#define GPIO_ISTAT	 		0x18 	// Interrupt Status Register
#define GPIO_EDGE_SEL 		0x1C 	// Interrupt Status Register

//---------------------------------------
// IPU - Image Processing Unit
// additional IPU defines are in mx31_lcd.h
#define IPU_BASE_ADD		0x53FC0000
#define IPU_REG(_x_)		*(vulong *)(IPU_BASE_ADD + _x_)
#define IPU_MAP(_x_)		*(vulong *)(IPU_BASE_ADD + 0x800 + _x_)

/*********************************************************************
*
* Fast Ethernet Controller (FEC)
*
*********************************************************************/

/* Register read/write macros */
#define MCF_FEC_EIR                   (*(vuint32*)(0x50038004))
#define MCF_FEC_EIMR                  (*(vuint32*)(0x50038008))
#define MCF_FEC_RDAR                  (*(vuint32*)(0x50038010))
#define MCF_FEC_TDAR                  (*(vuint32*)(0x50038014))
#define MCF_FEC_ECR                   (*(vuint32*)(0x50038024))
#define MCF_FEC_MMFR                  (*(vuint32*)(0x50038040))
#define MCF_FEC_MSCR                  (*(vuint32*)(0x50038044))
#define MCF_FEC_MIBC                  (*(vuint32*)(0x50038064))
#define MCF_FEC_RCR                   (*(vuint32*)(0x50038084))
#define MCF_FEC_TCR                   (*(vuint32*)(0x500380C4))
#define MCF_FEC_PALR                  (*(vuint32*)(0x500380E4))
#define MCF_FEC_PAUR                  (*(vuint32*)(0x500380E8))
#define MCF_FEC_OPD                   (*(vuint32*)(0x500380EC))
#define MCF_FEC_IAUR                  (*(vuint32*)(0x50038118))
#define MCF_FEC_IALR                  (*(vuint32*)(0x5003811C))
#define MCF_FEC_GAUR                  (*(vuint32*)(0x50038120))
#define MCF_FEC_GALR                  (*(vuint32*)(0x50038124))
#define MCF_FEC_TFWR                  (*(vuint32*)(0x50038144))
#define MCF_FEC_FRBR                  (*(vuint32*)(0x5003814C))
#define MCF_FEC_FRSR                  (*(vuint32*)(0x50038150))
#define MCF_FEC_ERDSR                 (*(vuint32*)(0x50038180))
#define MCF_FEC_ETDSR                 (*(vuint32*)(0x50038184))
#define MCF_FEC_EMRBR                 (*(vuint32*)(0x50038188))
#define MCF_FEC_RMON_T_DROP           (*(vuint32*)(0x50038200))
#define MCF_FEC_RMON_T_PACKETS        (*(vuint32*)(0x50038204))
#define MCF_FEC_RMON_T_BC_PKT         (*(vuint32*)(0x50038208))
#define MCF_FEC_RMON_T_MC_PKT         (*(vuint32*)(0x5003820C))
#define MCF_FEC_RMON_T_CRC_ALIGN      (*(vuint32*)(0x50038210))
#define MCF_FEC_RMON_T_UNDERSIZE      (*(vuint32*)(0x50038214))
#define MCF_FEC_RMON_T_OVERSIZE       (*(vuint32*)(0x50038218))
#define MCF_FEC_RMON_T_FRAG           (*(vuint32*)(0x5003821C))
#define MCF_FEC_RMON_T_JAB            (*(vuint32*)(0x50038220))
#define MCF_FEC_RMON_T_COL            (*(vuint32*)(0x50038224))
#define MCF_FEC_RMON_T_P64            (*(vuint32*)(0x50038228))
#define MCF_FEC_RMON_T_P65TO127       (*(vuint32*)(0x5003822C))
#define MCF_FEC_RMON_T_P128TO255      (*(vuint32*)(0x50038230))
#define MCF_FEC_RMON_T_P256TO511      (*(vuint32*)(0x50038234))
#define MCF_FEC_RMON_T_P512TO1023     (*(vuint32*)(0x50038238))
#define MCF_FEC_RMON_T_P1024TO2047    (*(vuint32*)(0x5003823C))
#define MCF_FEC_RMON_T_P_GTE2048      (*(vuint32*)(0x50038240))
#define MCF_FEC_RMON_T_OCTETS         (*(vuint32*)(0x50038244))
#define MCF_FEC_IEEE_T_DROP           (*(vuint32*)(0x50038248))
#define MCF_FEC_IEEE_T_FRAME_OK       (*(vuint32*)(0x5003824C))
#define MCF_FEC_IEEE_T_1COL           (*(vuint32*)(0x50038250))
#define MCF_FEC_IEEE_T_MCOL           (*(vuint32*)(0x50038254))
#define MCF_FEC_IEEE_T_DEF            (*(vuint32*)(0x50038258))
#define MCF_FEC_IEEE_T_LCOL           (*(vuint32*)(0x5003825C))
#define MCF_FEC_IEEE_T_EXCOL          (*(vuint32*)(0x50038260))
#define MCF_FEC_IEEE_T_MACERR         (*(vuint32*)(0x50038264))
#define MCF_FEC_IEEE_T_CSERR          (*(vuint32*)(0x50038268))
#define MCF_FEC_IEEE_T_SQE            (*(vuint32*)(0x5003826C))
#define MCF_FEC_IEEE_T_FDXFC          (*(vuint32*)(0x50038270))
#define MCF_FEC_IEEE_T_OCTETS_OK      (*(vuint32*)(0x50038274))
#define MCF_FEC_RMON_R_PACKETS        (*(vuint32*)(0x50038284))
#define MCF_FEC_RMON_R_BC_PKT         (*(vuint32*)(0x50038288))
#define MCF_FEC_RMON_R_MC_PKT         (*(vuint32*)(0x5003828C))
#define MCF_FEC_RMON_R_CRC_ALIGN      (*(vuint32*)(0x50038290))
#define MCF_FEC_RMON_R_UNDERSIZE      (*(vuint32*)(0x50038294))
#define MCF_FEC_RMON_R_OVERSIZE       (*(vuint32*)(0x50038298))
#define MCF_FEC_RMON_R_FRAG           (*(vuint32*)(0x5003829C))
#define MCF_FEC_RMON_R_JAB            (*(vuint32*)(0x500382A0))
#define MCF_FEC_RMON_R_RESVD_0        (*(vuint32*)(0x500382A4))
#define MCF_FEC_RMON_R_P64            (*(vuint32*)(0x500382A8))
#define MCF_FEC_RMON_R_P65TO127       (*(vuint32*)(0x500382AC))
#define MCF_FEC_RMON_R_P128TO255      (*(vuint32*)(0x500382B0))
#define MCF_FEC_RMON_R_P256TO511      (*(vuint32*)(0x500382B4))
#define MCF_FEC_RMON_R_512TO1023      (*(vuint32*)(0x500382B8))
#define MCF_FEC_RMON_R_P_GTE2048      (*(vuint32*)(0x500382C0))
#define MCF_FEC_RMON_R_1024TO2047     (*(vuint32*)(0x500382BC))
#define MCF_FEC_RMON_R_OCTETS         (*(vuint32*)(0x500382C4))
#define MCF_FEC_IEEE_R_DROP           (*(vuint32*)(0x500382C8))
#define MCF_FEC_IEEE_R_FRAME_OK       (*(vuint32*)(0x500382CC))
#define MCF_FEC_IEEE_R_CRC            (*(vuint32*)(0x500382D0))
#define MCF_FEC_IEEE_R_ALIGN          (*(vuint32*)(0x500382D4))
#define MCF_FEC_IEEE_R_MACERR         (*(vuint32*)(0x500382D8))
#define MCF_FEC_IEEE_R_FDXFC          (*(vuint32*)(0x500382DC))
#define MCF_FEC_IEEE_R_OCTETS_OK      (*(vuint32*)(0x500382E0))
													 	 
/* Bit definitions and macros for MCF_FEC_EIR */		 
#define MCF_FEC_EIR_UN                (0x00080000)		 
#define MCF_FEC_EIR_RL                (0x00100000)
#define MCF_FEC_EIR_LC                (0x00200000)
#define MCF_FEC_EIR_EBERR             (0x00400000)
#define MCF_FEC_EIR_MII               (0x00800000)
#define MCF_FEC_EIR_RXB               (0x01000000)
#define MCF_FEC_EIR_RXF               (0x02000000)
#define MCF_FEC_EIR_TXB               (0x04000000)
#define MCF_FEC_EIR_TXF               (0x08000000)
#define MCF_FEC_EIR_GRA               (0x10000000)
#define MCF_FEC_EIR_BABT              (0x20000000)
#define MCF_FEC_EIR_BABR              (0x40000000)
#define MCF_FEC_EIR_HBERR             (0x80000000)
#define MCF_FEC_EIR_CLEAR_ALL         (0xFFFFFFFF)

/* Bit definitions and macros for MCF_FEC_EIMR */
#define MCF_FEC_EIMR_UN               (0x00080000)
#define MCF_FEC_EIMR_RL               (0x00100000)
#define MCF_FEC_EIMR_LC               (0x00200000)
#define MCF_FEC_EIMR_EBERR            (0x00400000)
#define MCF_FEC_EIMR_MII              (0x00800000)
#define MCF_FEC_EIMR_RXB              (0x01000000)
#define MCF_FEC_EIMR_RXF              (0x02000000)
#define MCF_FEC_EIMR_TXB              (0x04000000)
#define MCF_FEC_EIMR_TXF              (0x08000000)
#define MCF_FEC_EIMR_GRA              (0x10000000)
#define MCF_FEC_EIMR_BABT             (0x20000000)
#define MCF_FEC_EIMR_BABR             (0x40000000)
#define MCF_FEC_EIMR_HBERR            (0x80000000)
#define MCF_FEC_EIMR_MASK_ALL         (0x00000000)
#define MCF_FEC_EIMR_UNMASK_ALL       (0xFFFFFFFF)

/* Bit definitions and macros for MCF_FEC_RDAR */
#define MCF_FEC_RDAR_R_DES_ACTIVE     (0x01000000)

/* Bit definitions and macros for MCF_FEC_TDAR */
#define MCF_FEC_TDAR_X_DES_ACTIVE     (0x01000000)

/* Bit definitions and macros for MCF_FEC_ECR */
#define MCF_FEC_ECR_RESET             (0x00000001)
#define MCF_FEC_ECR_ETHER_EN          (0x00000002)

/* Bit definitions and macros for MCF_FEC_MMFR */
#define MCF_FEC_MMFR_DATA(x)          (((x)&0x0000FFFF)<<0)
#define MCF_FEC_MMFR_TA(x)            (((x)&0x00000003)<<16)
#define MCF_FEC_MMFR_RA(x)            (((x)&0x0000001F)<<18)
#define MCF_FEC_MMFR_PA(x)            (((x)&0x0000001F)<<23)
#define MCF_FEC_MMFR_OP(x)            (((x)&0x00000003)<<28)
#define MCF_FEC_MMFR_ST(x)            (((x)&0x00000003)<<30)
#define MCF_FEC_MMFR_ST_01            (0x40000000)
#define MCF_FEC_MMFR_OP_READ          (0x20000000)
#define MCF_FEC_MMFR_OP_WRITE         (0x10000000)
#define MCF_FEC_MMFR_TA_10            (0x00020000)

/* Bit definitions and macros for MCF_FEC_MSCR */
#define MCF_FEC_MSCR_MII_SPEED(x)     (((x)&0x0000003F)<<1)
#define MCF_FEC_MSCR_DIS_PREAMBLE     (0x00000080)

/* Bit definitions and macros for MCF_FEC_MIBC */
#define MCF_FEC_MIBC_MIB_IDLE         (0x40000000)
#define MCF_FEC_MIBC_MIB_DISABLE      (0x80000000)

/* Bit definitions and macros for MCF_FEC_RCR */
#define MCF_FEC_RCR_LOOP              (0x00000001)
#define MCF_FEC_RCR_DRT               (0x00000002)
#define MCF_FEC_RCR_MII_MODE          (0x00000004)
#define MCF_FEC_RCR_PROM              (0x00000008)
#define MCF_FEC_RCR_BC_REJ            (0x00000010)
#define MCF_FEC_RCR_FCE               (0x00000020)
#define MCF_FEC_RCR_MAX_FL(x)         (((x)&0x000007FF)<<16)

/* Bit definitions and macros for MCF_FEC_TCR */
#define MCF_FEC_TCR_GTS               (0x00000001)
#define MCF_FEC_TCR_HBC               (0x00000002)
#define MCF_FEC_TCR_FDEN              (0x00000004)
#define MCF_FEC_TCR_TFC_PAUSE         (0x00000008)
#define MCF_FEC_TCR_RFC_PAUSE         (0x00000010)

/* Bit definitions and macros for MCF_FEC_PALR */
#define MCF_FEC_PALR_PADDR1(x)        (((x)&0xFFFFFFFF)<<0)

/* Bit definitions and macros for MCF_FEC_PAUR */
#define MCF_FEC_PAUR_TYPE(x)          (((x)&0x0000FFFF)<<0)
#define MCF_FEC_PAUR_PADDR2(x)        (((x)&0xFFFF)<<16)

/* Bit definitions and macros for MCF_FEC_OPD */
#define MCF_FEC_OPD_PAUSE_DUR(x)      (((x)&0x0000FFFF)<<0)
#define MCF_FEC_OPD_OPCODE(x)         (((x)&0x0000FFFF)<<16)

/* Bit definitions and macros for MCF_FEC_IAUR */
#define MCF_FEC_IAUR_IADDR1(x)        (((x)&0xFFFFFFFF)<<0)

/* Bit definitions and macros for MCF_FEC_IALR */
#define MCF_FEC_IALR_IADDR2(x)        (((x)&0xFFFFFFFF)<<0)

/* Bit definitions and macros for MCF_FEC_GAUR */
#define MCF_FEC_GAUR_GADDR1(x)        (((x)&0xFFFFFFFF)<<0)

/* Bit definitions and macros for MCF_FEC_GALR */
#define MCF_FEC_GALR_GADDR2(x)        (((x)&0xFFFFFFFF)<<0)

/* Bit definitions and macros for MCF_FEC_TFWR */
#define MCF_FEC_TFWR_X_WMRK(x)        (((x)&0x00000003)<<0)

/* Bit definitions and macros for MCF_FEC_FRBR */
#define MCF_FEC_FRBR_R_BOUND(x)       (((x)&0x000000FF)<<2)

/* Bit definitions and macros for MCF_FEC_FRSR */
#define MCF_FEC_FRSR_R_FSTART(x)      (((x)&0x000000FF)<<2)

/* Bit definitions and macros for MCF_FEC_ERDSR */
#define MCF_FEC_ERDSR_R_DES_START(x)  (((x)&0x3FFFFFFF)<<2)

/* Bit definitions and macros for MCF_FEC_ETDSR */
#define MCF_FEC_ETDSR_X_DES_START(x)  (((x)&0x3FFFFFFF)<<2)

/* Bit definitions and macros for MCF_FEC_EMRBR */
#define MCF_FEC_EMRBR_R_BUF_SIZE(x)   (((x)&0x0000007F)<<4)

#define MCF_FEC_TxBD_R		0x8000
#define MCF_FEC_TxBD_BUSY	0x4000
#define MCF_FEC_TxBD_TO1	0x4000
#define MCF_FEC_TxBD_W		0x2000
#define MCF_FEC_TxBD_TO2	0x1000
#define MCF_FEC_TxBD_FIRST	0x1000
#define MCF_FEC_TxBD_L		0x0800
#define MCF_FEC_TxBD_TC		0x0400
#define MCF_FEC_TxBD_DEF	0x0200
#define MCF_FEC_TxBD_HB		0x0100
#define MCF_FEC_TxBD_LC		0x0080
#define MCF_FEC_TxBD_RL		0x0040
#define MCF_FEC_TxBD_UN		0x0002
#define MCF_FEC_TxBD_CSL	0x0001
#define MCF_FEC_RxBD_E		0x8000
#define MCF_FEC_RxBD_INUSE	0x4000
#define MCF_FEC_RxBD_R01	0x4000
#define MCF_FEC_RxBD_W		0x2000
#define MCF_FEC_RxBD_R02	0x1000
#define MCF_FEC_RxBD_L		0x0800
#define MCF_FEC_RxBD_M		0x0100
#define MCF_FEC_RxBD_BC		0x0080
#define MCF_FEC_RxBD_MC		0x0040
#define MCF_FEC_RxBD_LG		0x0020
#define MCF_FEC_RxBD_NO		0x0010
#define MCF_FEC_RxBD_CR		0x0004
#define MCF_FEC_RxBD_OV		0x0002
#define MCF_FEC_RxBD_TR		0x0001


