//==========================================================================
//
// mx35_iomux.h
//
// Author(s):    Luis Torrico, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         02/20/2009
// Description:  This file contains offsets and bit defines
//				 for the MCIMX35 Software Multiplexor Control Register
//

#include "bits.h"

// Base address for Software Multiplexor Control Register (SW_MUX_CTL).
// The SW_MUX_CTL has 82 seperate registers each of which contains 4
// seperate Control Signals.  So we have to write to a total of 328
// different signals in order to set-up the MX31 to run on the Cogent platform.
#define IOMUXC_BASE_ADDR        0x43FAC000
#define IOMUX_CTL_REG(_x_)		*(vulong *)(IOMUXC_BASE_ADDR + _x_)

#define SW_MUX_CTL_PAD_CAPTURE	    0x004	// 
#define SW_MUX_CTL_PAD_COMPARE	    0x008	// 
#define SW_MUX_CTL_PAD_WDOG_RST     0x00C	// 
#define SW_MUX_CTL_PAD_GPIO1_0      0x010	// 
#define SW_MUX_CTL_PAD_GPIO1_1      0x014	// 
#define SW_MUX_CTL_PAD_GPIO2_0      0x018	// 
#define SW_MUX_CTL_PAD_GPIO3_0      0x018	// 
#define SW_MUX_CTL_PAD_CLKO         0x020	// 
#define SW_MUX_CTL_PAD_VSTBY        0x024	// 
#define SW_MUX_CTL_PAD_A0	        0x028	// 
#define SW_MUX_CTL_PAD_A1	        0x02C	// 
#define SW_MUX_CTL_PAD_A2		    0x030	// 
#define SW_MUX_CTL_PAD_A3			0x034
#define SW_MUX_CTL_PAD_A4			0x038
#define SW_MUX_CTL_PAD_A5			0x03C
#define SW_MUX_CTL_PAD_A6			0x040
#define SW_MUX_CTL_PAD_A7			0x044
#define SW_MUX_CTL_PAD_A8			0x048
#define SW_MUX_CTL_PAD_A9			0x04C
#define SW_MUX_CTL_PAD_A10			0x050
#define SW_MUX_CTL_PAD_MA10			0x054
#define SW_MUX_CTL_PAD_A11			0x058
#define SW_MUX_CTL_PAD_A12			0x05C
#define SW_MUX_CTL_PAD_A13			0x060
#define SW_MUX_CTL_PAD_A14			0x064
#define SW_MUX_CTL_PAD_A15			0x068
#define SW_MUX_CTL_PAD_A16			0x06C
#define SW_MUX_CTL_PAD_A17			0x070
#define SW_MUX_CTL_PAD_A18			0x074
#define SW_MUX_CTL_PAD_A19			0x078
#define SW_MUX_CTL_PAD_A20			0x07C
#define SW_MUX_CTL_PAD_A21			0x080
#define SW_MUX_CTL_PAD_A22			0x084
#define SW_MUX_CTL_PAD_A23			0x088
#define SW_MUX_CTL_PAD_A24			0x08C
#define SW_MUX_CTL_PAD_A25			0x090
#define SW_MUX_CTL_PAD_EB0	        0x094
#define SW_MUX_CTL_PAD_EB1	        0x098
#define SW_MUX_CTL_PAD_OE	        0x09C
#define SW_MUX_CTL_PAD_CS0	        0x0A0
#define SW_MUX_CTL_PAD_CS1	        0x0A4
#define SW_MUX_CTL_PAD_CS2	        0x0A8
#define SW_MUX_CTL_PAD_CS3		    0x0AC
#define SW_MUX_CTL_PAD_CS4	        0x0B0
#define SW_MUX_CTL_PAD_CS5          0x0B4
#define SW_MUX_CTL_PAD_NF_CE0       0x0B8
#define SW_MUX_CTL_PAD_LBA			0x0BC
#define SW_MUX_CTL_PAD_BCLK			0x0C0
#define SW_MUX_CTL_PAD_RW			0x0C4
#define SW_MUX_CTL_PAD_NFWE_B       0x0C8
#define SW_MUX_CTL_PAD_NFRE_B       0x0CC
#define SW_MUX_CTL_PAD_NFALE        0x0D0
#define SW_MUX_CTL_PAD_NFCLE		0x0D4
#define SW_MUX_CTL_PAD_NFWP_B       0x0D8
#define SW_MUX_CTL_PAD_NFRB	        0x0DC
#define SW_MUX_CTL_PAD_CSI_D8       0x0E0
#define SW_MUX_CTL_PAD_CSI_D9       0x0E4
#define SW_MUX_CTL_PAD_CSI_D10      0x0E8
#define SW_MUX_CTL_PAD_CSI_D11      0x0EC
#define SW_MUX_CTL_PAD_CSI_D12      0x0F0
#define SW_MUX_CTL_PAD_CSI_D13      0x0F4
#define SW_MUX_CTL_PAD_CSI_D14      0x0F8
#define SW_MUX_CTL_PAD_CSI_D15      0x0FC
#define SW_MUX_CTL_PAD_CSI_MCLK     0x100
#define SW_MUX_CTL_PAD_CSI_VSYNC    0x104
#define SW_MUX_CTL_PAD_CSI_HSYNC    0x108
#define SW_MUX_CTL_PAD_CSI_PIXCLK   0x10C
#define SW_MUX_CTL_PAD_I2C1_CLK     0x110
#define SW_MUX_CTL_PAD_I2C1_DAT     0x114
#define SW_MUX_CTL_PAD_I2C2_CLK     0x118
#define SW_MUX_CTL_PAD_I2C2_DAT     0x11C
#define SW_MUX_CTL_PAD_STXD4        0x120
#define SW_MUX_CTL_PAD_SRXD4        0x124
#define SW_MUX_CTL_PAD_SCK4         0x128
#define SW_MUX_CTL_PAD_STXFS4       0x12C
#define SW_MUX_CTL_PAD_STXD5        0x130
#define SW_MUX_CTL_PAD_SRXD5        0x134
#define SW_MUX_CTL_PAD_SCK5         0x138
#define SW_MUX_CTL_PAD_STXFS5       0x13C
#define SW_MUX_CTL_PAD_SCKR         0x140
#define SW_MUX_CTL_PAD_FSR          0x144
#define SW_MUX_CTL_PAD_HCKR         0x148
#define SW_MUX_CTL_PAD_SCKT         0x14C
#define SW_MUX_CTL_PAD_FST          0x150
#define SW_MUX_CTL_PAD_HCKT         0x154
#define SW_MUX_CTL_PAD_TX5_RX0      0x158
#define SW_MUX_CTL_PAD_TX4_RX1      0x15C
#define SW_MUX_CTL_PAD_TX3_RX2      0x160
#define SW_MUX_CTL_PAD_TX2_RX3      0x164
#define SW_MUX_CTL_PAD_TX1			0x168
#define SW_MUX_CTL_PAD_TX0			0x16C
#define SW_MUX_CTL_PAD_CSPI1_MOSI   0x170
#define SW_MUX_CTL_PAD_CSPI1_MISO   0x174
#define SW_MUX_CTL_PAD_CSPI1_SS0    0x178
#define SW_MUX_CTL_PAD_CSPI1_SS1    0x17C
#define SW_MUX_CTL_PAD_CSPI1_SCLK   0x180
#define SW_MUX_CTL_PAD_CSPI1_SPI_RDY	0x184
#define SW_MUX_CTL_PAD_RXD1         0x188
#define SW_MUX_CTL_PAD_TXD1         0x18C
#define SW_MUX_CTL_PAD_RTS1         0x190
#define SW_MUX_CTL_PAD_CTS1         0x194
#define SW_MUX_CTL_PAD_RXD2         0x198
#define SW_MUX_CTL_PAD_TXD2         0x19C
#define SW_MUX_CTL_PAD_RTS2         0x1A0
#define SW_MUX_CTL_PAD_CTS2         0x1A4
#define SW_MUX_CTL_PAD_USBOTG_PWR   0x1A8
#define SW_MUX_CTL_PAD_USBOTG_OC    0x1AC
#define SW_MUX_CTL_PAD_LD0	        0x1B0
#define SW_MUX_CTL_PAD_LD1	        0x1B4
#define SW_MUX_CTL_PAD_LD2		    0x1B8
#define SW_MUX_CTL_PAD_LD3 	        0x1BC
#define SW_MUX_CTL_PAD_LD4          0x1C0
#define SW_MUX_CTL_PAD_LD5	        0x1C4
#define SW_MUX_CTL_PAD_LD6	        0x1C8
#define SW_MUX_CTL_PAD_LD7	        0x1CC
#define SW_MUX_CTL_PAD_LD8	        0x1D0
#define SW_MUX_CTL_PAD_LD9	        0x1D4
#define SW_MUX_CTL_PAD_LD10	        0x1D8
#define SW_MUX_CTL_PAD_LD11         0x1DC
#define SW_MUX_CTL_PAD_LD12         0x1E0
#define SW_MUX_CTL_PAD_LD13         0x1E4
#define SW_MUX_CTL_PAD_LD14         0x1E8
#define SW_MUX_CTL_PAD_LD15         0x1EC
#define SW_MUX_CTL_PAD_LD16         0x1F0
#define SW_MUX_CTL_PAD_LD17         0x1F4
#define SW_MUX_CTL_PAD_LD18         0x1F8
#define SW_MUX_CTL_PAD_LD19         0x1FC
#define SW_MUX_CTL_PAD_LD20         0x200
#define SW_MUX_CTL_PAD_LD21         0x204
#define SW_MUX_CTL_PAD_LD22         0x208
#define SW_MUX_CTL_PAD_LD23         0x20C
#define SW_MUX_CTL_PAD_D3_HSYNC     0x210
#define SW_MUX_CTL_PAD_D3_FPSHIFT   0x214
#define SW_MUX_CTL_PAD_D3_DRDY      0x218
#define SW_MUX_CTL_PAD_CONTRAST     0x21C
#define SW_MUX_CTL_PAD_D3_VSYNC     0x220
#define SW_MUX_CTL_PAD_D3_REV       0x224
#define SW_MUX_CTL_PAD_D3_CLS       0x228
#define SW_MUX_CTL_PAD_D3_SPL       0x22C
#define SW_MUX_CTL_PAD_SD1_CMD      0x230
#define SW_MUX_CTL_PAD_SD1_CLK      0x234
#define SW_MUX_CTL_PAD_SD1_DATA0    0x238
#define SW_MUX_CTL_PAD_SD1_DATA1    0x23C
#define SW_MUX_CTL_PAD_SD1_DATA2    0x240
#define SW_MUX_CTL_PAD_SD1_DATA3    0x244
#define SW_MUX_CTL_PAD_SD2_CMD      0x248
#define SW_MUX_CTL_PAD_SD2_CLK      0x24C
#define SW_MUX_CTL_PAD_SD2_DATA0    0x250
#define SW_MUX_CTL_PAD_SD2_DATA1    0x254
#define SW_MUX_CTL_PAD_SD2_DATA2    0x258
#define SW_MUX_CTL_PAD_SD2_DATA3    0x25C
#define SW_MUX_CTL_PAD_ATA_CS0      0x260
#define SW_MUX_CTL_PAD_ATA_CS1      0x264
#define SW_MUX_CTL_PAD_ATA_DIOR     0x268
#define SW_MUX_CTL_PAD_ATA_DIOW     0x26C
#define SW_MUX_CTL_PAD_ATA_DMACK    0x270
#define SW_MUX_CTL_PAD_ATA_RESET_B  0x274
#define SW_MUX_CTL_PAD_ATA_IORDY    0x278
#define SW_MUX_CTL_PAD_ATA_DATA0    0x27C
#define SW_MUX_CTL_PAD_ATA_DATA1    0x280
#define SW_MUX_CTL_PAD_ATA_DATA2    0x284
#define SW_MUX_CTL_PAD_ATA_DATA3    0x288
#define SW_MUX_CTL_PAD_ATA_DATA4    0x28C
#define SW_MUX_CTL_PAD_ATA_DATA5    0x290
#define SW_MUX_CTL_PAD_ATA_DATA6    0x294
#define SW_MUX_CTL_PAD_ATA_DATA7    0x298
#define SW_MUX_CTL_PAD_ATA_DATA8    0x29C
#define SW_MUX_CTL_PAD_ATA_DATA9    0x2A0
#define SW_MUX_CTL_PAD_ATA_DATA10   0x2A4
#define SW_MUX_CTL_PAD_ATA_DATA11   0x2A8
#define SW_MUX_CTL_PAD_ATA_DATA12   0x2AC
#define SW_MUX_CTL_PAD_ATA_DATA13   0x2B0
#define SW_MUX_CTL_PAD_ATA_DATA14   0x2B4
#define SW_MUX_CTL_PAD_ATA_DATA15   0x2B8
#define SW_MUX_CTL_PAD_ATA_INTRQ    0x2BC
#define SW_MUX_CTL_PAD_ATA_BUFF_EN  0x2C0
#define SW_MUX_CTL_PAD_ATA_DMARQ    0x2C4
#define SW_MUX_CTL_PAD_ATA_DA0		0x2C8
#define SW_MUX_CTL_PAD_ATA_DA1		0x2CC
#define SW_MUX_CTL_PAD_ATA_DA2		0x2D0
#define SW_MUX_CTL_PAD_MLB_CLK		0x2D4
#define _SW_MUX_CTL_PAD_MLB_DAT		0x2D8
#define SW_MUX_CTL_PAD_MLB_SIG	    0x2DC
#define SW_MUX_CTL_PAD_FEC_TX_CLK   0x2E0
#define SW_MUX_CTL_PAD_FEC_RX_CLK   0x2E4
#define SW_MUX_CTL_PAD_FEC_RX_DV    0x2E8
#define SW_MUX_CTL_PAD_FEC_COL	    0x2EC
#define SW_MUX_CTL_PAD_FEC_RDATA0   0x2F0
#define SW_MUX_CTL_PAD_FEC_TDATA0   0x2F4
#define SW_MUX_CTL_PAD_FEC_TX_EN    0x2F8
#define SW_MUX_CTL_PAD_FEC_MDC	    0x2FC
#define SW_MUX_CTL_PAD_FEC_MDIO	    0x300
#define SW_MUX_CTL_PAD_FEC_TX_ERR   0x304
#define SW_MUX_CTL_PAD_FEC_RX_ERR   0x308
#define SW_MUX_CTL_PAD_FEC_CRS	    0x30C
#define SW_MUX_CTL_PAD_FEC_RDATA1   0x310
#define SW_MUX_CTL_PAD_FEC_TDATA1   0x314
#define SW_MUX_CTL_PAD_FEC_RDATA2   0x318
#define SW_MUX_CTL_PAD_FEC_TDATA2   0x31C
#define SW_MUX_CTL_PAD_FEC_RDATA3   0x320
#define SW_MUX_CTL_PAD_FEC_TDATA3   0x324
#define SW_PAD_CTL_PAD_FEC_TX_CLK	0x744
#define SW_PAD_CTL_PAD_FEC_RX_CLK	0x748
#define SW_PAD_CTL_PAD_FEC_RX_DV	0x74c
#define SW_PAD_CTL_PAD_FEC_COL		0x750
#define SW_PAD_CTL_PAD_FEC_RDATA0	0x754
#define SW_PAD_CTL_PAD_FEC_TDATA0	0x758
#define SW_PAD_CTL_PAD_FEC_TX_EN	0x75c
#define SW_PAD_CTL_PAD_FEC_MDC		0x760
#define SW_PAD_CTL_PAD_FEC_MDIO		0x764
#define SW_PAD_CTL_PAD_FEC_TX_ERR	0x768
#define SW_PAD_CTL_PAD_FEC_RX_ERR	0x76c
#define SW_PAD_CTL_PAD_FEC_CRS		0x770
#define SW_PAD_CTL_PAD_FEC_RDATA1	0x774
#define SW_PAD_CTL_PAD_FEC_TDATA1	0x778
#define SW_PAD_CTL_PAD_FEC_RDATA2	0x77c
#define SW_PAD_CTL_PAD_FEC_TDATA2	0x780
#define SW_PAD_CTL_PAD_FEC_RDATA3	0x784
#define SW_PAD_CTL_PAD_FEC_TDATA3	0x788

// Function Input Muxes
#define GPIO3_IPP_IND_G_IN_5_SELECT_INPUT   0x908
#define UART3_RXD_MUX_SELECT_INPUT   0x9A0















// General Purpose Register Bit Defines
#define DDR_MODE_ON_CLK0_EN		BIT31		// 1 = Enable DDR mode on CLK0 contact
#define USBH2_LOOPBACK_EN		BIT30		// 1 = Turn on sw_input_on (loopback) on some USBH2 contacts
#define USBH1_LOOPBACK_EN		BIT29		// 1 = Turn on sw_input_on (loopback) on some USBH1 contacts
#define USBOTG_LOOPBACK_EN		BIT28		// 1 = Turn on sw_input_on (loopback) on some USBOTG contacts
#define USBH1_SUS_ON_SFS6_EN	BIT27		// 1 = Enable USBH1_SUSPEND signal on SFS6 contact
#define ATA_ON_KEYPAD_EN		BIT26		// 1 = Enable ATA signals on Keypad Group contacts
#define UART5_DMA_REQ_EN		BIT25		// Selects either CSPI3 or UART5 DMA requests for events 10 and 11, 1 = UART5, 0 = CSPI1
#define	SLEW_RATE_SEL			BIT24		// 1 = Fast Slew Rate, 0 = Slow Slew Rate
#define DRIVE_STRENGTH_SEL		BIT23		// 1 = Maximum drive strength, 0 = standard or high drive strength
#define UPLL_ON_GPIO3_1_EN		BIT22		// 1 = Enable UPLL clock bypass through GPIO3_1 contact
#define SPLL_ON_GPIO3_0_EN		BIT21		// 1 = Enable SPLL clock bypass through GPIO3_0 contact
#define MSHC2_DMA_REQ_EN		BIT20		// Selects either SDHC2 or MSHC2 DMA requests, 1 = MSCHC2, 0 = SDHC2
#define MSHC1_DMA_REQ_EN		BIT19		// Selects either SDHC1 or MSHC1 DMA requests, 1 = MSCHC1, 0 = SDHC1
#define OTG_DATA_ON_UART_EN		BIT18		// 1 = Enable USBOTG_DATA[5:3] on Full UART Group contacts
#define OTG_D4_ON_DSR_DCE1_EN	BIT17		// 1 = Enable USBOTG_DATA4 on DSR_DCE1 contact
#define TAMPER_DETECT_EN		BIT16		// 1 = Enable Tamper detect logic
#define MBX_DMA_REQ_EN			BIT15		// Selects either External or MBX DMA requests, 1 = MDX, 0 = External
#define UART_DMA_REQ_EN			BIT14		// Selects either CSPI1 or UART3 DMA requests, 1 = UART3, 0 = CSPI1
#define WEIM_ON_CS3_EN			BIT13		// Selects either CSD1 or WEIM on EMI CS3 contact, 1 = CSD1, 0 = WEIM
#define WEIM_ON_CS2_EN			BIT12		// Selects either CSD0 or WEIM on EMI CS2 contact, 1 = CSD0, 0 = WEIM
#define USBH2_ON_AUDIO_EN		BIT11		// 1 = Enable USBH2 signals on AudioPort 3 and AudioPort6
#define ATA_SIG_ON_CSPI1_EN		BIT10		// 1 = Enable ATA signals on CSPI1 Group contacts
#define ATA_DATA_ON_CSPI1_EN	BIT9		// 1 = Enable ATA DATA14-15 on Timer Group contacts and DATA0-6 on CSPI1 Group contacts
#define ATA_DATA_ON_AUDIO_EN	BIT8		// 1 = Enable DATA7-10 signals of ATA on AudioPort3 and DATA11-13 on AudioPort6
#define ATA_DATA_ON_IPU_EN		BIT7		// 1 = Enable DATA0-13 signals of ATA on IPU (CSI) and DATA14-15 on I2C
#define ATA_SIG_ON_NANDF_EN		BIT6		// 1 = Enable ATA signals on NANF contacts
#define ATA_DATA_ON_NANDF_EN	BIT5		// 1 = Enable ATA DATA7-13 on NANDF contacts
#define ATA_ON_USBH2_EN			BIT4		// 1 = Enable ATA signals on USBH2 contacts
#define PWMO_ON_ATA_IORDY_EN	BIT3		// 1 = Enable ATA IORDY signal on PWMO contact
#define CSPI1_ON_UART_EN		BIT2		// 1 = Replaces Full UART Group with CSPI1 signals
#define DDR_MODE_EN				BIT1		// 1 = Forces DDR type I/O contacts to DDR mode
#define FIR_DMA_REQ_EN			BIT0		// Selects FIR or UART2 SDMA events, 1 = FIR, 0 = UART2

extern void iomux_init(void);
