//==========================================================================
//
// mx31_lcd.h
//
// Author(s):    Luis Torrico, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         05/14/2008
// Description:  This file contains register offsets and bit defines
//				 for the MCIMX31 LCD Controller
//

// The IPU is designed to support video and graphics processing functions and to
// interface with video/still image sensors and displays.
#include "bits.h"

#define IPU_CONF				0x00 		// IPU Configuration Register
#define IPU_CHA_BUF0_RDY		0x04 		// IPU Channel Buffer 0 Ready Register
#define IPU_CHA_BUF1_RDY		0x08 		// IPU Channel Buffer 1 Ready Register
#define IPU_CHA_DB_MODE_SEL		0x0C 		// IPU Channel Double Mode Select Register
#define IPU_CHA_CUR_BUF			0x10 		// IPU Channel Current Buffer
#define IPU_FS_PROC_FLOW		0x14 		// IPU Frame Synchronization Processing Flow Register
#define IPU_FS_DISP_FLOW		0x18 		// IPU Frame Synchronization Displaying Flow Register
#define IPU_TASKS_STAT			0x1C 		// IPU Tasks Status Register
#define IPU_IMA_ADDR			0x20 		// IPU Internal Memory Access Address Register
#define IPU_IMA_DATA			0x24 		// IPU Internal Memory Access Data Register
#define IPU_INT_CTRL_1			0x28 		// IPU Interrupt Control Register 1
#define IPU_INT_CTRL_2			0x2C 		// IPU Interrupt Control Register 2
#define IPU_INT_CTRL_3			0x30 		// IPU Interrupt Control Register 3
#define IPU_INT_CTRL_4			0x34 		// IPU Interrupt Control Register 4
#define IPU_INT_CTRL_5			0x38 		// IPU Interrupt Control Register 5
#define IPU_INT_STAT_1			0x3C 		// IPU Interrupt Status Register 1
#define IPU_INT_STAT_2			0x40 		// IPU Interrupt Status Register 2
#define IPU_INT_STAT_3			0x44 		// IPU Interrupt Status Register 3
#define IPU_INT_STAT_4			0x48 		// IPU Interrupt Status Register 4
#define IPU_INT_STAT_5 			0x4C 		// IPU Interrupt Status Register 5
#define IPU_BRK_CTRL_1 			0x50 		// IPU Break Control Register 1
#define IPU_BRK_CTRL_2			0x54 		// IPU Break Control Register 2
#define IPU_BRK_STAT			0x58 		// IPU Break Status Register
#define IPU_DIAGB_CTRL			0x5C 		// IPU Diagnostic Bus Control Register

#define CSI_SENS_CONF			0x60 		// CSI Sensor Configuration Register
#define CSI_SENS_FRM_SIZE		0x64 		// CSI Sensor Frame Size Register
#define CSI_ACT_FRM_SIZE		0x68 		// CSI Actual Frame Size Register
#define CSI_OUT_FRM_CTRL		0x6C 		// CSI Output Frame Control Register
#define CSI_TST_CTRL			0x70 		// CSI Test Control Register
#define CSI_CCIR_CODE_1			0x74 		// CSI CCIR Code Register 1
#define CSI_CCIR_CODE_2			0x78 		// CSI CCIR Code Register 2
#define CSI_CCIR_CODE_3			0x7C 		// CSI CCIR Code Register 3
#define CSI_FLASH_STROBE_1		0x80 		// CSI Flash Strobe Register 1
#define CSI_FLASH_STROBE_2		0x84 		// CSI Flash Strobe Register 2

#define IC_CONF					0x88 		// IC Configuration Register
#define IC_PRP_ENC_RSC			0x8C 		// IC Preprocessing Encoder Resizing Coefficients Register
#define IC_PRP_VF_RSC			0x90 		// IC Preprocessing View-Finder Resizing Coefficients Register
#define IC_PP_RSC				0x94 		// IC Post-Processing Resizing Coefficients Register
#define IC_CMBP_1				0x98 		// IC Combining Parameters Register 1
#define IC_CMBP_2				0x9C 		// IC Combining Parameters Register 2
#define PF_CONF					0xA0 		// Post Filter Configuration Register
#define IDMAC_CONF				0xA4 		// IDMAC Configuration Register
#define IDMAC_CHA_EN			0xA8 		// IDMAC Channel Enable Register
#define IDMAC_CHA_PRI			0xAC 		// IDMAC Channel Priority Register
#define IDMAC_CHA_BUSY			0xB0 		// IDMAC Channel Busy Register

#define SDC_COM_CONF			0xB4 		// SDC Common Configuration Register
#define SDC_GRAPH_WIND_CTRL		0xB8 		// SDC Graphic Window Control Register
#define SDC_FG_POS				0xBC 		// SDC Foreground Window Position Register
#define SDC_BG_POS				0xC0 		// SDC Background Window Position Register
#define SDC_CUR_POS				0xC4 		// SDC Cursor Position Register
#define SDC_CUR_BLINK_PWM_CTRL	0xC8 		// SDC Cursor Blinking and PWM Contrast Control Register
#define SDC_CUR_MAP				0xCC 		// SDC Color Cursor Mapping Register
#define SDC_HOR_CONF			0xD0 		// SDC Horizontal Configuration Register
#define SDC_VER_CONF			0xD4 		// SDC Vertical Configuration Register
#define SDC_SHARP_CONF_1		0xD8 		// SDC Sharp Configuration Register 1
#define SDC_SHARP_CONF_2		0xDC 		// SDC Sharp Configuration Register 2

#define ADC_CONF				0xE0 		// ADC Configuration Register
#define ADC_SYSCHA1_SA			0xE4 		// ADC System Channel 1 Start Address Register
#define ADC_SYSCHA2_SA			0xE8 		// ADC System Channel 2 Start Address Register
#define ADC_PRPCHAN_SA			0xEC 		// ADC Pre-Processing Channel Start Address Register
#define ADC_PPCHAN_SA			0xF0 		// ADC Post-Processing Channel Start Address Register
#define ADC_DISP0_CONF			0xF4 		// ADC Display 0 Configuration Register
#define ADC_DISP0_RD_AP			0xF8 		// ADC Display 0 Read Acknowledge Pattern Register
#define ADC_DISP0_RDM			0xFC 		// ADC Display 0 Read Mask Register
#define ADC_DISP0_SS			0x100 		// ADC Display 0 Screen Size Register
#define ADC_DISP1_CONF			0x104 		// ADC Display 1 Configuration Register
#define ADC_DISP1_RD_AP			0x108 		// ADC Display 1 Read Acknowledge Pattern Register
#define ADC_DISP1_RDM			0x10C 		// ADC Display 1 Read Mask Register
#define ADC_DISP1_SS			0x110 		// ADC Display 1 Screen Size Register
#define ADC_DISP2_CONF			0x114 		// ADC Display 2 Configuration Register
#define ADC_DISP2_RD_AP			0x118 		// ADC Display 2 Read Acknowledge Pattern Register
#define ADC_DISP2_RDM			0x11C 		// ADC Display 2 Read Mask Register
#define ADC_DISP_VSYNC			0x120 		// ADC Displays Vertical Synchronization Register

#define DI_DISP_IF_CONF			0x124 		// DI Display Interface Configuration Register
#define DI_DISP_SIG_POL			0x128 		// DI Display Signals Polarity Register
#define DI_SER_DISP1_CONF		0x12C 		// DI Serial Display 1 Configuration Register
#define DI_SER_DISP2_CONF		0x130 		// DI Serial Display 2 Configuration Register
#define DI_HSP_CLK_PER			0x134 		// DI HSP_CLK Period Register
#define DI_DISP0_TIME_CONF_1	0x138 		// DI Display 0 Time Configuration Register 1
#define DI_DISP0_TIME_CONF_2	0x13C 		// DI Display 0 Time Configuration Register 2
#define DI_DISP0_TIME_CONF_3	0x140 		// DI Display 0 Time Configuration Register 3
#define DI_DISP1_TIME_CONF_1	0x144 		// DI Display 1 Time Configuration Register 1
#define DI_DISP1_TIME_CONF_2	0x148 		// DI Display 1 Time Configuration Register 2
#define DI_DISP1_TIME_CONF_3	0x14C 		// DI Display 1 Time Configuration Register 3
#define DI_DISP2_TIME_CONF_1	0x150 		// DI Display 2 Time Configuration Register 1
#define DI_DISP2_TIME_CONF_2	0x154 		// DI Display 2 Time Configuration Register 2
#define DI_DISP2_TIME_CONF_3	0x158 		// DI Display 2 Time Configuration Register 3

#define DI_DISP3_TIME_CONF		0x15C 		// DI Display 3 Time Configuration Register
#define DI_DISP0_DB0_MAP		0x160 		// DI Display 0 Byte 0 Mapping Register
#define DI_DISP0_DB1_MAP		0x164 		// DI Display 0 Byte 1 Mapping Register
#define DI_DISP0_DB2_MAP		0x168 		// DI Display 0 Byte 2 Mapping Register
#define DI_DISP0_CB0_MAP		0x16C 		// DI Display 0 Command Byte 0 Mapping Register
#define DI_DISP0_CB1_MAP		0x170 		// DI Display 0 Command Byte 1 Mapping Register
#define DI_DISP0_CB2_MAP		0x174 		// DI Display 0 Command Byte 2 Mapping Register
#define DI_DISP1_DB0_MAP		0x178 		// DI Display 1 Byte 0 Mapping Register
#define DI_DISP1_DB1_MAP		0x17C 		// DI Display 1 Byte 1 Mapping Register
#define DI_DISP1_DB2_MAP		0x180 		// DI Display 1 Byte 2 Mapping Register
#define DI_DISP1_CB0_MAP		0x184 		// DI Display 1 Command Byte 0 Mapping Register
#define DI_DISP1_CB1_MAP		0x188 		// DI Display 1 Command Byte 1 Mapping Register
#define DI_DISP1_CB2_MAP		0x18C 		// DI Display 1 Command Byte 2 Mapping Register
#define DI_DISP2_DB0_MAP		0x190 		// DI Display 2 Data Byte 0 Mapping Register
#define DI_DISP2_DB1_MAP		0x194 		// DI Display 2 Data Byte 1 Mapping Register
#define DI_DISP2_DB2_MAP		0x198 		// DI Display 2 Data Byte 2 Mapping Register
#define DI_DISP2_CB0_MAP		0x19C 		// DI Display 2 Command Byte 0 Mapping Register
#define DI_DISP2_CB1_MAP		0x1A0 		// DI Display 2 Command Byte 1 Mapping Register
#define DI_DISP2_CB2_MAP		0x1A4 		// DI Display 2 Command Byte 2 Mapping Register
#define DI_DISP3_B0_MAP			0x1A8 		// DI Display 3 Byte 0 Mapping Register
#define DI_DISP3_B1_MAP			0x1AC 		// DI Display 3 Byte 1 Mapping Register
#define DI_DISP3_B2_MAP			0x1B0 		// DI Display 3 Byte 2 Mapping Register
#define DI_DISP_ACC_CC			0x1B4 		// DI Display Access Cycles Count Register
#define DI_DISP_LLA_CONF		0x1B8 		// DI Display Low Level Access Configuration Register
#define DI_DISP_LLA_DATA		0x1BC 		// DI Display Low Level Access Data Register

// Bit defines - Refer to MCIMX31 Users Manual for more detailed information
// I do not define all the bits for all the registers in the IPU.  I am only
// defining the register bits that Micromonitor will use.  The customer will have
// to define any bits for registers that they need and are not defined here.

// IPU_CONF - IPU Configuration Register
#define IPU_CONF_PXL_ENDIAN		BIT8		// 1 = Big Endian
#define IPU_CONF_DU_EN			BIT7		// 1 = Debug Unit Enable
#define IPU_CONF_DI_EN			BIT6		// 1 = Display Interface Enable
#define IPU_CONF_ADC_EN			BIT5		// 1 = Asynchronous Display Controller enable
#define IPU_CONF_SDC_EN			BIT4		// 1 = Synchronous Display Controller enable
#define IPU_CONF_PF_EN			BIT3		// 1 = Postfilter enable
#define IPU_CONF_ROT_EN			BIT2		// 1 = Rotation Unit enable
#define IPU_CONF_IC_EN			BIT1		// 1 = Image Converter enable
#define IPU_CONF_CSI_EN			BIT0		// 1 = Camera Sensor interface enable

// IPU_CHA_BUF0_RDY - IPU Channel Buffer 0 Ready Register

// IPU_CHA_BUF1_RDY - IPU Channel Buffer 1 Ready Register

// IPU_CHA_DB_MODE_SEL - IPU Channel Double Mode Select Register

// IPU_CHA_CUR_BUF - IPU Channel Current Buffer

// IPU_FS_PROC_FLOW	- IPU Frame Synchronization Processing Flow Register

// IPU_FS_DISP_FLOW - IPU Frame Synchronization Displaying Flow Register
#define IPU_SDC1_SRC_PP			(4 << 0)		// SDC foreground channel (1) source select = Post-Processing
#define IPU_SDC1_SRC_VF			(3 << 0)		// SDC foreground channel (1) source select = View-Finder
#define IPU_SDC1_SRC_RPP		(2 << 0)		// SDC foreground channel (1) source select = Rotation for Post-Processing
#define IPU_SDC1_SRC_RVF		(1 << 0)		// SDC foreground channel (1) source select = Rotation for View-Finder
#define IPU_SDC1_SRC_MCU		(0 << 0)		// SDC foreground channel (1) source select = MCU
#define IPU_SDC0_SRC_PP			(4 << 0)		// SDC background channel (0) source select = Post-Processing
#define IPU_SDC0_SRC_VF			(3 << 0)		// SDC background channel (0) source select = View-Finder
#define IPU_SDC0_SRC_RPP		(2 << 0)		// SDC background channel (0) source select = Rotation for Post-Processing
#define IPU_SDC0_SRC_RVF		(1 << 0)		// SDC background channel (0) source select = Rotation for View-Finder
#define IPU_SDC0_SRC_MCU		(0 << 0)		// SDC background channel (0) source select = MCU

// IPU_TASKS_STAT -	IPU Tasks Status Register

// IPU_IMA_ADDR	- IPU Internal Memory Access Address Register
//#define IPU_IMA_MEM_NU_TPM		(0 << 16)				// 
//#define IPU_IMA_MEM_NU_CPM		(1 << 16)				// 
//#define IPU_IMA_MEM_NU_LUPM		(2 << 16)				// 
//#define IPU_IMA_MEM_NU_TM		(3 << 16)				// 
//#define IPU_IMA_MEM_NU_ADBM		(4 << 16)				// 
//#define IPU_IMA_MEM_NU_DOM		(5 << 16)				// 
//#define IPU_IMA_MEM_NU_DSTM		(6 << 16)				// 
//#define IPU_IMA_MEM_NU_IBM		(7 << 16)				// 
//#define IPU_IMA_MEM_NU_MPM		(8 << 16)				// 
//#define IPU_IMA_MEM_NU_RM		(9 << 16)				// 
//#define IPU_IMA_MEM_NU_PFM		(10 << 16)				// 
//#define IPU_IMA_MEM_NU_SDBM		(11 << 16)				// 
//#define IPU_IMA_ROW_NU(_x_)		((_x_ & 0x1fff) << 3)	// 
//#define IPU_IMA_WORD_NU(_x_)	((_x_ & 0x7) << 0)		// 
//
//-------------------------------------------------------------
// IPU_IMA_DATA	- IPU Internal Memory Access Data Register
//-------------------------------------------------------------
//...parameters for YUV/RGB  interleaved - 1st 132 bit word

////...0th 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_XV(_x_)       ((_x_ & 0x3ff) << 0)	// W0[9:0]
//#define IPU_IPU_IMA_DATA_PARAM_YV(_x_)       ((_x_ & 0x3ff) << 10)	// W0[19:10]
//#define IPU_IPU_IMA_DATA_PARAM_XB(_x_)       ((_x_ & 0xfff) << 20)	// W0[31:20]
//
////...1st 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_YB(_x_)       ((_x_ & 0xfff) << 0)	// W0[43:32] = [11:0]
//#define IPU_IPU_IMA_DATA_PARAM_SCE	         BIT12					// W0[44] = [12]
//#define IPU_IPU_IMA_DATA_PARAM_NSB		     BIT13					// W0[45] = [13]
////  1 - reserved bit													// W0[46] = [14]                    
//#define IPU_IPU_IMA_DATA_PARAM_LNPB(_x_)     ((_x_ & 0x3f) << 15)	// W0[52:47] = [20:15]
//#define IPU_IPU_IMA_DATA_PARAM_SX(_x_)       ((_x_ & 0x3ff) << 21)	// W0[62:53] = [30:21]
//#define IPU_IPU_IMA_DATA_PARAM_LOW_SY		 BIT31					// W0[63] = [31]
//
////...2nd 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_HIGH_SY(_x_)  ((_x_ & 0x1ff) << 0)	// W0[72:64] = [8:0]
//#define IPU_IPU_IMA_DATA_PARAM_NS(_x_)       ((_x_ & 0x3ff) << 9)	// W0[82:73] = [18:9]
//#define IPU_IPU_IMA_DATA_PARAM_SM(_x_)       ((_x_ & 0x3ff) << 19)	// W0[92:83] = [28:19]
//#define IPU_IPU_IMA_DATA_PARAM_LOW_SDX(_x_)  ((_x_ & 0x7) << 29)		// W0[95:93] = [31:29]
//
////...3rd 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_HIGH_SDX(_x_) ((_x_ & 0x3) << 0)		// W0[97:96] = [1:0]
//#define IPU_IPU_IMA_DATA_PARAM_SDY(_x_)      ((_x_ & 0x3) << 2)		// W0[102:98] = [6:2]
//#define IPU_IPU_IMA_DATA_PARAM_SDRX		     BIT7					// W0[103] = [7]
//#define IPU_IPU_IMA_DATA_PARAM_SDRY			 BIT8					// W0[104] = [8]
//#define IPU_IPU_IMA_DATA_PARAM_SCRQ			 BIT9					// W0[105] = [9]
////  2 - reserved bits													// W0[107:106] = [11:10]
//#define IPU_IPU_IMA_DATA_PARAM_FW(_x_)       ((_x_ & 0xfff) << 12)	// W0[119:108] = [23:12]
//#define IPU_IPU_IMA_DATA_PARAM_LOW_FH(_x_)   ((_x_ & 0xff) << 24)	// W0[127:120] = [31:24]
//
////...4th 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_HIGH_FH(_x_)  ((_x_ & 0xf) << 0)		// W0[131:128] = [3:0]
//
////...parameters for YUV/RGB interleaved - 2nd 132 bit word
//
////...0th 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_EBA0(_x_)     ((_x_ & 0xffffffff) << 0)	// W0[31:0] = [31:0]
//
////...1st 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_EBA1(_x_)     ((_x_ & 0xffffffff) << 0)	// W0[63:32] = [31:0]
//
////...2nd 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_BPP(_x_)      ((_x_ & 0x7) << 0)			// W0[66:64] = [2:0]
//#define IPU_IPU_IMA_DATA_PARAM_SL(_x_)       ((_x_ & 0x3fff) << 3)		// W0[80:67] = [16:3]
//#define IPU_IPU_IMA_DATA_PARAM_PFS(_x_)      ((_x_ & 0x7) << 17)			// W0[83:81] = [19:17]
//#define IPU_IPU_IMA_DATA_PARAM_BAM(_x_)      ((_x_ & 0x7) << 20)			// W0[86:84] = [22:20]
////  2 - reserved bits														// W0[88:87] = [24:23]
//#define IPU_IPU_IMA_DATA_PARAM_NPB(_x_)      ((_x_ & 0x3f) << 25)		// W0[94:89] = [30:25]
////  1 - reserved bit														// W0[95] = [31]                    
//
////...3rd 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_SAT(_x_)      ((_x_ & 0x3) << 0)			// W0[97:96] = [1:0]
//#define IPU_IPU_IMA_DATA_PARAM_SCC			 BIT2						// W0[98] = [2]
//#define IPU_IPU_IMA_DATA_PARAM_OFS0(_x_)     ((_x_ & 0x1f) << 3)			// W0[103:99] = [7:3]
//#define IPU_IPU_IMA_DATA_PARAM_OFS1(_x_)     ((_x_ & 0x1f) << 8)			// W0[108:104] = [12:8]
//#define IPU_IPU_IMA_DATA_PARAM_OFS2(_x_)     ((_x_ & 0x1f) << 13)		// W0[113:109] = [17:13]
//#define IPU_IPU_IMA_DATA_PARAM_OFS3(_x_)     ((_x_ & 0x1f) << 18)		// W0[118:114] = [22:18]
//#define IPU_IPU_IMA_DATA_PARAM_WID0(_x_)     ((_x_ & 0x7) << 23)			// W0[121:119] = [25:23]
//#define IPU_IPU_IMA_DATA_PARAM_WID1(_x_)     ((_x_ & 0x7) << 26)			// W0[124:122] = [28:26]
//#define IPU_IPU_IMA_DATA_PARAM_WID2(_x_)     ((_x_ & 0x7) << 29)			// W0[127:125] = [31:29]
//
////...4th 32 bit word
//#define IPU_IPU_IMA_DATA_PARAM_WID3(_x_)     ((_x_ & 0x7) << 0)			// W0[130:128] = [2:0]
//#define IPU_IPU_IMA_DATA_PARAM_DEC_SEL		 BIT3						// W0[131] = [3]
//-------------------------------------------------------------
// 
//-------------------------------------------------------------

// IPU_INT_CTRL_1 - IPU Interrupt Control Register 1

// IPU_INT_CTRL_2 -	IPU Interrupt Control Register 2

// IPU_INT_CTRL_3 -	IPU Interrupt Control Register 3

// IPU_INT_CTRL_4 - IPU Interrupt Control Register 4

// IPU_INT_CTRL_5 -	IPU Interrupt Control Register 5

// IPU_INT_STAT_1 -	IPU Interrupt Status Register 1

// IPU_INT_STAT_2 -	IPU Interrupt Status Register 2

// IPU_INT_STAT_3 -	IPU Interrupt Status Register 3

// IPU_INT_STAT_4 -	IPU Interrupt Status Register 4

// IPU_INT_STAT_5 -	IPU Interrupt Status Register 5

// IPU_BRK_CTRL_1 -	IPU Break Control Register 1

// IPU_BRK_CTRL_2 -	IPU Break Control Register 2

// IPU_BRK_STAT	- IPU Break Status Register

// IPU_DIAGB_CTRL - IPU Diagnostic Bus Control Register

// CSI_SENS_CONF - CSI Sensor Configuration Register

// CSI_SENS_FRM_SIZE - CSI Sensor Frame Size Register

// CSI_ACT_FRM_SIZE - CSI Actual Frame Size Register

// CSI_OUT_FRM_CTRL - CSI Output Frame Control Register

// CSI_TST_CTRL - CSI Test Control Register

// CSI_CCIR_CODE_1 - CSI CCIR Code Register 1

// CSI_CCIR_CODE_2 - CSI CCIR Code Register 2

// CSI_CCIR_CODE_3 - CSI CCIR Code Register 3

// CSI_FLASH_STROBE_1 - CSI Flash Strobe Register 1

// CSI_FLASH_STROBE_2 - CSI Flash Strobe Register 2

// IC_CONF - IC Configuration Register

// IC_PRP_ENC_RSC - IC Preprocessing Encoder Resizing Coefficients Register

// IC_PRP_VF_RSC - IC Preprocessing View-Finder Resizing Coefficients Register

// IC_PP_RSC - IC Post-Processing Resizing Coefficients Register

// IC_CMBP_1 - IC Combining Parameters Register 1

// IC_CMBP_2 - IC Combining Parameters Register 2

// PF_CONF - Post Filter Configuration Register

// IDMAC_CONF - IDMAC Configuration Register
#define IDMAC_SIN_AHB_M_EN		BIT8			// 1 = Single Master AHB enabled
#define IDMAC_SRCNT_1			(0 << 4)		// 1 consecutive request
#define IDMAC_SRCNT_2			(1 << 4)		// 2 consecutive request
#define IDMAC_SRCNT_3			(2 << 4)		// 3 consecutive request
#define IDMAC_SRCNT_4			(3 << 4)		// 4 consecutive request
#define IDMAC_SRCNT_5			(4 << 4)		// 5 consecutive request
#define IDMAC_SRCNT_6			(5 << 4)		// 6 consecutive request
#define IDMAC_SRCNT_7			(6 << 4)		// 7 consecutive request
#define IDMAC_SRCNT_8			(7 << 4)		// 8 consecutive request
#define IDMAC_PRYM_RR			(0 << 0)		// 6 consecutive request
#define IDMAC_PRYM_RANDOM		(1 << 0)		// 7 consecutive request
#define IDMAC_PRYM_RAW			(2 << 0)		// 8 consecutive request

// IDMAC_CHA_EN	- IDMAC Channel Enable Register

// IDMAC_CHA_PRI - IDMAC Channel Priority Register
#define DMASDC_3_PRI			BIT17		// 1 = SDC_3 has high priority
#define DMASDC_2_PRI			BIT16		// 1 = SDC_2 has high priority
#define DMASDC_1_PRI			BIT15		// 1 = SDC_1 has high priority
#define DMASDC_0_PRI			BIT14		// 1 = SDC_0 has high priority

// IDMAC_CHA_BUSY - IDMAC Channel Busy Register

// SDC_COM_CONF	- SDC Common Configuration Register
#define SDC_CONF_COC_DIS		(0 << 16)	// Transparent, cursor is disabled
#define SDC_CONF_COC_FULL		(1 << 16)	// Full cursor
#define SDC_CONF_COC_REV		(2 << 16)	// Reversed cursor
#define SDC_CONF_COC_AND		(3 << 16)	// AND between background and cursor
#define SDC_CONF_COC_OR			(5 << 16)	// OR between background and cursor
#define SDC_CONF_COC_XOR		(6 << 16)	// XOR between background and cursor
#define SDC_CONF_DUAL_MODE		BIT15		// 1 = Enable dual mode
#define SDC_CONF_SAVE_REFR_EN	BIT14		// 1 = Enable saving refresh
#define SDC_CONF_SHARP			BIT12		// 1 = Enable Sharp signals
#define SDC_CONF_BG_EN			BIT9		// 1 = Background channel is enabled
#define SDC_CONF_MASK_EN		BIT8		// 1 = Mask channel is enabled
#define SDC_CONF_KEY_CLR_EN		BIT7		// 1 = Enable color keying of graphic window
#define SDC_CONF_GLB_LOC_A		BIT6		// 1 = Global alpha
#define SDC_CONF_GWSEL			BIT5		// 1 = Graphic window is foreground
#define SDC_CONF_FG_EN			BIT4		// 1 = Foreground channel enable
#define SDC_CONF_FG_MCP_FORM	BIT3		// 1 = Foreground format is 16bpp in TFT Mono only
#define SDC_CONF_BG_MCP_FORM	BIT2		// 1 = Background format is 16bpp in TFT Mono only
#define SDC_CONF_MONO_MODE		(0 << 0)	// TFT Monochrome
#define SDC_CONF_COLOR_MODE		(1 << 0)	// TFT Color
#define SDC_CONF_YUVP_MODE		(2 << 0)	// YUV Progressive
#define SDC_CONF_YUVI_MODE		(3 << 0)	// YUV Interlaced

// SDC_GRAPH_WIND_CTRL - SDC Graphic Window Control Register

// SDC_FG_POS - SDC Foreground Window Position Register
#define SDC_FGXP(_x_)	((_x_ & 0x3ff) << 16)		// Forground window X position
#define SDC_FGYP(_x_)	((_x_ & 0x3ff) << 0)		// Forground window Y position

// SDC_BG_POS - SDC Background Window Position Register
#define SDC_BGXP(_x_)	((_x_ & 0x3ff) << 16)		// Background window X position
#define SDC_BGYP(_x_)	((_x_ & 0x3ff) << 0)		// Background window Y position

// SDC_CUR_POS - SDC Cursor Position Register

// SDC_CUR_BLINK_PWM_CTRL -	 SDC Cursor Blinking and PWM Contrast Control Register

// SDC_CUR_MAP - SDC Color Cursor Mapping Register

// SDC_HOR_CONF	- SDC Horizontal Configuration Register
#define SDC_HSYNC_WIDTH(_x_)	((_x_ & 0x3f) << 26)	// Horizontal synchronization pulse width minus 1
#define SDC_SCREEN_WIDTH(_x_)	((_x_ & 0x3ff) << 16)	// Screen width minus 1
#define SDC_HSYNC_DELAY(_x_)	((_x_ & 0xf) << 0)		// Horizontal synchronization pulse delay

// SDC_VER_CONF	- SDC Vertical Configuration Register
#define SDC_VSYNC_WIDTH(_x_)	((_x_ & 0x3f) << 26)	// Vertical synchronization pulse width minus 1
#define SDC_SCREEN_HEIGHT(_x_)	((_x_ & 0x3ff) << 16)	// Screen height minus 1
#define SDC_VSYNC_WIDTH_L		BIT0					// Vertical synchronization pulse width units 1 = in rows, 0 = in pixels

// SDC_SHARP_CONF_1	- SDC Sharp Configuration Register 1
#define SDC_REVTOG_DELAY(_x_)	((_x_ & 0x3ff) << 16)	// REV toggle delay
#define SDC_PSFALL_DELAY(_x_)	((_x_ & 0xff) << 8)		// PS fall delay
#define SDC_CLSRISE_DELAY(_x_)	((_x_ & 0xff) << 0)		// CLS rise delay

// SDC_SHARP_CONF_2 - SDC Sharp Configuration Register 2
#define SDC_PSRISE_DELAY(_x_)	((_x_ & 0x3ff) << 16)		// PS rise delay
#define SDC_CLSFALL_DELAY(_x_)	((_x_ & 0x3ff) << 0)		// CLS fall delay

// ADC_CONF - ADC Configuration Register

// ADC_SYSCHA1_SA - ADC System Channel 1 Start Address Register

// ADC_SYSCHA2_SA - ADC System Channel 2 Start Address Register

// ADC_PRPCHAN_SA - ADC Pre-Processing Channel Start Address Register

// ADC_PPCHAN_SA - ADC Post-Processing Channel Start Address Register

// ADC_DISP0_CONF - ADC Display 0 Configuration Register

// ADC_DISP0_RD_AP - ADC Display 0 Read Acknowledge Pattern Register

// ADC_DISP0_RDM - ADC Display 0 Read Mask Register

// ADC_DISP0_SS	- ADC Display 0 Screen Size Register

// ADC_DISP1_CONF - ADC Display 1 Configuration Register

// ADC_DISP1_RD_AP - ADC Display 1 Read Acknowledge Pattern Register

// ADC_DISP1_RDM - ADC Display 1 Read Mask Register

// ADC_DISP1_SS	- ADC Display 1 Screen Size Register

// ADC_DISP2_CONF - ADC Display 2 Configuration Register

// ADC_DISP2_RD_AP - ADC Display 2 Read Acknowledge Pattern Register

// ADC_DISP2_RDM - ADC Display 2 Read Mask Register

// ADC_DISP_VSYNC - ADC Displays Vertical Synchronization Register

// DI_DISP_IF_CONF - DI Display Interface Configuration Register
#define DI_CONF_D012_DCLK_NUM(_x_)	((_x_ & 0xF) << 27)	// Number of dead clock cycles
#define DI_CONF_D3_CLK_IDLE_DIS		BIT26				// 1 = Disable clock
#define DI_CONF_D3_CLK_SEL_DIS		BIT25				// 1 = Disable clock when no data output
#define DI_CONF_D3_DATAMASK_0		BIT24				// 1 = Data always equals 0
#define DI_CONF_D2_PB_MODE(_x_)		((_x_ & 0x3) << 20)	// Display 2 parallel interface burst mode
#define DI_CONF_D2_MODE(_x_)		((_x_ & 0x3) << 17)	// Display 2 interface mode
#define DI_CONF_D2_EN				BIT16				// 1 = Display 2 Enable
#define DI_CONF_D1_PB_MODE(_x_)		((_x_ & 0x3) << 12)	// Display 1 parallel interface burst mode
#define DI_CONF_D1_MODE(_x_)		((_x_ & 0x3) << 9)	// Display 1 interface mode
#define DI_CONF_D1_EN				BIT8				// 1 = Display 1 Enable
#define DI_CONF_D0_PB_MODE(_x_)		((_x_ & 0x3) << 3)	// Display 0 parallel interface burst mode
#define DI_CONF_D0_MODE(_x_)		((_x_ & 0x3) << 1)	// Display 0 interface mode
#define DI_CONF_D0_EN				BIT0				// 1 = Display 0 Enable

// DI_DISP_SIG_POL - DI Display Signals Polarity Register
#define DI_SIG_D2_BCLK_I_POL		BIT31	// 1 = Inverse Polarity
#define DI_SIG_D1_BCLK_I_POL		BIT30	// 1 = Inverse Polarity
#define DI_SIG_D0_BCLK_I_POL		BIT29	// 1 = Inverse Polarity
#define DI_SIG_D3_VSYNC_H_POL		BIT28	// 1 = Active High
#define DI_SIG_D3_HSYNC_H_POL		BIT27	// 1 = Active High
#define DI_SIG_D3_SHARP_H_POL		BIT26	// 1 = Active High
#define DI_SIG_D3_CS_I_POL			BIT25	// 1 = Inverse Polarity
#define DI_SIG_D3_DATA_I_POL		BIT24	// 1 = Inverse Polarity
#define DI_SIG_D2_SER_RS_I_POL		BIT23	// 1 = Inverse Polarity
#define DI_SIG_D2_SD_CLK_I_POL		BIT22	// 1 = Inverse Polarity
#define DI_SIG_D2_SD_D_I_POL		BIT21	// 1 = Inverse Polarity
#define DI_SIG_D2_RD_H_I_POL		BIT20	// 1 = Active High
#define DI_SIG_D2_WR_H_POL			BIT19	// 1 = Active High
#define DI_SIG_D2_PAR_RS_I_POL		BIT18	// 1 = Inverse Polarity
#define DI_SIG_D2_CS_H_POL			BIT17	// 1 = Active High
#define DI_SIG_D2_DATA_I_POL		BIT16	// 1 = Inverse Polarity
#define DI_SIG_D1_SER_RS_I_POL		BIT15	// 1 = Inverse Polarity
#define DI_SIG_D1_SD_CLK_I_POL		BIT14	// 1 = Inverse Polarity
#define DI_SIG_D1_SD_D_I_POL		BIT13	// 1 = Inverse Polarity
#define DI_SIG_D1_RD_H_POL			BIT12	// 1 = Active High
#define DI_SIG_D1_WR_H_POL			BIT11	// 1 = Active High
#define DI_SIG_D1_PAR_RS_I_POL		BIT10	// 1 = Inverse Polarity
#define DI_SIG_D1_CS_H_POL			BIT9	// 1 = Active High
#define DI_SIG_D1_DATA_I_POL		BIT8	// 1 = Inverse Polarity
#define DI_SIG_D12_VSYNC_H_POL		BIT6	// 1 = Active High
#define DI_SIG_D0_VSYNC_H_POL		BIT5	// 1 = Active High
#define DI_SIG_D0_RD_H_POL			BIT4	// 1 = Active High
#define DI_SIG_D0_WR_H_POL			BIT3	// 1 = Active High
#define DI_SIG_D0_PAR_RS_I_POL		BIT2	// 1 = Inverse Polarity
#define DI_SIG_D0_CS_H_POL			BIT1	// 1 = Active High
#define DI_SIG_D0_DATA_I_POL		BIT0	// 1 = Inverse Polarity

// DI_SER_DISP1_CONF - DI Serial Display 1 Configuration Register

// DI_SER_DISP2_CONF - DI Serial Display 2 Configuration Register

// DI_HSP_CLK_PER DI - HSP_CLK Period Register
#define DI_HSP_CLK_PER_2(_x_)		((_x_ & 0x7F) << 16)	// HSP_CLK period option 2
#define DI_HSP_CLK_PER_1(_x_)		((_x_ & 0x7F) << 0)		// HSP_CLK period option 1

// DI_DISP0_TIME_CONF_1	- DI Display 0 Time Configuration Register 1

// DI_DISP0_TIME_CONF_2	- DI Display 0 Time Configuration Register 2

// DI_DISP0_TIME_CONF_3	- DI Display 0 Time Configuration Register 3

// DI_DISP1_TIME_CONF_1	- DI Display 1 Time Configuration Register 1

// DI_DISP1_TIME_CONF_2	- DI Display 1 Time Configuration Register 2

// DI_DISP1_TIME_CONF_3	- DI Display 1 Time Configuration Register 3

// DI_DISP2_TIME_CONF_1	- DI Display 2 Time Configuration Register 1

// DI_DISP2_TIME_CONF_2	- DI Display 2 Time Configuration Register 2

// DI_DISP2_TIME_CONF_3	- DI Display 2 Time Configuration Register 3

// DI_DISP3_TIME_CONF - DI Display 3 Time Configuration Register
#define DI_DISP3_CLK_DWN_WR(_x_)	((_x_ & 0x3FF) << 22)	// Display 3 interface clock falling edge position for display write access
#define DI_DISP3_CLK_UP_WR(_x_)		((_x_ & 0x3FF) << 12)	// Display 3 interface clock rising edge position for display write access
#define DI_DISP3_CLK_PER_WR(_x_)	((_x_ & 0xFFF) << 0)	// Display 3 interface clock period for display write access

// DI_DISP0_DB0_MAP	- DI Display 0 Byte 0 Mapping Register

// DI_DISP0_DB1_MAP	- DI Display 0 Byte 1 Mapping Register

// DI_DISP0_DB2_MAP	- DI Display 0 Byte 2 Mapping Register

// DI_DISP0_CB0_MAP	- DI Display 0 Command Byte 0 Mapping Register

// DI_DISP0_CB1_MAP	- DI Display 0 Command Byte 1 Mapping Register

// DI_DISP0_CB2_MAP	- DI Display 0 Command Byte 2 Mapping Register

// DI_DISP1_DB0_MAP	- DI Display 1 Byte 0 Mapping Register

// DI_DISP1_DB1_MAP	- DI Display 1 Byte 1 Mapping Register

// DI_DISP1_DB2_MAP	- DI Display 1 Byte 2 Mapping Register

// DI_DISP1_CB0_MAP	- DI Display 1 Command Byte 0 Mapping Register

// DI_DISP1_CB1_MAP	- DI Display 1 Command Byte 1 Mapping Register

// DI_DISP1_CB2_MAP	- DI Display 1 Command Byte 2 Mapping Register

// DI_DISP2_DB0_MAP	- DI Display 2 Data Byte 0 Mapping Register

// DI_DISP2_DB1_MAP	- DI Display 2 Data Byte 1 Mapping Register

// DI_DISP2_DB2_MAP	- DI Display 2 Data Byte 2 Mapping Register

// DI_DISP2_CB0_MAP	- DI Display 2 Command Byte 0 Mapping Register

// DI_DISP2_CB1_MAP	- DI Display 2 Command Byte 1 Mapping Register

// DI_DISP2_CB2_MAP	- DI Display 2 Command Byte 2 Mapping Register

// DI_DISP3_B0_MAP - DI Display 3 Byte 0 Mapping Register

// DI_DISP3_B1_MAP - DI Display 3 Byte 1 Mapping Register

// DI_DISP3_B2_MAP - DI Display 3 Byte 2 Mapping Register

// DI_DISP_ACC_CC - DI Display Access Cycles Count Register
#define DI_DISP3_IF_CLK_CNT_D(_x_)	((_x_ & 0x3) << 12)		// Display clock cycles number minus 1 for output/input one data word
#define DI_DISP2_IF_CLK_CNT_C(_x_)	((_x_ & 0x3) << 10)		// Display clock cycles number minus 1 for output one command word
#define DI_DISP2_IF_CLK_CNT_D(_x_)	((_x_ & 0x3) << 8)		// Display clock cycles number minus 1 for output/input one data word
#define DI_DISP1_IF_CLK_CNT_C(_x_)	((_x_ & 0x3) << 6)		// Display clock cycles number minus 1 for output one command word
#define DI_DISP1_IF_CLK_CNT_D(_x_)	((_x_ & 0x3) << 4)		// Display clock cycles number minus 1 for output/input one data word
#define DI_DISP0_IF_CLK_CNT_C(_x_)	((_x_ & 0x3) << 2)		// Display clock cycles number minus 1 for output one command word
#define DI_DISP0_IF_CLK_CNT_D(_x_)	((_x_ & 0x3) << 0)		// Display clock cycles number minus 1 for output/input one data word

// DI_DISP_LLA_CONF	- DI Display Low Level Access Configuration Register
#define DI_LLA_CONF_DRCT_BE_MODE	BIT5		// 1 = Byte Enable Mode is on (only for parallel display interfaces)
#define DI_LLA_CONF_DRCT_MAP_DC		BIT4		// Selects display mapping for data or command, 1 = Command, 0 = Data 
#define DI_LLA_CONF_DRCT_LOCK		BIT3		// 1 = Lock, DI waits for data from the MCU
#define DI_LLA_CONF_DRCT_DISP0		(0 << 1)	// Display 0 is active
#define DI_LLA_CONF_DRCT_DISP1		(1 << 1)	// Display 1 is active
#define DI_LLA_CONF_DRCT_DISP2		(2 << 1)	// Display 2 is active
#define DI_LLA_CONF_DRCT_RS			BIT0		// 1 = RS is 1

// DI_DISP_LLA_DATA	- DI Display Low Level Access Data Register
//#define DI_DISP_LLA_DATA(_x_)		((_x_ & 0xFFFFFF) << 0)	// Low level access data. This field contain the data of direct access of MCU


