// This file is pulled into the build if VGA_MOD is defined in config.h.
// It provides an alternate configuraion for the mx21 LCD driver code
// to put a full VGA display connection to the mx21.
// (contributed).

// board specific defines for micro monitor
#define DEFAULT_BAUD_RATE   	38400
#define MON_CPU_CLOCK       	266000000

#define LOOPS_PER_USEC			5

// CS8900a 10Mbit Ethernet 
#define CS8900A_BASE_ADDRESS	0xCC000000	// CS1 
#define CS8900A_STEP				4				// CS8900a is on 32-bit boundries
#define CS_TIMEOUT 				500000		// Time to wait for chip to complete various commands

// LCD Defines
//
// The LCD frame buffer is fixed at 0xC0080000, which is .5Mbyte from the
// beginning of SDRAM space.  Note that we access it 16-bits at a time.
//
#define LCD_BUF_ADD				0xc0080000
#define LCD_BUF(_x_)			*(vushort *)(LCD_BUF_ADD + _x_)	// Frame Buffer
#define USE_FONT8X8
#define LCD_GET_PIXEL_ADD(_X_, _Y_)	(((_Y_ * PIXELS_PER_ROW) + _X_)*2)

// defines for the display geometry - TD035 240x320 TFT
#define PIXELS_PER_ROW			640
#define PIXELS_PER_COL			480
#define BITS_PER_PIXEL			16
#define LCD_H_WIDTH 				63	// pulse width in pixels + 1
#define LCD_H_FRONT 				15	// front porch (sync to enable) + 1
#define LCD_H_BACK 				77	// back porch (enable to sync) + 3
#define LCD_V_WIDTH 				1	// pulse width in lines
#define LCD_V_FRONT 				12	// front porch (sync to enable)
#define LCD_V_BACK 				32	// back porch (enable to sync)
#define LCD_PCD					1	// LCD PERCLK3 = 53.2Mhz/PCD +1 = Pixel Clock ~ 26.6Mhz

// from freescale lcd code
//#define LCD_H_WIDTH 			1	// pulse width in pixels
//#define LCD_H_FRONT 			15	// front porch (sync to enable)
//#define LCD_H_BACK 			6	// back porch (enable to sync)
//#define LCD_V_WIDTH 			1	// pulse width in lines
//#define LCD_V_FRONT 			9	// front porch (sync to enable)
//#define LCD_V_BACK 			7	// back porch (enable to sync)

#define TOP						0
#define BOTTOM					(PIXELS_PER_COL-1)
#define LEFT					0
#define RIGHT					(PIXELS_PER_ROW-1)
#define CENTER_X				(PIXELS_PER_ROW/2)
#define CENTER_Y				(PIXELS_PER_COL/2)

#define PIXELS_PER_ROW			640
#define PIXELS_PER_COL			480

#define ROWS_PER_SCREEN			60
#define COLS_PER_SCREEN			80

#define LCD_BG_DEF				1
#define LCD_FG_DEF				14

#define LCD_FB_SIZE(_depth_)				(((PIXELS_PER_COL * PIXELS_PER_ROW) * _depth_) / 8)

#define LCD_ROW_SIZE(_depth_)				((PIXELS_PER_ROW * _depth_) / 8)

#define LCD_GET_ADD(_row_, _col_, _depth_)	(((((_row_ * PIXELS_PER_ROW) * FONT_HEIGHT) \
											  + (_col_ * FONT_WIDTH)) \
											  * _depth_) / 8)



