//=============================================================================
//
//      cpuio.c
//
//      CPU/Board Specific IO
//
// Author(s):    Luis Torrico, Cogent Computer Systems, Inc.
// Date:         10-07-2008
// Description:  This file contains the IO functions required by Micro Monitor
//				 that are unique to each CPU/Board combination
//
//
//=============================================================================

#include "config.h"
#include "cpuio.h"
#include "cpu_gpio.h"
#include "genlib.h"
#include "ether.h"
#include "stddefs.h"
#include "arch_ppc.h"
#include "mpc5121e.h"
#include "mpc5121e_psc.h"


extern int i2c_init(void);

uchar bcolor=0;		// vga black

// Delay for some usecs. - Not accurate, assumes ROM mode
// and no Cache
void udelay(int delay)
{
  int i;
  for ( i = LOOPS_PER_USEC * delay; i ; i--)
	;
}

/* InitUART():
 * This is the top-level UART initialization for the monitor.
 * The CSB781 uses PSC3 as the Debug UART 
 */
void
InitUART(int baud)
{
    if (baud == 0)
        baud = ConsoleBaudRate;

    /* Keep track of the last baud rate, so that it can be used if the */
    /* incoming baudrate is NULL. */
    ConsoleBaudRate = baud;

//	// Set PSC3 register in Clock Control Module
//   	CLOCK_REG(CLOCK_P3CCR) = 0x00020000;	// Disable before you can write
//
//   	CLOCK_REG(CLOCK_P3CCR) = 0x00038000;	// Choose PSC_MCLK_IN and divide it by 2
//
//	// Disable the tx and rx
//   	PSC3_REG_8(PSC_CR) = PSC_MISC(0)		// No command
//   					 | PSC_TC(2)		// Transmitter Disabled
//   					 | PSC_RC(2);		// Receiver Disabled
//
//	// Select the clock source
//   	PSC3_REG_16(PSC_CSR) = PSC_RCS(13)		// set receive clock prescaler to 16
//   					 | PSC_TCS(13);		// set transmitter clock prescaler to 16
//
//	// Select the UART mode
//   	PSC3_REG_32(PSC_SICR) = PSC_SIM(0);	// UART mode, DCD input ignored
//
//	// Select error mode, parity mode, and the parity type
//   	PSC3_REG_8(PSC_MR1) = PSC_PM_NP		// No Parity
//   					  | PSC_B_C_8;		// 8 bits per character
//
//	// Select channel mode, port mode, and stop-bit length
//   	PSC3_REG_8(PSC_MR2) = PSC_SB(7);		// One stop bit at 8 bits per character
//
//	// Set the calculated baudrate depend on the IP bus clock
//   	//PSC3_REG_8(PSC_CTUR) = ((PSC_CLK/(baud * 16)) >> 8);	// Set the upper bytes for the divider
//   	//PSC3_REG_8(PSC_CTLR) = (PSC_CLK/(baud * 16));	// Set the lower bytes for the divider
//   	PSC3_REG_8(PSC_CTUR) = 0x00;	// Set the upper bytes for the divider
//   	PSC3_REG_8(PSC_CTLR) = 0x35;	// Set the lower bytes for the divider
//
//	// Select the desired interrupt
//	PSC3_REG_16(PSC_IMR) = 0x0000; 		// No interrupts set
//
//	// Enable tx and rx
//   	PSC3_REG_8(PSC_CR) = PSC_TC(1)		// Transmitter Enabled
//   					 | PSC_RC(1);		// Receiver Enabled

	// Set PSC3 register in Clock Control Module
   	CLOCK_REG(CLOCK_P3CCR) = 0x00000000;	// Disable before you can write

   	CLOCK_REG(CLOCK_P3CCR) = 0x00010000;	// Choose XCLK (132MHz) and divide it by 2

   	CLOCK_REG(CLOCK_P3CCR) = 0x00050000;	// enable

	// Reset Rx and Tx FIFO slice
   	PSC3_REG_32(PSC3_RX_CMD) = 0x00000080;				 
   	PSC3_REG_32(PSC3_TX_CMD) = 0x00000080;				 

	// Disable Rx and Tx FIFO interrupts
   	PSC3_REG_32(PSC3_RX_IMR) = 0x00000000;				 
   	PSC3_REG_32(PSC3_TX_IMR) = 0x00000000;				 

	// Set Rx and Tx FIFO size
   	PSC3_REG_32(PSC3_TX_SIZE) = 0x00000004;				 
   	PSC3_REG_32(PSC3_RX_SIZE) = 0x00100004;				 

	// Enable Rx and Tx FIFO slice
   	PSC3_REG_32(PSC3_RX_CMD) = 0x00000001;				 
   	PSC3_REG_32(PSC3_TX_CMD) = 0x00000001;				 

	// Disable clock gateing
   	FIFOC_REG(FIFO_CMD) = 0x00000000;				 

	// Set MR register to point to MR1
   	PSC3_REG_8(PSC_CR) = 0x10;				 

	// Disable tx and rx
   	PSC3_REG_8(PSC_CR) = 0x0A;				 

	// Select the prescaler by 16 for the Tx/Rx clock generation
	PSC3_REG_16(PSC_CSR) = 0xDD00; 		    

	// Select UART mode
   	PSC3_REG_32(PSC_SICR) = 0x00000000;		 

	// Mode register points to MR1
	// Configure parity and bit length
   	PSC3_REG_8(PSC_MR1) = 0x13;		 

	// Now, Mode register points to MR2
	// Configure parity and bit length
   	PSC3_REG_8(PSC_MR2) = 0x07;		 

	// Set the calculated baudrate depend on the IP bus clock
   	//PSC3_REG_8(PSC_CTUR) = ((PSC_CLK/(baud * 16)) >> 8);	// Set the upper bytes for the divider
   	PSC3_REG_8(PSC_CTUR) = 0x00;	// Set the upper bytes for the divider
   	//PSC3_REG_8(PSC_CTUR) = ((PSC_CLK/(baud * 16)) >> 8);	// Set the upper bytes for the divider
   	PSC3_REG_8(PSC_CTLR) = (PSC_CLK/(baud * 16));	// Set the lower bytes for the divider
   	//PSC3_REG_8(PSC_CTLR) = 16;	// Set the upper bytes for the divider

	// Disable all interrupts
	PSC3_REG_32(PSC_IMR) = 0x00000000;		// 

	// Reset and enable Tx and Rx
   	PSC3_REG_8(PSC_CR) = 0x20;		// Reset Rx
   	PSC3_REG_8(PSC_CR) = 0x30;		// Reset Tx
   	PSC3_REG_8(PSC_CR) = 0x05;		// Rx and Tx Enabled

//    InitRemoteIO();
}

int
ConsoleBaudSet(int baud)
{
   	//PSC3_REG(PSC_CTUR) = ((PSC_CLK/(baud * 16)) >> 8);	// Set the upper bytes for the divider
   	PSC3_REG_8(PSC_CTUR) = 0x00;	// Set the upper bytes for the divider
   	//PSC3_REG_8(PSC_CTUR) = ((PSC_CLK/(baud * 16)) >> 8);	// Set the upper bytes for the divider
	PSC3_REG_8(PSC_CTLR) = (PSC_CLK/(baud * 16));	// Set the lower bytes for the divider
   	//PSC3_REG_8(PSC_CTLR) = 16;	// Set the lower bytes for the divider
	return(0);
}

int
devInit(int baud)
{
	// Initialize IO Control
	ioctrl_init();

	// Initialize the UART
    InitUART(baud);

	// Initialize cdce925 to set correct clock values
	cdce925_init();

	// Initialize the I2C Port
	//i2c_init();

	// Initialize the GPIO Port
	//GPIO_init();

	return 0;
}

int
target_console_empty(void)
{
	//if (PSC3_REG_16(PSC_SR) & PSC_USR_TXEMP)
    if (PSC3_REG_32(PSC3_TX_STAT) & 0x0001)
		return(1);
	return(0);
}

int
target_putchar(char c)
{
    /* Wait for transmit ready bit, then send character.
	 */
    //while(!(PSC3_REG_16(PSC_SR) & PSC_USR_TXEMP)){}
    while(!(PSC3_REG_32(PSC3_TX_STAT) & 0x0001)){}
	//PSC3_REG_32(PSC_TXB) = (ulong)c;
	PSC3_REG_32(PSC3_TX_DATA) = (ulong)c;
//	lcd_putchar(c);
    return((int)c);
}

int
target_gotachar(void)
{

    //if (PSC3_REG_16(PSC_SR) & PSC_USR_RB)
    if (!(PSC3_REG_32(PSC3_RX_STAT) & 0x0001))
        return(1);
    return(0);
}

int 
target_getchar(void)
{
    char    c;


    //c = (uchar)PSC3_REG_32(PSC_RXB) & 0xff;
    //c = (uchar)PSC3_REG_32(PSC3_RX_DATA) & 0xffff;
   c = (uchar)PSC3_REG_8(PSC3_RX_DATA) & 0xff;
    return((int)c);
}

void
target_reset(void)
{
	coldstart();
}

void
initCPUio(void)
{
//	/* Set the UART for two-port mode */
//	UARTA(UART_DCR) = DCR_SDM;
//	return;
}

void
intsrestore(ulong msr)
{
    ppcMtmsr(msr);
}

ulong
intsoff()
{
    ulong  msr;

    msr = ppcMfmsr();
    ppcMtmsr(msr & ~0x8000);
    return(msr);
}

/* cacheInitForTarget():
    Enable instruction cache only...
*/
void
cacheInitForTarget()
{
    asm(".equ   r3,3");
    asm(".equ   IC_CST,560");

    asm("   mfspr   r3,IC_CST");    
    asm("   lis     r3,0x0200");
    asm("   mtspr   IC_CST,r3");
    asm("   isync");
}
